缠中说禅重新编排版《论语》（整理版）

> 编撰者按：本人自知是学识浅薄之人，这里仅仅是对缠中说禅博客“《论语》详解：给所有曲解孔子的人”部分内容进行汇集。同时在保留释义不变的情况下对一些不太适宜的内容进行删减。这个编撰还未完成，缓慢进行中。

- 阅读博客原文，推荐到 缠论坛

## 缠中说禅编排版《论语》一览

1. 子曰：学而时习之，不亦说乎？有朋自远方来，不亦乐乎？人不知而不愠，不亦君子乎？
2. 子曰：朝闻道夕死，可矣！
3. 子在川上曰：逝者如斯夫，不舍昼夜。
4. 子曰：人能弘道，非道弘人。
5. 子曰：攻乎异端，斯害也己。
6. 子曰：道，不同、不相为谋。
7. 子曰：有教无类。
8. 子曰：士志於道，而耻恶衣恶食者，未足与议也！
9. 子曰：贤哉，回也！一箪食，一瓢饮，在陋巷，人不堪其忧，回也不改其乐。贤哉，回也！
10. 子曰：贫而无怨难；富而无骄易。
11. 子贡曰：“贫而无谄，富而无骄，何如？”子曰：“可也；未若贫而乐，富而好礼者也。”
12. 子曰：齐一变，至於鲁；鲁一变，至於道。
13. 子曰：放于利而行，多怨。
14. 子曰：好勇疾贫，乱也。人而不仁，疾之已甚，乱也。
15. 子曰：善人为邦百年，亦可以胜残去杀矣。诚哉是言也！
16. 子曰：如有王者，必世而后仁。
17. 子适卫，冉有仆。子曰：“庶矣哉！”冉有曰：“既庶矣，又何加焉？”曰：“富之。”曰：“既富矣，又何加焉？”曰：“教之。”
18. 子曰：善人、教民七年，亦可以即戎矣。
19. 子曰：以不教民战，是谓弃之。
20. 哀公问社於宰我。宰我对曰：“夏后氏以松，殷人以柏，周人以栗，曰，使民战栗。”子闻之，曰：“成事不说，遂事不谏，既往不咎。”
21. 子曰：夷狄之有君、不如，诸夏之亡也。
22. 子曰：为政以德譬，如北辰居其所而众星共之。
23. 季康子问政於孔子，孔子对曰：政者，正也，子帅以正，孰敢不正？
24. 子曰：不在其位，不谋其政。
25. 子曰：“不在其位，不谋其政。”曾子曰：“君子思不出其位。”
26. 子曰：“不患，无位；患，所以立。不患，莫己知求，为可知也。”
27. 子曰：不患人之不己知；患其不能也。
28. 子曰：“不患人之不己知；患不知人也。”
29. 子曰：“性相，近也；习相，远也。”
30. 子曰：人无远虑，必有近忧。
31. 子曰：众，恶之，必察焉；众，好之，必察焉。
32. 子曰：视，其所以；观，其所由；察，其所安。人焉廋哉？人焉廋哉？
33. 子曰：不知，命无以为君子也；不知，礼无以立也；不知，言无以知人也。
34. 子曰：由知、德者，鲜矣！
35. 子曰：民可，使由之；不可，使知之。
36. 子曰：由诲女，知之乎！知之为，知之；不知为，不知；是知也！
37. 子曰：我非生而知之者，好古，敏以求之者也。
38. 孔子曰∶生而知之者，上也；学而知之者，次也；困而学之，又其次也。困而不学，民斯为下矣！
39. 子曰：盖有不知而作之者，我无是也。多闻，择其善者而从之；多见而识之；知之次也。
40. 子张学干禄。子曰：多闻阙疑，慎言其余，则寡尤。多见阙殆，慎行其余，则寡悔。言寡尤，行寡悔，禄在其中矣。
41. 子曰∶君子谋道不谋食。耕也，馁在其中矣；学也，禄在其中矣。君子忧道不忧贫。
42. 子曰：君子不器。
43. 子曰：古之学者为己；今之学者为人。
44. 子曰：三年学不至，於榖不易，得也。
45. 子曰：学如不及，犹恐失之。
46. 子曰：学而不思则罔，思而不学则殆。
47. 子曰：唯！女子与小人为难、养也。近之则不孙，远之则怨。
48. 子曰：唯上知与下愚不移。
49. 子曰：温故而知新，可以为师矣。
50. 子曰：吾十有五而志于学，三十而立，四十而不惑，五十而知天命，六十而耳顺，七十而从心所欲不逾矩。
51. 子曰：君子，食无求饱，居无求安；敏於事而慎於言；就有，道而正焉；可谓好学也已。
52. 子曰：十室之邑，必有忠信如丘者焉，不如丘之好学也。
53. 子曰：三人行，必有我师焉：择其善者而从之，其不善者而改之。
54. 子夏曰：日知其所亡，月无忘其所能，可谓好学也已矣！
55. 子夏曰：仕而优则学；学而优则仕。
56. 子夏曰：百工居肆以成其事；君子学以致其道。
57. 子谓子夏曰：女为君子儒！无为小人儒！
58. 哀公问：“弟子孰为好学？”孔子对曰：“有颜回者好学，不迁怒，不贰过。不幸短命死矣，今也则亡，未闻好学者也。”
59. 季康子问：“弟子孰为好学？”孔子对曰：“有颜回者好学，不幸短命死矣！今也则亡。”
60. 子曰：语之而不惰者，其回也与？
61. 子贡问君子。子曰：先行其言而后从之。
62. 子贡问曰：“赐也何如？”子曰：“女，器也。”曰：“何器也？”曰：“瑚琏也。”
63. 子贡问曰：“有一言而可以终身行之者乎？”子曰：“其恕乎？己所不欲，勿施於人。”
64. 子贡曰：“我不欲人之加诸我也，吾亦欲无加诸人。”子曰：“赐也，非尔所及也。”
65. 子曰：“赐也，女以予为多学而识之者与？”对曰：“然，非与？”曰：“非也！予一以贯之。”
66. 子曰：“参乎！吾道一以贯之。”曾子曰：“唯。”子出。门人问曰：“何谓也？”曾子曰：“夫子之道，忠恕而已矣。”
67. 有子曰：其为人也孝弟，而好犯上者，鲜矣；不好犯上，而好作乱者，未之有也。君子务本，本立而道生。孝弟也者，其为仁之本与！
68. 孟懿子问孝。子曰：“无违”。樊迟御，子告之曰：“孟孙问孝於我，我对曰，”无违。””樊迟曰：“何谓也？”子曰：“生，事之以礼；死，葬之以礼，祭之以礼。”
69. 子游问孝。子曰：“今之孝者，是谓能养。至於犬马，皆能有养；不敬，何以别乎。”
70. 孟武伯问孝。子曰：“父母唯其疾之忧。”
71. 子夏问孝。子曰：色难。有事，弟子服其劳；有酒食，先生馔，曾是以为孝乎？
72. 子曰：父母在，不远游，游必有方。
73. 子曰：父母之年，不可不知也。一则以喜，一则以惧。
74. 子曰：君子喻於义，小人喻於利。
75. 子曰：君子周而不比，小人比而不周。
76. 子曰：君子和而不同；小人同而不和。
77. 子曰：君子成，人之美；不成，人之恶。小人反是。
78. 子曰：君子之於天下也，无适也，无莫也，义之於比。

《论语》中章节的题目都是后人所加，而整个《论语》是气脉贯通的，其实并不需要分什么章节。

文言文中，每个字都有着丰富的含义，但这也使得相应的理解往往很难把握。对文言文的把握，例如，对《论语》的解释，不能按照白话文那种西方式思维，首先假设文章的意义是如同细胞之于人体般由字符堆积起来，就如同西医般，白话文是一种死的文字。而文言文不同，理解文言文必须首先要得其神，而其神不在字符中，是文章的整体，如同中医，离开了整体的字符是没意义的。庖丁解牛，神遇而牛解，文言文的阅读也一样，神不遇而解其文，无有是处。

## 1. 子曰：学而时习之，不亦说乎？有朋自远方来，不亦乐乎？人不知而不愠，不亦君子乎？

所谓半部《论语》治天下，这开头，当然不是一般所解那般肤浅可笑。这三句话只是一句话，这是一个整体，是整个儒家思想的概括。浩如烟海的儒家经典，不过是这三句话的一个推演。明白了这三句话，整部《论语》就豁然了，就知道上面“整个《论语》是气脉贯通的”那话并不是随便说的。

“学而时习之”，什么是学？谁学？学什么？学了能成什么？首先，这“学”前面就少了一个主语。不解决这个“学”前面缺少的主语，是不可能明白《论语》的。其实，这主语就在这句子里，就是“君子”。学《论语》的，就是这“君子”，这话最后就落实在这“君子”上。整个儒家学说，归根结底，就是“君子学”。何谓“君子”？“君子”就是要成为“君”的人。“君子学”最终的目的就是要成为“君”。何谓“君”？“君”就是“圣人”。

那么，为什么是“君子学”，而不是“圣人学”？“圣人”是无学的，整部《论语》，整个儒家学说，就是讲述如何从“君子”“学而”成“君”、也就成“圣人”的过程，只有这个过程才有所谓“学”的问题。“君子学”不是学当“君子”，而是只有“君子”才能“学”，只有“君子”在这成为“君”的道上不断“学”，才有“君子学而”成“君”的可能。

但这“君”不是一日炼成的，当你打开《论语》，当你要学《论语》，你首要明白的是，你最终要通过《论语》而成为“君”，成为“圣人”，有了这个志愿，才有必要看《论语》，而《论语》下面的话才有意义。阅读是不能脱离读者的，而不能承当这个阅读的读者是没有阅读的，只不过是看一些文字符号而已。

在人人争当经济人的年代谈论成圣人之道，也忒不靠谱了。当然，任何的不靠谱都是站在一定立场上的，而圣人的不靠谱，必须有非圣人的视角，例如：经济人、社会人等。没有任何没有前提的逻辑是可以无条件地被证明的，没有一个视角是绝对的、不需要前提的，既然这样，这世界的喧嚣已经不缺乏经济人、社会人了，圣人当然也有喧嚣的必然。

站在这个角度，没有任何视角是有永恒价值的，但也没有任何视角是永恒没有价值的，《论语》一样，孔子一样，圣人也一样。但曲解是不允许的，必须首先要弄清楚《论语》究竟在说什么，否则一切的赞誉或诋毁都无意义。 当然，在喧嚣的年代，无意义就是最大的意义，那就让最大继续最大，最后阳亢而死。而继续《论语》之旅，进入《论语》之旅的前提就是，要立志成为“圣人”，或者至少要有兴趣去了解如何成为“圣人”。

“学”的主语解决了，那“学”的宾语是什么？也就是说，“君子”要学什么才能成就“圣人”？千古以来，基本所有的解释都把这“学”当成各种一般技能、学问的学习了。但《论语》不一般地探讨所谓的教育问题，《论语》归根结底是探讨儒家的核心问题，是如何成“圣人”的问题，因此这里的“学”不是一般教育意义上的，而是“闻道”、“见道”、“学道”，“学”后面的宾语只能是成“圣人”之道。

这里的“学”，首先是“闻道”，不闻无以学，其次是“见道”，不见亦无以学。只有“见道”以后，才可以真正地“学道”。和“学”同源的是“校”，也就是“效”，就是“效法”。“学”，不是一个人的瞎修盲练，而是要“效法”，“效法”什么？当然就是“圣人”了。“校”，至少要包含两个不能偏废的方面：1、对照；2、校对。“对照”“圣人”学之效之而使自己也成为“圣人”，但这种“学”和“效”不是固定不变、一劳永逸的，必须不断地“校对”。就像一块表，按报时调好后，并不是一劳永逸，而是要不断地“校对”，表才不会出现大的偏差。 儒家的思想是积极入世的，因此这“校对”的工夫，就不光光是“对照”“圣人”理论，而是必须针对现实，脱离了现实，就无所谓“校对”，也无所谓“学”了。而现实中的“学”，必然是群体性的，用现代术语，就是社会性的。因此，这“学”字的完整意义就是，闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”，只有这，才勉强称得上“学”。

对““学而时习之”中的“学”，概括如下，就是：

问：什么是学？
答：闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”。

问：谁学？
答：君子。

问：学什么？
答：成“圣人”之道。

问：学了能成什么？
答：“圣人”。

上面说了“学”，现在继续说这“习”字。甲骨文中“习”是“羽”字下从“日”，后来篆书误把“日”写成“白”，将错就错，一直流传下来，结果现在的繁体字里，“羽”字下从“白”，简体字就干脆把“羽”字劈成两半，“白、日”都不要。“习”，“羽”字下从“日”，本义指的就是鸟儿在晴天里试飞。这个“习”字，如诗如画，一字而有神。“日”属阳，所谓乘天地之正气而游六合，就是“习”，也才是“习”。但后来所有的解释，都把“习”当成不断、反复、频频地练习、温习、复习之类的玩意，典型的白话文思维，以为不断上下左右地折腾就可以表现出色、工夫了得、赢得奖赏，真是既无情趣、又无品位。

“学”而“习”，就是“闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对””而得乘天地之正气而游六合。不“学”“圣人之道”，无以得乘天地之正气。“学”，得“圣人之道”之体；“习”，施“圣人之道”之用。不“学”无以成其“习”，不“习”无以成其“学”，全体而大用，这才算是“学”而“习”之。何谓“之”？成圣人之道也。

“学”而“习”之，必与其时，所以有“学而时习之”。“时”者，天时，非依其时，乃与其时、时其时也。依其时者，小人也；与其时者，君子也；时其时者，君子行成“圣人之道”也。可笑几乎所有的解释，都将“时”弄成所谓按时、依时、适时之类的玩意，真不知其时矣。而“时其时”者，必得乘天地之正气，此谓得其天时也。“时其时”者，非得天与其时，乃与天其时也。由此可见，所谓天时，是与天其时而天与其时也。不如此知之，实不知何谓“时”矣。

“学而时习之”，君子闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”，与天其时而天与其时，得乘天地之正气而游六合，行成圣人之道，这样，才能“不亦说乎”。后面这句“不亦说乎”，就不用解释了吧。

“学而时习之”，与天其时而天与其时，风云际会、波随浪逐，感而“有朋自远方来”。“有”，非“有无”、“持有”之“有”，乃《左传》“是不有寡君也”之“有”，“友”之通假也。几乎所有的解释都将“有”解释成“有无”、“持有”之“有”，大谬矣。何谓“友”？“同志为友”，志向相同者也。甲骨文中，“友”为双手并列，为共同的志向而联手、而互助合作，才是“友”。在《论语》里，“有”或“友”的共同志向就是同成“圣人之道”。“圣人之道”，不是独自去偷欢的私道、小道，是普及天下、大善天下的公道、大道。要成“圣人之道”，成“圣人”，必须先“圣”其时，不“圣”其时，何以“圣”其人？圣人者，必圣其时、必圣其地、必圣其人，复圣它时、复圣它地、复圣它人也。而君子行“圣人之道”，必有之、方类之。

“朋”者，“凤”之古字也，本义为凤凰。“朋自远方”者，“有凤来仪”也。《尚书·益稷》“箫韶九成，凤凰来仪。”，而“有朋自远方来，不亦乐乎？”，实本于此。“有凤来仪”之地，即地灵之地，行“圣人之道”之地。而行“圣人之道”之君子，就是“人中之凤”，行“圣人之道”之君子“自远方来”，就是“有凤来仪”。“仪”者，法度也。“朋自远方来”干什么？法度也。以“圣人之道”法度之，教化之，成就“圣人之道”彰显之天下，这才是真行“圣人之道”。

“远”，遥远、久远，不独指空间上的，“圣人之道”不是凭空而起，源远而流长。

“方”，非方向之类，而是“旁”的通假，广大的意思。《尚书·立政》，“方行天下，至于海表”，“圣人之道”之“行”，是“方行”，君子“行”圣人之道，也是“方行”，要“方行天下，至于海表”，这才算“行”圣人之道之“行”。

“自”，不是介词。文言文的“自远方来”不是白话文的“自远方来”，每一个字都有着独立的意思，把“自”当成介词表示时间、方位的由始，那是白话文中的意思。“自”者，依旧、依然也。依旧、依然“有凤来仪”，“圣人之道”不断也。“来”，由彼至此、由远及近，浩浩汤汤，如日之东升、海之潮回，天地浩然正气升腾之景象也。圣人之道，大道流行，其远矣，其方矣。

“有朋自远方来”，君子，为共同的志向而联手，为共成“圣人之道”而同行，如人中之凤，依旧、依然，乘天地之正气，源远而流长、浩瀚而广大，由彼至此、由远及近，如日之东升、海之潮回，将“圣人之道”披之六合、播于八方，法度之，教化之，成就“圣人之道”彰显之天下，这样，才能“不亦乐乎”。“乐”者，非le，是yue，箫韶九成，盛世之象也。

将“圣人之道”披之六合、播于八方，法度之，教化之，首要且常态地必然会面对“人不知”的问题。如果“人皆知”了，就无所谓“法度之，教化之”。行“圣人之道”，乃难行之行，所谓知易难行，知且不易，行则更难。

“人不知而不愠”，几乎所有的解释都把“知”当成“知道”、“理解”之类的玩意。“人不知而不愠”快成了现在酸死人的“理解万岁”的对应物了。但这里的“知”不是本义的“知”，而是“智”的古字，“人不知”不是“人不知道”，而是“人没有智慧”。“人”，一般指别人，但这里的别人特指那些不能“闻、见、学、行”“圣人之道”的人，也就是行“圣人之道”时需要“法度之，教化之”的人。“人不知”，这些人没有智慧，没有什么智慧？没有“闻、见、学、行”“圣人之道”的智慧。

比起“人不知而不愠”中的“愠”，上面“知”的错解就是小菜了。对于这个“愠”，《论语》成书后，所有解释都是“生气、愤怒”之类。其实，“愠”，发yun音，有两种声调，第一种发去声，就是通常解释“生气、愤怒”的那个，但这在这里大错特错，这里的音调应该发上声，解释为“郁结”。《孔子家语》有“南风之熏兮，可以解吾民之愠兮”，其中的“愠”就是发上声，解释为“郁结”。而这里的“不愠”，就是本于“南风之熏兮，可以解吾民之愠兮”。

“不愠”，是“使之不愠”的意思，“之”是指“人不知”里的人，谁使之？行“圣人之道”的人。“愠”的根源在于“不知”，一个人“不知”，各种不好的情绪就会“郁结”其中，就会生病，对于中医来看，所有的病，归根结底就是“愠”，就是“郁结”。一个家庭、一个团体、一个国家、一个世界，如果由“不知”的人组成，那么同样要“愠”，同样要生出“郁结”来，所谓民怨沸腾、夫妻不和、冷战热战，等等，都是由“不知”而“愠”的结果。

一个和谐的世界、一个大同世界、一个政通人和的世界，前提必然是“不愠”的，行“圣人之道”的人就是要使得“不知之人”变得“不愠”，使得“不知之世界”变得“不愠”。“学而时习之”、“有朋自远方来”、如“南风之熏”般地行“圣人之道”，一个最重要的成果检测标准就是“不愠”，就是和谐，就是大同，就是政通人和，就是要把“人不知”的世界改造成“人不愠”的世界。

“人不知而不愠”，现实的天下仍未成就“圣人之道”的彰显，现实的天下几乎都是不能“闻、见、学、行”“圣人之道”的人，他们没有“闻、见、学、行”“圣人之道”的智慧，而行“圣人之道”的人，要如“南风之熏”般地熏染他们，把“没有智慧的人”改造成“没有郁结的人”，把“没有智慧的世界”改造成“没有郁结的世界”，这样，才能“不亦君子乎”，才能算是真正行“圣人之道”的人。

《论语》二十篇，实为一大文章，而首章三个“不亦”，为文章之纲领，也是儒学之总纲。世人皆说《易》难解，实则，《易》是隐而难，《论语》是显而难，是难上加难。《论语》书成后，真能解首章的，千古以来，未曾见也。而首章都不能解，后面就更是以盲引盲。

本ID所写，皆发前人所未发，余人从其字句中求《论语》之真精神，不过是啃尸之徒。《论语》不死之真精神，岂在区区字句间。神会，则字句之纠缠自然顿明。下面将解释一个千古无人能解的问题：为什么《论语》首章是三个“不亦”，不是二个，也不是四个或其它？

对于以前所有解《论语》的人，对这三个“不亦”，连这些人自己都是囫囵吞枣，又怎么可能解释好？上面为什么是三个“不亦”的问题，这些人连提都不敢提，或者根本就没想到，就更不要说解答了。这个问题的答案，本ID在前面的解释中其实已有所透露，在（四）中就有“圣人者，必圣其时、必圣其地、必圣其人，复圣它时、复圣它地、复圣它人也。”也就是说，这三个“不亦”，基于儒家最基本的信念，即儒家思维最基本的结构：天、地、人。

“学而时习之”，言“天”，在儒家思维的基本结构下，天与天时，“天、天时”是一而二、二而一的。与“天、天时”紧密联系的就是所谓的“天命”了。参照前面对“时”的解释，就不难知道，《论语》对天时、天命的态度就是“与天其时而天与其时”、“与天其命而天与其命”，儒家对“时运”、“命运”的态度是十分积极的。“学而时习之”就是要成就这“与天其时而天与其时”、“与天其命而天与其命”。

“有朋自远方来”，言“地”。地，包括土地等，但不单指土地，甚至地球之类的玩意，而是指大道流行的场所、空间等。地是离不开天的，有其天时，必成就其地，其地，包括一切的现实客观条件。通常所说的“地运”、“国运”等，就属于“地”的范围。一般人更熟悉的，就是所谓的“地利”了，儒家对“地利”的态度也是“与地其利而地与其利”。“有朋自远方来”就是要成就这“与地其利而地与其利”。

“人不知而不愠”，言“人”。人，天地之心也。张载所言“为天地立心，为生民立命，为往圣继绝学，为万世开太平”，说的就是这“人不知而不愠”。那么天地之心在哪里？天地之心就在人的心里，人心立，则天地立其心。西学讲人化自然，后来又有了所谓的人择原理，但对这“天地人”的关系，还是没有儒家、《论语》讲得透彻。“人不知而不愠”，就是要成就“与人其和而人与其和”，最终成就真正的“人和”。

这三个“不亦”，讲的就是君子如何“与其天时、与其地利”，最后“成其人和”，什么才是真正的“人和”？就是“人不愠”的世界，“没有郁结的世界”，就是世界大同。只有“与人其和而人与其和”，最终成就真正的“人和”，君子才算是真正行成“圣人之道”。离开这三个“不亦”，一般所说的“天时、地利、人和”，实不知何谓“天时、地利、人和”也。

明白了上面，就不难明白这三个“不亦”，为什么是按“说、乐、君子“的顺序来安排。“说”，就是“悦”，对于忧郁症等大流行的现代社会，这个“悦”太罕见了，而连“悦”都没有，就不要侈谈诸如幸福感之类的废话。那么，何谓真“悦”？“闻、见、学、行”“圣人之道”也。“闻、见、学、行”“圣人之道”，才是真正快乐的事，令人心情舒畅的事，如果个体的心情都不能“悦”、不能“不愠”，怎么可能成就“不愠”的世界？所以要“修身”，“学而时习之”地“修身”，其结果就是“悦”，“悦”也就是个体的“不愠”。那么，“修身”为什么和“天时”挂钩？所谓“修身”不是一个人的盲修瞎练，“闻、见、学、行”“圣人之道”要“与天其时而天与其时”，其中的关系是密不可分的。

“修身”，然后要“齐家”。这“家”，不是一般所谓的家庭，那是“小家”，一个地区是家，一个国家也是家，那是“大家”。齐家才能“乐”，这读yue，箫韶九成，盛世之象。家不齐，国不齐，怎么可能有“箫韶九成，盛世之象”？所以要“齐家”，“有朋自远方来”就是要“齐家”，其结果就是“乐”，“乐”也就是“家”的“不愠”，只有“不愠”才可能“箫韶九成，盛世之象”，才可能“乐”。那么，“齐家”为什么和“地利”挂钩？家、国都属于“地”的范畴，通常有所谓的“家运”、“国运”等，要“齐家”，改变“家运”、“国运”，就要“与地其利而地与其利”，这样才能最终成就“箫韶九成，盛世之象”，其中的关系是密不可分的。

“齐家”，然后要“平天下”。而只有“天下平”了，世界“不愠”、没有郁结了，世界大同了，才算是“平天下”，才算是“人和”，才算是君子行“圣人之道”，才算是“不亦君子乎？”上面的“说”、“乐”，都是“不愠”的特殊形式，分别对应着个体和家，但真正的“不愠”是全天下的，这个天下不单单指人类社会，按现代术语，至少是包括了整个人类社会和自然界。天下万物都要和谐、都要“不愠”，这才是真的“不愠”，也才是真的“平天下”，只有这样，才是真的“人和”了。所以，“平天下”与“人和”是密不可分的！

综上所述，可以清楚地看到，“学而时习之”、“有朋自远方来”、“人不知而不愠”与“说、乐、君子”以及“天、地、人”或“天时、地利、人和”之间的关系密不可分，《论语》的首章是站在这样的高度立论的，而不是如千古以来那些盲人的瞎解释所说那样。只有这样，才算初步明白“子曰：学而时习之，不亦说乎？有朋自远方来，不亦乐乎？人不知而不愠，不亦君子乎？”的意思，也才算初步知道《论语》说了点什么。但这只是一个大纲，只是一个框架，更重要的东西还在后面。

《论语》，中文第一书，其开头：
“子曰：学而时习之，不亦说乎？有朋自远方来，不亦乐乎？人不知而不愠，不亦君子乎？”

《圣经》，西文第一书，其开头：
“起初，神创造天地。地是空虚混沌，渊面黑暗；神的灵运行在水面上。神说：「要有光」，就有了光。”
相互对比，这两者之间的区别是显然的，这种区别也构成国学与西学的重大分歧，更构成了国人和西人思维方式和生存状态的重大分歧。

“子曰”，对应的是当下，是现世，是人；而“起初”，对应的是起源，是根源，是神。对于国学来说，“天、地、人”的思维和生存结构是当下的，所谓当下，就是承担，任何根源性的探讨，都必须以这当下的承担为前提。换句话说，一切科学、宗教、艺术，都是以这“天、地、人”的思维和生存结构的承担为前提的。你，首先是一个人，而且是在世界、在天地中生存的人，没有这个承担，一切都瞎掰。人，对于国学来说，不是一个前提，因为任何前提都以之为前提，连前提这个词都要以之为前提，那么人，又怎能是一个前提所能困住的？

而西人的生存和思维方式又是什么呢？柏拉图有著名的洞喻，说人如在洞中，须走到洞外，靠理智的光辉才能看清楚世界。这个比喻完全概括了柏拉图后整个西学以及西人的状态，这里没有了承担，人需要靠理智的光辉，这理智的光辉，在耶教里变成了上帝，耶教从本质上说就是柏拉图思想的神秘化。后来，科学代替了上帝的位置，但无论是理智、上帝还是科学，人都是奴隶，人不能独自去承担，独自去面对，而是要靠某样东西，即使那样东西被称为理智的光辉，也是典型的懦夫思维。

对于西人来说，他们可以如古希腊一样悲剧，一样面对命运去抗争，但人的尊严只是一个推论或假设的前提。但是，只有奴隶才需要解放，只有奴隶才需要自由，只有奴隶才需要尊严，而你本解放，你本自由，你本尊严，又何须劳什子的解放来解放你、自由来自由你、尊严来尊严你？你只要承担，人一样去承担。承担什么？承担这个天地，人，天地之心；天地，人之躯壳，你连自己的躯壳都不能承担，你还能算是人吗？

承担，就是《论语》、也是儒学的真精神，什么是承担？就如本ID所写《六州歌头》里的“入红尘戏。惊天地，鹏展翅。挟风雷，存永罪，终不悔。振罗衣，立云霓，抖擞凌霄志。银河坠，缺星堤，弯日轨，旋经纬，乾坤回。混浊同污，纳纳穹苍气，激荡崔嵬，送鲸涛翻海。掷酒一高歌，万古同杯。”这，就是承担。 这里不需要假设什么理智的光辉，也不需要假设什么上帝，如果真有什么理智、上帝，都只能是人的理智、人的上帝，最终都需要人来承担。人，浩然之气充盈天地，天地都为之小，一人成大，一人就成其天地之大，没有这种胸襟，没有这种浩然，没资格谈论儒家，没资格谈论《论语》。

当然，西学之内也并不都是糊涂蛋，例如马克思、海德格尔，他们所展示的就是柏拉图以来西学完全不同的道路。从气质上说，马克思走的是刚阳路子，而海德格尔是阴柔的，这方面的研究，这里就不展开了，只是要说明，那些妄自菲薄、以贩卖祖宗为乐的畜生，不仅不理解国学，连西学也是人屁不通。用郭德刚的口吻送给这些人，就两字：死去！

对首章三个“不亦”的初步了解，最终必须落在“承担”上，如果没有这种对“天地人”、对“圣人之道”、对行“圣人之道”最终达到“不愠的世界”的承担，那么就没必要继续《论语》的研读。

## 2. 子曰：朝闻道夕死，可矣！

这句话被排在三个“不亦”总纲之后，是《论语》的第一条。所谓“闻、见、学、行”“圣人之道”，首先要“闻其道”。道不闻，则无由“学、行”。

“死”，不是死去的意思，而是“固守”的意思。所谓“固守”，也就是“承担”。 而“朝、夕”，不是单纯的“早晨、晚上”，而应该从“天、地、人”三个角度来考察。从“天”的角度，代表了时间上的“开始、最后”，从“闻其道”开始，不断地“固守”，“承担”“圣人之道”之行直到最终成就“不愠的世界”而不退转；从“地”的角度，代表了“东方、西方”，也代表了整个天下所有的地方，无论任何地方，无论条件恶劣还是优越，都要不断地“固守”，“承担”“圣人之道”之行直到最终成就“不愠的世界”而不退转；从“人”的角度，最大的承担就是生死的承担，所谓出生入死，都要不断地“固守”，“承担”“圣人之道”之行直到最终成就“不愠的世界”而不退转。只有从这三方面去理解，才是真知道“朝、夕”。

原来的断句“子曰：朝闻道，夕死可矣！”是不对的，由于古文都没有标点，因此断句就是一个很大的问题。千古以来被惯用的这个断句，就把“死”真当死给搞死了。而从上面的分析知道，这“死”是“固守”、是“承担”，相应的断句就是“子曰：朝闻道夕死，可矣！”其实，里面的“道”字是可以省略的，因为整部《论语》就是说这圣人之道和行圣人之道，省略“道”并不会影响理解，“朝闻夕死”，这更符合古汉语的语气。光“闻”不“死”，是不能行圣人之道的，只能是口头玩意，而历史上的腐儒们，最大的弊病就是光“闻”不“死”，这“死”，是“固守”、是“承担”，而要“固守”、“承担”，就必须“死心塌地”、“痴心不改”，偷心不死，是不可能行圣人之道的。

“朝闻道夕死，可矣”，君子从“闻其道”开始，无论任何地方，无论条件恶劣还是优越，甚至出生入死，都要不断地“固守”，“承担”“圣人之道”之行直到最终成就“不愠的世界”而不退转，只有这样，才可以行“圣人之道”呀。

## 3. 子在川上曰：逝者如斯夫，不舍昼夜。

“闻圣人之道”，“朝闻道夕死，可矣”地“承担”，就要开始“见、学、行”“圣人之道”。对于这个“承担”的开始，“子在川上”发出了“逝者如斯夫，不舍昼夜”的感慨。其他语录，都是简单的“子曰”，为什么这里偏偏多了“在川上”？

“川”，不是一般的河流，而是指河的源头，这里更指代“承担”“见、学、行”“圣人之道”的开始。“闻圣人之道”，就是“见、学、行”“圣人之道”的开始、源头，因此才有“逝者如斯夫！不舍昼夜。”，这“在川上”，无论是否实指孔子真的站在某条河的源头，都更重要地指向“承担”“见、学、行”“圣人之道”的开始。这里，既是孔子的自我感慨，也是对要开始“见、学、行”“圣人之道”的君子的忠告。

所有的人，都把“逝者”这句解释成“消逝的一切都如同这河水一样不分昼夜”之类的玩意。但这种解释是完全错误的。“逝”是“誓”的通假字，“逝者”就是“誓者”，就是决心开始“见、学、行”“圣人之道”的君子。 君子“见、学、行”“圣人之道”的开始，就如同每条河的源头，最终都有一个共同的目标，就像大河东流归于大海，这个目标就是成就“圣人之道”，成就一个“不愠的世界”。“誓者”，决心行圣人之道的君子，就像河流一样，从“闻其道”的源头开始，后浪推前浪，生生不息、前赴后继。“昼夜”，就是“朝闻道夕死，可矣”中的“朝夕”，也必须如同其中对“朝、夕”的解释，要从“天地人”三方面来理解。“舍”，去声，“止息”的意思；“不舍”，不止息，也就是“不退转”的意思。

这章的难点就在这个“逝”对“誓”的通假上，其实这种用法并不是孤例，《诗经》里就有“逝将去女，适彼乐土”，其中“逝”就是“誓”的通假。以前的人解释《论语》，都是一章章分裂开来，所以被“川”字一迷惑，当然就会把“逝”解释成“流逝”之类的意思。但只要真正理解《论语》的精神，就明白，这话是和儒家强调的阳刚精神相一致的，和“易经”里的“天行健，君子以自强不息”，“大学”里的“苟日新，日日新，又日新”，都是一脉相承的。但细辩之下，“天行健，君子以自强不息”只得个“天与其时”，“苟日新，日日新，又日新”只得个“与天其时”，都不如“逝者如斯夫，不舍昼夜”。“逝者如斯夫，不舍昼夜”就是“与天其时而天与其时”、“与地其利而地与其利”、“与人其和而人与其和”，这里的“逝者”就是立志行“圣人之道”的君子，最终要成就真正的“人和”，只有这样，才能真明白“逝者如斯夫，不舍昼夜”。

“子在川上曰：逝者如斯夫，不舍昼夜。”，孔子在河流的源头，抚今追昔、满怀感慨，自告且忠告所有决心开始“见、学、行”“圣人之道”的君子：“立志“见、学、行”“圣人之道”的君子，就要像这江水一样，从“闻其道”的源头开始，后浪推前浪，生生不息、前赴后继，无论任何时候、任何地方，无论条件恶劣还是优越，甚至出生入死，都要不断地“固守”，“承担”“圣人之道”之行直到最终成就“不愠的世界”而不退转。”这里必须明确，这话既是孔子自己的感慨，也是对所有有志于圣人之道的人的忠告和勉励。这种感慨并不是孔子一人所独有，所谓同声同气，有此心，必有此感。这，超越时间，所谓万古同一情怀矣。本ID所写是否正解，无此万古同一情怀之章句蠹虫，没资格讨论！同样，也需先有此情怀，方可言《论语》、孔子矣。

## 4. 子曰：人能弘道，非道弘人。

这句话和前面的有点不同，字面意思很简单。“弘”，“使~光大”。“人能弘道，非道弘人”，“人能使道光大，而不是道能使人光大。”然而，字面简单的，往往理解起来更复杂。这个简单的句子，却厘定着《论语》、儒家对“人”与“道”关系的基本看法。

有一个很坏的传统，总把“道”往虚无缥缈中寻去。这种把戏，千百年来一直愚弄着偷心不死之人。而对于《论语》、对于儒家，这种把戏是无效的。儒家从来都是现世的，无论这“道”是何道，最终都要落实到“人的承担”上。在《论语》里，“道”只指“圣人之道”，只和现世有关，只和现世的“人不愠”有关。任何往虚无缥缈处瞎推的把戏，都只能是把戏。

还有一种更坏的传统，就是以“道”压“人”，把“道”描绘成一个虚无缥缈的远景，然后让现实的“人”为这个虚无缥缈的远景垫背。这，比起“一将功成万骨枯”还要残忍。后者，至少还有一个“一将功成”让大家唾骂。而当把“道”有意无意地装扮成虚无缥缈的远景时，则连对它的唾骂都变成此等造假戏剧中的荒谬情节。这种荒谬的悲剧，在历史上不断重复。

但比起下面这种，以上两种就不算什么了。历史上永远不缺这种人，他们以“得道者”、“行道者”自居，以“道”的代表自居，他们成了人间的上帝，他们制定人间的法律，一切违背他们的就成了大逆不道。历史上最不缺的就是这种人，却往往是个个道貌岸然，一副拯民于水火的姿态，私下却干尽见不得“人”的事。这种“挟私道以令诸人”的人，难道还少见？而“道”，是大道，是公道，不是哪个人、哪群人的小道、私道。只有“人”，才能使“道”得以光大，离开了“人”，并没有一个“道”可以让“人”得以光大。

“道”的彰显，是“人”现世存在的当下涌现，离开当下、现世，只能是虚无缥缈的远景，与《论语》、儒家的“圣人之道”毫无瓜葛。这里，我们更清楚地看到前面曾提到的《论语》、儒家和西学中的柏拉图、耶教、科学主义等的根本分歧。对于后者来说，是“道能弘人”，在柏拉图那里“道”是理智的光芒，在耶教那里“道”是上帝，在科学主义那里“道”是科学；但对于《论语》、儒家来说，是“人能弘道”，理智的光辉、上帝、科学都离不开“人”，没有“人”，这些所谓的“道”都没有任何的意义。正由于《论语》、儒家的这种精神，使得西式的宗教在中国从来都没能得到光大。

有人可能要问，这样是否意味着《论语》、儒家否认客观的规律？其实有此一问的前提，就是一种西学的思维语境。对于《论语》、儒家来说，客观规律的有无并不是一个首要的前提，无论有无，都是“人”必须承担的。在“天地人”模式中，客观规律属于“天地”范畴，构成“人”展现的舞台。打个比方，对于“人”这个演员来说，无论舞台如何，演好戏是最重要的，而好的演员，无论怎样的舞台，都会充分利用构成这个舞台的当下、现实的条件。《论语》、儒家并不否认客观规律的存在，但这只构成“人”活动的舞台，而不构成“人”的表演、显现。对于《论语》、儒家来说，“道”只特指现世、当下的“圣人之道”，并不是一般所理解的本体、本原、规律之类的东西，这一点，对于已经受西学影响太大的国人来说，是需要反复强调的。

有人把儒家归于西学“人本”主义的范式，完全是无的放失。儒家的“人”，是站在“天地人”的宇宙结构下说的，并不需要一个“人本”主义来“本”人。“人本”一旦被主义，就会失去一切主意，变成意识形态的闹剧。而用西学的“结构”范式来考察儒家的“天地人”结构中的“人”，同样是无的放失。“人”在“天地人”结构中并不是某种构成因素，而是展现，“天地”只是“人”展现的舞台，而这一切都是当下、现世的。这里的“人”有两种含义，一种是正“闻、见、学、行”“圣人之道”的君子，一种暂时不能“闻、见、学、行”“圣人之道”的“人不知”的人。这两种人构成了所有的人，用现代术语就是包括了构成社会的所有人。

因此，根据“人”的两种不同含义，“人能弘道，非道弘人”，必须至少从两个方面来理解：其一，对于正“闻、见、学、行”“圣人之道”的君子来说，他们的“闻、见、学、行”能使得“圣人之道”得到彰显、涌现，但并不是他们“闻、见、学、行”“圣人之道”就使得自己得以高人一等、凌驾于别人之上，成为所谓的精英，甚至打着“闻、见、学、行”“圣人之道”的旗号行其私道；其二，对于暂时不能“闻、见、学、行”“圣人之道”的“人不知”的人，“圣人之道”的彰显、涌现并不能离开他们，把“人不知”的世界改造成“人不愠”的世界，不能离开“人不知”的人，并不能打着一个抽象的、虚无飘渺的“圣人之道”去利用“人不知”的人，把他们当成就一个抽象的、虚无飘渺的“圣人之道”的垫背。

“人能弘道，非道弘人”，归根结底只有一点，就是“道”不是目的，只有“人”才是目的，只有现实中的“人”才是目的，一切以打着虚无飘渺的所谓“道”为目的，以现实的“人”为手段的所谓“闻、见、学、行”“圣人之道”，都是《论语》背道而驰的。 对于《论语》、孔子、儒家来说，“人”是开始，也是目的，而“道”是手段，即使是“圣人之道”，也只是把“人不知”世界改造成“人不愠”世界的手段，无论从开始到成就，都离不开“人”。“道”是“人”行的，而非“人”是“道”行的；“道”是“人”光大的，而非“人”是“道”光大的。只有这样理解，才能算初步明白“人能弘道，非道弘人”。

而人被无所本地抛掷在此世间，就是人的当下，就是人的承担，这构成了人的无所位次，而人“无所位而生其本、无所本而生其位”，才有这人类社会的存在发展，才有个体的存在发展，这里没有所谓的悲剧、喜剧、正剧，没有人，无所谓天地，也无所谓人展现的舞台，又何来悲剧、喜剧、正剧？悲剧、喜剧、正剧都不过是人生“无所位而生其本、无所本而生其位”而来的位次展现，这里所谓理智、情感的预设，没有人，又何来理智、情感？这里只有承担，人的承担，首先是对“人”的承担，由此承担，才有所谓乐、悲、情、智、观、欲等等葛藤，只有这样，才算进一步理解何谓“人能弘道，非道弘人”。

## 5. 子曰：攻乎异端，斯害也己。

理解这句话的关键在“攻”和“异端”。有把“攻”当成“专治”的，更有甚者，把“异端”解释成“不走中道”的，这些，都是胡解。之所以这样，主要是对《论语》没有一个整体的把握，割裂去解释，真是“斯害也己。”
朱熹，宋朝大儒，他在《论语集注》里就把“攻”当成“专治”。但“攻”的古字，声“工”，从“攴”。金文“攴”，手持器械打击，相应，“攻”的本义是“攻打”。而“攻”的“专治”等意思，是相当后期才出现的，是从“攻打”引申为“加工”再引申为“研究”才出现的。而且，“攻”一般也不解释为“专治”，也就是“研究”而已，而不是“专门研究”。而“研究异端”，甚至是“专门研究异端”，又有什么问题？所谓一事不明，儒者之耻，异端不研究，怎么知道是异端？连异端都不知道，怎么正之同之？所以，这种解释是不对的。“攻”，就是本义“攻击、攻打”的意思。

“异端”，有人解释成“不走中道、钻牛角尖、标新立异”之类的，这种解释确实够“不走中道、钻牛角尖、标新立异”了。如果说“端”是“头、边”等意思，那“异”于“端”，那不正好是“中”？这一点上，朱熹是对的，他解释的“异端”就是通常所理解的“异端”，就是“别为一端”、“非圣人之道”的意思。但由于他把“攻”解释为“专治”，“攻乎异端”就成了“专治非圣人之道”。

“攻乎异端”，就是“攻打、攻击非圣人之道的别为一端者”。“斯害也已”，“这是灾害、损害呀”。是对什么的损害、灾害？是对行“圣人之道”的损害、灾害。在上一章“人能弘道，非道弘人”的解释中，已经说过：“对于暂时不能“闻、见、学、行”“圣人之道”的“人不知”的人，“圣人之道”的彰显、涌现并不能离开他们，把“人不知”的世界改造成“人不愠”的世界，不能离开“人不知”的人。”而“人不知”的人，就是“非圣人之道的别为一端者”，对这种人，不能采取“攻打、攻击”的手段，不能通过“攻打、攻击”的手段把他们消灭，否则就违背了同出于《论语》的“和而不同”的儒家精神。

对于行“圣人之道”的君子，“异端”只不过是“别为一端行非圣人之道”的“不知”者，如果没有这种人，“圣人之道”之行就成了无源之水。“不知”，如同米；“不愠”，如同饭；“圣人之道”，如同水、火；行“圣人之道”，如同利用水、火把米煮成“饭”；行“圣人之道”的君子，当然就是那煮饭的人。而没有了米，没有了“不知”，没有了“不知”者，没有了“不知”的世界，巧妇难为无米之炊，又如何行“圣人之道”呢？对于“异端”，对于“别为一端行非圣人之道”的“不知”者，行“圣人之道”的君子不是要攻打他们、消灭他们，而是要如把“米”煮成“饭”般把他们从“不知”者变成“不愠”者，变成行“圣人之道”的君子，把“不知”的世界变成“不愠”的世界，只有这样，才算是真行“圣人之道”。

## 6. 子曰：道，不同、不相为谋。

这句话，《论语》成书以来，其断句都是“道不同，不相为谋”，解释成“善恶邪正之间不能合作共谋、走着不同道路的人不能在一起谋划。比喻意见或志趣不同的人就无法共事。”等等，把“闻、见、学、行”“圣人之道”的君子当成一个精英小团体了，把“圣人之道”当成了小道、私道，这是和《论语》、儒家“和而不同”的精神背道而驰的。试想，如果“道不同”就“不相为谋”，那何谓“和而不同”？难道“和而不同”就是在某个叫行“圣人之道”的君子组成的精英小团体里玩的一场无聊把戏？

正确的断句应该是“道，不同、不相为谋。”通常的理解之所以出问题，关键是把“相”字当平声，当副词了，而这只是“相”的后生义。“相”，去声，本义是“观察”，引申为“根据外貌判断人的命运”，然后就有了“选择”的意思。这里的“相”就是“选择”的意思，“不相”，就是“不选择”。 “谋”，就是“征求解决疑难的意见或办法”，引申为“谋划、商量办法”等，《论语》后面还有所谓“谋道”、“谋食”的说法，和这里的“谋”是一致的。

道，圣人之道，就如同大河，大河是不会去“选择”的、也不会去强迫“一致”，是“不相”、“不同”的。 “圣人之道”之“谋”，就是“不同”、“不相”。“不同”，就是“异”，就像上一章“攻乎异端，斯害也己”所说，对“异”不能攻击，不能去谋求消灭“异”，否则就不能“不同”，就和“圣人之道”相违了；“不相”，就是“不以相而相之”，所有的选择都会有假设的标准，也就是以“相”相之，最常见的以“相”相之就是所谓的“以貌取人”，延伸下去，根据思想、观点、意识形态、经济水平等等，都是以“相”相之，都不是“不相”，是和“圣人之道”相违的。

“不同”和“不相”是密切联系的，“不同”是“不相”的实现，“不相”是“不同”的前提。 只有“不相”，才可能“不同”，否则，前提就是“相”，就是以“相”相之，那么怎么可能有“不同”？其结果只能是某种抽象标准、某种统一模版克隆出来的玩意。而只有终于能达到“不同”，这“不相”才有意义，才能实现，否则这“不相”只是挂羊头卖狗肉，成了一句口号。“圣人之道”，归根结底是以“不同”为基础的，只有“不同”，最终才能实现“大同”。“大同”的关键不是“同”，而是“大”，包罗万有，如“天地”般，而不是让花只有一种颜色、鸟只有一种叫声。真正的“大同”，不是“同而大同”，是“不同而大同”，要“不同”，首先就要成就其“大”。无其“大”，就无其“不同”。无其“不同”，就无其“大同”。

除了《论语》总纲的那三个“不亦”，“道，不同、不相为谋。”这条，是《论语》中极为重要的一章，在后面的语录中，对本章的意义多有阐发。例如，对于“不同”，有“君子和而不同”的说法；对于“不相”，有“有教无类”的说法。但后面这些，都只是本章思想在某些具体方面的具体化表述，都是从属于本章的。而本章的重要在于，它确立了行“圣人之道”的君子谋道的最高原则：不同、不相。必须注意的是，“不相”，不是指个体对自己的行为、思想不加选择，而是指对不同个体、团体的行为，不能用一种权威、上帝等独断的方式来以“相”相之，这一点是必须明确的。

## 7. 子曰：有教无类。

“无类”，就是“不相”，这一章，就是君子谋“圣人之道”所必须坚持的“不相”原则在上层建筑领域的一个具体化表述。这里的关键在“教”。“教”，不是平声，而是去声，在古代具有如下含义：教育、政令、法令、政教、教令、宗旨、学说或学派、宗教等。用现代术语，这个“教”包括了整个上层建筑领域。“有教无类”，不只是通常所理解的只是从教育的角度讲，而是指行“圣人之道”，在上层建筑领域、当然也包括一般所理解的教育，但按现代的术语，还包括法律、舆论、行政、宗教、学术、艺术等等一切的上层建筑领域，相应地就要行“不相”之谋。只有这样理解，才算真明白何谓“有教无类”。

## 8. 子曰：士志於道，而耻恶衣恶食者，未足与议也！

“耻恶衣恶食者”，就是“相”，当然就“未足与议也！”不过这里有一个问题，就是“耻恶衣恶食者”究竟指谁？朱熹《论语集注》里，就把“志於道”之士和“耻恶衣恶食者”的人当成同一个人了。如果真这样解释，那这个“士”字就没必要了，完全可以变成“志於道而耻恶衣恶食者，未足与议也！”。正确的解释应该是：志於道之士“耻”恶衣恶食者，这个“恶衣恶食者”主要是指别人，就是“恶衣恶食”的人，当然也可以指“志於道之士”自己，因为如果他自己就是“恶衣恶食”的人，他自己也看自己不顺眼，也“耻”之，也是可以的。

这样，这句话的意思就很清楚了，如果一个人，立志要行“圣人之道”，却把人分为“好衣好食”、“恶衣恶食”两类人，也就是以贫富划分人，而选择以“恶衣恶食”也就是穷人为耻，远离他们，那这种人谈论的“圣人之道”只是羊头狗肉的勾当。为什么？因为他不能“不相”。

## 9. 子曰：贤哉，回也！一箪食，一瓢饮，在陋巷，人不堪其忧，回也不改其乐。贤哉，回也！

本章是紧接着上一章的意思来的，“一箪食，一瓢饮，在陋巷”，这是典型的“恶衣恶食”了。“人不堪其忧”，这里的“人”就是“人不知”的人，就是不能行“圣人之道”的人，他们对这种情况不能忍受，但“回”，颜回，孔子最出名的学生，也是孔子心目中立志行“圣人之道”的一个典型，他“不改其乐”，孔子因此给“贤哉，回也！”的赞誉，而且是一句话前后两次。为什么？因此颜回能“不相”，是真立志行“圣人之道”。

必须强调的是，颜回这个“安贫乐道”的典型，并不是故意去“贫”，并不是故意要“恶衣恶食”，也不是如某些宗教所教唆的故意去苦行，这些都是严重地“相”了，这些都是和君子谋“圣人之道”所必须坚持的“不相”原则背道而驰的。

## 10. 子曰：贫而无怨难；富而无骄易。

上面几章都说到面对“贫富”的“不相”问题，不过都是从“安贫”而“乐道”这个角度说的。但并不是说贫穷就是好的，富就是不好的。“贫富”都是“相”，对于行“圣人之道”的君子来说，对于“贫富”只存在一个如何面对的问题，而不存在好和不好的问题。“贫”和“富”，都不影响行“圣人之道”，“圣人之道”是大道，不是某类人的专利，无论穷人还是富人，一律平等，没有哪类人有优先权。 “贫”和“富”，在任何现实社会中都会存在的，而且关系到每一个人，特别在财富分配不公的社会，这问题就更加突出。但这里相应的理解，不能光局限在财富上，例如学识上也有“贫富”问题，权力、权利分配上同样有类似的问题。任何一个现实的人构成的现实中的社会，都不可能在所有方面绝对的平等，只要不平等，必然面临着“贫富”问题，无论是在财富、学识，还是权力、权利等方面，这个问题都是无可逃避的。

但这一章，自古以来都把其中的“难”当成平声，相应的断句其实就成了“贫而无怨，难；富而无骄，易。”例如，朱熹等人就是这样把“难”当成“难易”的“难”了，这句话的意思就成了“贫穷而不怨恨是困难的，富贵而不骄横是容易的。”而如果这是人之常情，那这话就成了废话，但事实上，这样的解释连废话都算不上，只能是瞎话。自古以来的现实往往是穷人经常乐呵呵，富人却骄横无理，要把穷人赶尽杀绝。这章，自古以来的断句、解释都是错误的。

正确的断句应该是“贫而无怨难；富而无骄易。”这里的关键在于“难”，不是平声，而“易”也不是“容易”的意思。不过还是先从“怨”说起，程度浅的“埋怨”、程度深的“怨恨”，被“怨”的就成了“仇人”了。这个“怨”，在古代就包含了“埋怨、怨恨、仇人”等意思。而因“怨”就会生“难”。何谓“难”？“难”，去声，是“敌对、造反、灾难”的意思。因“怨”而有“仇”而“敌对”甚至“造反”，这不是“灾难”是什么？

“骄”，本义是“健壮”的意思。富人，自以为“健壮”，因此“骄傲”进而“傲慢”甚至“骄横”最后达到“强烈”的程度。 这个“骄”，在古代就包含了“健壮、骄傲、傲慢、骄横、强烈”等意思。“易”，不是“容易”的意思，其本义是“赐给”的意思。富人，自以为自己的“富”是上天“赐给”的或者是自己的天赋、努力“交换”来的，因而产生“轻视、怠慢”，最终对立在社会上“蔓延”。“赐给、交换、轻视、怠慢、蔓延”，都包含在“易”里。

君子行“圣人之道”，就是要把“人不知”的世界变成“人不愠”的世界。而“人不愠”的前提是“人不相”，在具体的社会存在中，包括财富、学识、权力、权利等方面的广义“贫富”，是社会中最大的“相”。而这个贫富之“相”在任何“人不知”的社会中，都体现为“贫而怨难；富而骄易。”君子行“圣人之道”，把“人不知”的世界变成“人不愠”的世界，首要面对的就是如何把这个“贫富”之“相”“不相”之，要让“贫而无怨难；富而无骄易。”这，就是面对“贫富”的“不相”之谋。

要让“贫而无怨难；富而无骄易。”不是让一个权威、教主等发一个倡议或来一段布道就可以完成的，更不是用强制或诱惑的手段把人改造成具有“贫而无怨难、富而无骄易。”的思想的新人来掩盖现实无法掩盖的“贫富”之“相”。而是在“贫富”存在的现实中，用各种现实的经济、政治、法律、文化等手段来实现“贫而无怨难、富而无骄易。”的“不相”。

对于《论语》、对于儒家来说，“不相”是“人不知”到“人不愠”的中间环节也是必经之路。“不相”是“相而不相”，不以“相”相之。首先不能否认“相”的存在，正因为有“相”的存在，才需要“不相”。例如，对于“贫富”之相来说，其存在是客观的，否认这种存在只能是掩耳盗铃、睁眼说瞎话，这不是“不相”，而是严重地“相”了。真正的“不相”，就是直面这“贫富”之相的存在，用在社会经济、政治、法律、文化等方面，不以“贫富”之相相之，进而对“贫富”之相“不相”之。

何谓社会经济、政治、法律、文化上对“贫富”的“不相”？就是采取公平、一视同仁之谋，“贫”或“富”都不是偏袒的理由。而“贫”或“富”之间也要“不相”，也要相互平等视之。对“为富不仁”的就要坚决打击，因为“为富不仁”者以“富”为相，所以就要对之“不相”，将其“富”者之相给去了；对“贫而自贱”者要“富之贵之”，因为“贫而自贱”者以“贫”为相，所以就要对之“不相”，将其“贫”者之相给去了；对“挟贫而贼”的坚决打击，因为“挟贫而贼”者以“贫”为相，所以就要对之“不相”，将其“贫”者之相给去了。

必须再次说明的，这里的“贫富”，不单单指财富上的，例如权力上的“贫富”，就有所谓的“官民”之别，政治地位的“贫富”就有所谓统治阶级与被统治阶级之分。必须在广义的“贫富”上最终成就“贫而无怨难；富而无骄易。”的“不相”，才能真正地“不相”。否则只能是“城头变换大王旗”，换汤不换药而矣。但这个问题涉及面太广，《论语》中有大量的章节涉及这个问题，将陆续展开讨论。

## 11. 子贡曰：“贫而无谄，富而无骄，何如？”子曰：“可也；未若贫而乐，富而好礼者也。”

上一章说明了必须通过对“贫富”的“不相”，达到“贫而无怨难；富而无骄易。”这样一个“人不相”的社会。所谓“人不相”，就是“人不知”到“人不愠”的中间环节和必经过程，就是社会中各种阶级、阶层等“相”都能平等地存在，不会出现某种类型的“相”以其“相”为相，从而一“相”独大，凌驾于其他各“相”之上。一旦出现一“相”独大，以“相”为相的，就要对之“不相”，回复到“人不相”的众相平等。而只有“不相”，才能“不同”；只有能同时容纳各种的“不同”，才能成就其“大”，才能有所谓的“大同”。但这种“人不相”的社会只是一个中间环节，行“圣人之道”，最终要实现的是“人不愠”的大同。正因为这样，所以接着就有了这一章。子贡，孔子的学生，以为“人不相”就是最高的境界，所以问到：“贫而无谄，富而无骄，何如？”这个“贫而无谄，富而无骄”就是上一章所说的“贫而无怨难；富而无骄易。”也就是“人不相”的社会状态。但孔子给予的回答是：“可也；未若贫而乐，富而好礼者也。”也就是说，这种“贫而无谄，富而无骄”的“人不相”社会是可以的，已经不错了，但还不是最理想的状态，对于儒家来说，最理想的社会就是“贫而乐，富而好礼”的“人不愠”的大同社会。

由于受通常观念的干扰，一般人都习惯于只在财富的角度使用“贫富”，但在上一章的解释里已经反复强调，《论语》里的“贫富”不单单指财富方面，只要人与人之间能产生差异的地方，无论是学识、智力、财富，还是政治地位、社会角色等等，都会出现“贫富”。而“人不愠”的大同社会并不是要消灭一切差异的绝对平均的社会，因为这种可能性根本不存在。人与人的差异，是必然存在的，探讨在一切方面绝对平均的社会，只能是乌托邦，毫无意义。而儒家最高明的地方就在于，根本不去假设这种毫无意义的社会存在，而是在承认人与人差异的必然性前提下，探讨可能出现的理想社会，其结论就是“人不愠”的大同社会。

用“贫富”对社会形态进行分类，就可以得出三种基本的社会形态：“贫而谄，富而骄”、“贫而无谄，富而无骄”、“贫而乐，富而好礼”，分别对应着“人不知”、“人不相”、“人不愠”的社会。而行“圣人之道”，就是要把“人不知”的社会，通过“人不相”的中间环节，最终达到“人不愠”的大同社会。《论语》对社会形态的总体把握，是十分清楚的，只是自古以来，腐儒被劣识所困，而无知之辈被妖人蛊惑，胡诌什么“打倒孔家店”的昏话。这种人，连孔子、《论语》、儒家究竟说了些什么都没搞明白，就唾天以自污，岂能不千古遗臭？

“谄”就是“奉承”，不光指语言，还包括一切行为。为什么要“奉承”？就因为是弱者而有所求。在“贫而谄，富而骄”的“人不知”社会，这种“贫而谄”无所不在。例如，下级和上级，打工和老板，鸭子和嫖鸭子的，（男）研究生和（女）教授，FANS对偶像，小国对大国等等。至于“富而骄”就更不用说了，“骄”，因强大而骄横。像美国，就是国家“富而骄”的典型；至于人的例子，随处可见。“贫而谄”不得，最终就会“贫而怨难”，因“怨”有“仇”而“敌对”甚至“造反”，但“造反”成功的马上又成为“富而骄”，又有新的“贫而谄”，结果不断循环，都逃不出这个“贫而谄，富而骄”的“人不知”社会。

《论语》、儒家看穿了这个“贫而谄，富而骄”的恶性循环，知道在这里打圈圈是没用的，而要打破这个恶性循环的办法，只有通过“人不相”而达到“人不愠”，最终摆脱“贫而谄，富而骄”的“人不知”的恶性循环。要实现这个打破，首先就要实现“贫而无谄，富而无骄”的“人不相”，为此，就必须要实现对“贫富”之相的“不相”，达到“人不相”。为什么实现对“贫富”之相的“不相”，就能实现“人不相”？是因为只要存在人与人的地方，就必然会出现各种方面的“贫富”之相，消灭这种“贫富”之相、将之抹平是不可能的，唯一办法就是使之“不相”，使得各种“贫富”之相能平等地存在，实现其“不同”，容纳各种“不同”而成其大，最终成就其“大同”。儒家、《论语》认为，这种“大同社会”的实现是当下的，是可以现世实现的，这种看法是由儒家的入世以及现世精神所决定的。

“贫而乐，富而好礼”，乐，yue，歌舞升平，连“贫”者弱者都能歌舞升平，而只有“不愠”才可能歌舞升平，连“贫”者都能“不愠”，这才是真正的“人不愠”，这才是“大同”。这里，“礼乐”并举，并不是说“礼”归富者，“乐”归贫者，而是“互文”的修辞手法，无论贫富，都“乐”且好“礼”。为什么“礼乐”并举？“乐”是指个体的，“礼”是人与人之间的，人人歌舞升平，相互又以礼相待，这才可能“人不愠”。另外，人人歌舞升平，还指代人人有好的修养，都是具有高度修养的君子。所谓“修身、齐家、平天下”，其人身不修，又何来“人不愠”的大同“天下平”？

## 12. 子曰：齐一变，至於鲁；鲁一变，至於道。

这一章很奇怪，仿佛毫无来由。“齐”和“鲁”，俩诸侯国，怎么“齐一变，至於鲁；鲁一变，至於道。”地折腾两遍就和“圣人之道”搭上界了？其实，这一章是顺着上一章从“人不知”经“人不相”达“人不愠”的大道而来的。
说起“齐”，都知道是孔子时代的强国，齐桓公，春秋五霸之首，其以“霸术”而行终成“霸业”。“霸术”而“霸业”，是以人之“恶”为前提的：对内以法制民、对外以武制敌，强调的是以暴制暴、以力制力、以恶制恶。这种类型的国家，自古以来从来不缺，是“人不知”所必然导致的社会结构。这种类型的国家，在当代依然被视为最先进的、必须效仿的对象。而在儒家、《论语》看来，这种“齐式”国家，不过是“人不知”的衍生物。
“人不知”的世界，人之恶是一切行为的前提，在当代经济社会里，扒掉一切伪装，唯一的动力就是人之私欲，利益是经济社会里最高的准则，法律是为保障各种利益而存在的。但在儒家看来，恶只能引发恶，制恶以法只能是权宜之法，诱人以利只能生人以怨，只能使得“贫而谄，富而骄”的“人不知”状态愈发严重直至不可救药，然后玉石俱焚再死灰复燃地重新开始“人不知”所惯有的恶性循环。

为转化这种“人不知”的“贫而谄，富而骄”，要打破“贫而谄，富而骄”的恶性循环，就有了“齐一变，至於鲁”，企图通过改变以恶为前提的“霸术”而“霸业”的“齐式”国家模式，一变为“鲁式”国家模式。何谓“鲁式”国家？“鲁国”，在孔子时代是打着以“仁”以“德”治国的典型，号称传承着被孔子当成典范的周公之仁德。以“仁”以“德”治国，强调善的力量，对于一个习惯于以恶为前提的“人不知”世界是不可想象的，相比“齐式”国家模式，“鲁式”国家模式的出现是一种进步，所以才有“齐一变，至於鲁”的说法。

在“人不知”的世界，以“善”为善，标榜其“善”，往往使得所谓的“善”成为伪善，成为另一种“恶”。 当时的“鲁国”，虽然打着“仁”“德”的旗号，但在孔子看来，这只能是假“仁”假“德”，不是儒家、《论语》所说的“仁”“德”。而当这种假“仁”假“德”成为一种新的意识形态，以此形成一个新的阶层后，“贫而谄，富而骄”的局面依然会出现。因此，这种“鲁式”国家模式并不能打破“贫而谄，富而骄”的恶性循环，这种“鲁式”国家模式依然只是“人不知”世界的一个变种。

要转化这种“人不知”的“贫而谄，富而骄”，要打破“贫而谄，富而骄”的恶性循环，靠“齐式”、“鲁式”招数都是没用的，必须要“鲁一变，至於道。”何谓“道”？就是从“人不知”经“人不相”达“人不愠”，最终成就圣人之道。 “人不知”的世界，以“善”不生为相，因此要对之“不相”，去掉“善”不生之相，从而扬其善；“人不知”的世界，以“恶”不灭为相，因此要对之“不相”，去掉“恶”不灭之相，从而惩其恶。在“人不知”的世界，扬其善、惩其恶，就是“不相”其“贫富”诸相。只有这样，才可能达到“人不相”的“贫而无谄，富而无骄”。要成就“人不相”的“贫而无谄，富而无骄”，不能如“齐式”模式那样光立其恶而惩其恶，也不能如“鲁式”模式那样光立其善而扬其善，必须善恶并举、文武并重，所谓“一阴一阳、文武之道”，这是儒家的一贯立场。只有这样，才能扬其善、惩其恶，“不相”其“贫富”诸相，打破得“贫而谄，富而骄”的恶性循环，达到“人不相”的“贫而无谄，富而无骄”，进而实现“贫而乐，富而好礼”的、“人不愠”的大同世界。由此可见，本章仿佛毫无头绪的话，其实是和前几章一脉相承的。

《论语》成书以来，解者无数，皆不得要领，就是因为其人都没能把握这个“人不知”、“人不相”、“人不愠”的关系，当然也就只能对《论语》肢解、胡解了。儒家走的是刚猛的路子，不是老好人，不能乡愿，这一点是任何一个真想了解《论语》的人必须时刻把握的。

## 13. 子曰：放于利而行，多怨。

这一章，七个字，没一个难字，但千古以来，都是错解。所有的解释，基本都按朱熹《论语集注》而来。朱熹认为：“放，依也。”按这解释，“放”就发上声了。而后来所有的解释基本都成了“如果一切行事以求利为目标，就容易招致他人的怨恨（或自己心中容易产生怨恨）”，最多就把“放”解释为“放纵”，基本意思还是一样的，就是把“利”当成恶的，或者是引发“怨”的事情。

而实际上，如果“放”真的就是“依”，那为什么不直接用“依”？“依于利而行，多怨。”，这样不更清楚？后世论诗有所谓诗眼，好诗的诗眼是不能改的，就像大家熟悉的“春风又绿江南岸”，这“绿”字就没法改，在汉语中，就再也找不到一个字可以替代的。 而《论语》时代虽无诗眼一说，但《论语》，中文第一书，里面的用字有着中文第一书应有的准确性与不可更改性。试想，那沐猴而冠的吕不韦纠集些三教九流之人弄了本杂说《吕氏春秋》都敢吹嘘“一字千金”，改一字都不行，又何况这中文第一书的《论语》呢？

“放”，应该发去声，包含“放弃、放纵”的意思。 可能所有人都要问，“放弃”和“放纵”，这两个意思不刚好反了？在这句里，“放弃”意味着不按“利”行事。既然不按“利”行事，又何来放纵？而“放纵”意味着惟利是图、放纵而行。既然是惟利是图，就谈不上“放弃”了。“放弃”的不能“放纵”，“放纵”的就不“放弃”，放弃利益和放纵利益，两个极端，怎么能同时出现在“放”的解释里？其实，正是这“放”字包含了这表面上相反的两个意思，才使得这“放”字成为诗眼而不可更改。《论语》，中文第一书，不仅仅道理上，连用字这么小的细节上，也可以傲视千古。这个“放”字，绝对算得上“一字而有神”。

“放于利而行，多怨。”就是无论放弃还是放纵“利”而行，都会产生“多怨”的结果。 其实，现在的人对于这句话，肯定会更容易理解。计划经济年代，都是放弃“利”而行，结果是“多怨”；而市场经济年代，放纵“利”而行，结果还是“多怨”。这句话的合理与高明之处，从这两个时代的对比中，就不难发现了。更高明的是，这两种相反的情况，用一个“放”字就包含了，这就像伯牙之“高山流水”，唯一可惜的是，千古以来，竟然罕有知音。

对“利”的放纵与放弃都是不对的，这和上一章所说的“齐一变，至於鲁；鲁一变，至於道。”的精神是一致的。“齐”模式代表的是对“利”的放纵，而“鲁”模式代表的是对“利”的放弃，这都违背了“圣人之道”善恶并举、文武并重，“一阴一阳、文武之道”的基本原则。所以必须要“齐一变，至於鲁；鲁一变，至於道。”最终归于“圣人之道”。“利”不单单指通常理解的“利益”，“利益”是一个后起义，“利”的本义是“锋利”，在“人不知”的社会，“利益”当然是最锋利的东西，其最终结果就是“贫富”之相。但更重要的是，“利”除了表现为静态的利益，也表现为一种动态趋势性，这里，更多体现出其本义“锋利”来了。

就算同在“人不知”的社会里，水平也有高低之分。“人不知”必然有“怨”，但“少怨”总比“多怨”好，用现代术语，就是社会矛盾缓和总比社会矛盾激化要好。 “放于利而行，多怨。”说的就是“人不知”社会的一个总规律，即无论放弃还是放纵“利”而行，都会使得“怨”增加，都会最终使得社会矛盾激化。“利”总是相对的，站在“贫富”之相上，对“富”者“利”的放纵，往往就意味着对“贫”者“利”的放弃，反之亦然。

要实现“贫而无谄，富而无骄”的“人不相”，就绝对不能违背“放于利而行，多怨。”这“人不知”社会的总规律，绝对不能放弃或放纵“利”而行，要充分把握其“利”，所谓用其刃而不被其刃所伤。 只有这样，才可以有资格谈论对“贫富”诸相的“不相”，否则，连“利”之所向都无所把握，又如何能“不相”其最终结果的“贫富”诸相呢？行“圣人之道”的君子，首先要是“知人”，如果自己都还“不知”，又如何去让“人不知”之相“不相”？一事不知，儒者之耻，不尽量用这世界上的知识武装自己，是没资格当儒者的。

## 14. 子曰：好勇疾贫，乱也。人而不仁，疾之已甚，乱也。

这一章是上一章“子曰：放于利而行，多怨。”的延伸。何谓“好勇疾贫”？好于勇而疾于贫也。疾于贫，即“贫者”之相，其“贫”而好于勇，所谓好勇斗狠。“好勇疾贫”，“贫者”，好勇斗狠。何谓“人而不仁，疾之已甚，”“已”，通假“以”，“甚”，“斟”的初文，本义是用勺舀酒等喝，引申为“过分享乐”。“疾”，病、得病、特指传染病，因此引申出“急速”等意思。“之”，指代前面的“人而不仁”，就是不仁之人，特指为富不仁之人。“人而不仁，疾之已甚”，为富不仁之人被“过分享乐”之病急速传染。“乱”，乱相也。“好勇疾贫，乱也。人而不仁，疾之已甚，乱也，”说的是“人不知”社会中同时存在的两种乱相：“贫者”，好勇斗狠；“富者”，为富不仁，被过分享乐之病急速传染，所谓纸醉金迷、醉生梦死。 对这一章最好的、所有人都熟悉的典型例子就是：“十里洋场上海滩”。其实，这种例子简直太多了，是“人不知”社会的通病。

前面反复提到，“贫富”不单单是指财富上的，只要有人参与其中的一切社会现象，都会有其“贫富”之相。 例如某精英团体或个人有某种理想或特长，精英团体或个人外的被诱惑者、FANS们又具有特别狂热的情绪，这时候就是典型的“好勇疾贫，乱也。人而不仁，疾之已甚，乱也。”了。除了那些极端的例子，这种乱相，无论何时何地，都是司空见惯，没有人会觉得陌生，只是太熟悉反而麻木了。举一个日常的例子，且不说报纸、杂志、电视上天天看到的偶像粉丝闹剧，就算在目前的名人博客江湖，名人以名卖名如传染病，而FANS、跟贴骂人的草根们又特别的狂热，如此，也就绘出了“好勇疾贫，乱也。人而不仁，疾之已甚，乱也。”的典型图景。

为什么会这样？明白了上一章“子曰：放于利而行，多怨。”的“人不知”社会总规律，就知道，之所以出现“好勇疾贫，乱也。人而不仁，疾之已甚，乱也。”的乱相，就是因为“放于利而行”。由于“富者”的强势地位，使得对“富”者“利”的放纵成为了“人不知”社会的常态，这就相应意味着对“贫”者“利”的违背，而“利”的诱惑又是客观存在的，在“人不知”的社会，单纯的道德说教是没意义的，在“利”面前，所有的道德说教都苍白无力。这种“利”的“贫富”之相的严重对立，使得“富者”因得其“利”而放纵无度，而“贫者”因不得其“利”而不平。就算是一个懦夫，当“利”的“贫富”之相严重对立形成的落差储备到了足够大势能后，懦夫也会成为“勇夫”的。这样，自然就有了“好勇疾贫，乱也。人而不仁，疾之已甚，乱也。”。这种图景在“人不知”的社会随处可见、无处不在，《论语》早在两千多年前就已总结出来了。

## 15. 子曰：善人为邦百年，亦可以胜残去杀矣。诚哉是言也！

这一章是接着上一章“子曰：好勇疾贫，乱也。人而不仁，疾之已甚，乱也。”来的。“好勇疾贫”和“人而不仁，疾之已甚”的乱相，可不是指一般的乱相。“乱”，在音乐和文学上是指乐曲的最后一章和辞赋的最后一段，引申为最后的乱相，对于国家来说，这种最后的乱相就是亡国之相。那么，怎么才能“不相”这亡国之相而“为邦百年”，让国家长治久安？必须要“善人”和“胜残去杀”。只有这样，才是“诚哉是言也！”，这话才是真实无谬。

“亦可以胜残去杀矣”，“可以”是“可”+“以”，“以”是介词，全句是“以胜残去杀亦可矣”的倒装。“善人为邦百年，亦可以胜残去杀矣。”的意思就是“善人”可“为邦百年”，“胜残去杀”亦可“为邦百年”。“胜残”、“去杀”都是动词+名词的结构，而“善人”也是。这三个词的语法结构是一样的，“残”、“杀”名词化了，而“善”是动词化了。这种词性的活用，在文言文里极为常见。

“胜残”、“去杀”，是两个意思相仿的词并列而成，简单说就是“战胜残暴、制止杀戮”；“善人”，就是“使人善”，“善”就是好的意思。 “亦”，“腋”的本字；“可”，相称；“亦可”，像人的两腋一样一体而相称。“善人”和“胜残去杀”，其并列是一体的，如两腋之于人，双翼之于鸟，钱币的两面之于钱币。“善人”和“胜残去杀”，其实就是上几章所说的对“贫富之相”的“不相”。对“好勇疾贫”和“人而不仁，疾之已甚”乱相的“不相”，也就是对“贫富之相”的“不相”，“善人、胜残去杀”，才可能“为邦百年”，让国家长治久安。

“胜残去杀”，是针对“人而不仁，疾之已甚”，是针对为富不仁的“富者”，包括贼王暴君、贪官污吏、奸商恶霸等等，所谓杀一暴君而救亿万者乃真大仁矣；“善人”，是针对“好勇疾贫”的“贫者”，改善他们的生存条件、扩展他们的生存空间、提高他们的生存能力等等，都可以归之于“善人”之数。但必须强调的是，站在人和社会的整体角度，没有一个人是在任何方面都是“富”者，也没有一个人在任何方面都是“贫”者，但对于现实中的国家来说，经济、社会地位、权力等角度的“贫富”之相才最具有现实力量，这点也是不能忽视的。

孔子、《论语》在两千多年前已经明确提出了让国家长治久安的六字箴言“善人、胜残去杀”，这三组字是相互相成的，不可能光“胜残去杀”而不“善人”，也不可能光“善人”而不“胜残去杀”。对于“胜残去杀”来说，只有“胜残”才能“去杀”，所谓“庆父不死、鲁难未已”，不“胜残”是不可能“去杀”的。

## 16. 子曰：如有王者，必世而后仁。

这里的难点在“世”字上，基本上所有的解释都把“世”解释成“三十年为一世”。大致意思就成了“如果有称王的，一定要经过一世三十年，才能行其仁政。”由此而引申出很多奇谈怪论，例如，必须先法治再德治，先搞经济再搞道德，诸如此类的。这类想法的潜台词就是，民对于王来说都是刁民，必须先折腾折腾，然后再给好果子吃。当然，这好果子是否能真吃到，那是后话。所谓三十年河东、三十河西，谁知道下一世又是什么？反正趁这三十年河东时先把河东给洗劫干净，至少积累经验下一世河西去继续洗劫，至于河东如何又有什么关系呢？这王，真有天大的如意算盘呀。

实际上，这话从上面的“齐一变，至於鲁”而来。上一章说到，国家长治久安的六字箴言“善人、胜残去杀”，而现实中，在“人不知”世界里，这六字箴言又有几人能办到？办不到，就必然是“城头变换大王旗”，中国历史上，这种改朝换代的事情，难道还不司空见惯？这种恶性循环中，有一个规律，就是本章的“如有王者，必世而后仁。”

“世”，世代相传。“王”，王霸之术而成其王，行“齐”式手段得到政权，必定打好世代相传、一世到万世的基础后，才会行所谓“仁”术，这就是“如有王者，必世而后仁。”这里的“仁”并非儒家所认为的“仁”，只是“齐一变，至於鲁”的打着“仁”“德”旗号的“鲁式”之“仁”，与《论语》、孔子毫无关系。

有人可能说，这只是封建社会才有的事情，所谓的民主社会哪里会存在这种事情。这，不过是陋见而已。例如美国，南北战争确立其国体的世代相传、一世到万世后，就开始行所谓的“民主、自由”之“仁”，其模式，早在2000多年前就被《论语》所揭示。“王”，不一定需要有人当皇帝，如资本主义的确立也是一种王，其后到处贩卖的“民主、自由”就是“必世而后仁”了。其实，这种模式不仅仅在政治领域，在学术、经济、宗教等领域，无处不在。甚至在一个小公司，一个小办公室里，这“如有王者，必世而后仁。”难道还少见？

就像儒家对“齐一变，至於鲁”，虽然认为有其进步的一面，但绝不会认同这“鲁”式把戏，对“如有王者，必世而后仁”的假“仁”也是不屑的。当然，就算是假“仁”，也比明目张胆的“残、杀”要好，而假的最终都要破的。“必世而后仁”只能是“人不知”世界恶性循环的一个注脚、一个反复出现的固定低音。而儒家的主旋律是“善人为邦百年，亦可以胜残去杀矣”，是“善人、胜残去杀”让国家长治久安的六字箴言，是善恶并举、文武并重、扬其善、惩其恶、“不相”其“贫富”诸相。

## 17. 子适卫，冉有仆。子曰：“庶矣哉！”冉有曰：“既庶矣，又何加焉？”曰：“富之。”曰：“既富矣，又何加焉？”曰：“教之。”

上面说到了让国家长治久安的六字箴言“善人、胜残去杀”，而这章主要就“善人”展开论述。孔子“述而不作”，其思想都是随机而说，因而更显得活泼生动。“子适卫，冉有仆。”孔子到卫国，其弟子冉有驾车来接，孔子沿途看到卫国市面繁华，一语双关地引出“庶矣哉！”的感叹。该感叹就是《诗经》的“比兴”手法，所谓“不知诗，无以言”，要理解《论语》，对此必须把握。孔子借所见市面的“庶”，“比兴”引出孔子心中的“庶”，这两者只是引发关系，就像“关关雎鸠，在河之洲。”不等于“窈窕淑女，君子好逑。”进而引发出师徒二人两问两答的一段妙文，将如何“善人”这样复杂的大问题论述得尽善尽美，可谓诗意昂然、相得益彰，师徒二人共同写就这千古不磨的一章。

该两问两答的意思很简单，但关键的难点在这三个字“庶、富、教”，所有的解释都是把“庶”当成“人口众多、人丁兴旺”，把“富”当成“增加财富，经济富裕”，把“教”当成“教育、教化以提高素质”之类。之所以有这种理解，都是因为对《论语》、孔子的总体思想没有一个切实的把握。其实，这三字诀说的就是如何“善人”的次第，而“善人”又是国家长治久安的一个重要的方面，所以，这三字诀说的就是如何让国家长治久安的次第问题。而通常的解释是有很大毛病的，例如不能说“富”了才“教”、才搞“教育”，如果真是这样，那“教育兴国”又如何解释？这里，教育不就排在国之“兴”之“富”前？这次第不就出问题了？

“庶”，不单单指“人口众多、人丁兴旺”，关键还指各种人以及社会生存形态的多样性，也就是“不同”。一个地方，就算满大街都是人，但清一色都穿同样的服装、同样的面孔、同样的神态，这样，无论如何也称不上“庶”；人如此，物也一样，所有商店都一个样子，所有报纸、传媒都一个样子，所有的文化都一个样子，这样也不是“庶”。 上面已经反复提到，只有“不相”才能“不同”，只有“不同”才有多样性，才能称得上“庶”。“庶”的前提就是自由，没有自由，就没有多样性，也就没有“庶”。但就像“鲁式”国家鼓吹“仁”，其实只是“假仁”，在鼓吹自由的地方，其实也是谈不上自由的。例如在资本主义社会，所谓的多样性被“资本”的单一性所掩盖，在资本主义社会，本质上是没有多样性的，有的只是“资本”，资本主义社会中人的颜色其实只有一种，就是“资本”。在“权力资本”同一性的社会里，其道理是一样的。

所以，如资本主义社会般的社会里，是谈不上“庶”的。没有“庶”，其“富”也是单面的。只有“庶”了，才可能谈得上“富之”。所以，子曰：“庶矣哉！”后，接着是冉有曰：“既庶矣，又何加焉？”然后才有孔子“富之”的回答，这里的次第是不能乱的。“富”，不单单指“增加财富，经济富裕”。在上面也曾反复强调，“贫富”不能光从财富角度看，社会的任何一个方面，都存在着“贫富”问题，而“富之”，是综合的，包括财富、人的素质等等，都存在“富之”的问题。而“富之”必须在“庶”的基础上，也就是在“不同”、“不相”的总原则下才有可能“富之”，而这“富之”是针对人的所有方面，用一个现代的词语，“富”就是人的全面发展，“富之”就是使人全面发展。只有人的全面发展，才谈得上“富”。但更重要的是，这个“富之”是针对所有的人，如果只针对某一部分的人，那连“不相”都达不到，就根本谈上不“富”，只有先对“贫富”之相“不相”之，才谈得上对所有人的“富之”。否则所谓的“富之”就成了名言把戏，成了“鲁式”“假仁”一样的玩意了。

“教”，必须在“富”的基础上，不同程度的“富”对应着不同程度的“教”。这个“教”，在“有教无类”那一章已经指出，在古代具有“教育、政令、法令、政教、教令、宗旨、学说或学派、宗教”等含义，用现代术语，这个“教”包括了整个上层建筑领域。这个“教”主要不是指通常所说的“教育、教化以提高素质”，这种意思其实已经包含在“富之”里，“富之”当然包括人的素质的提高。其实，“富”主要是针对个体来说的，“富之”最终都要落实到每一个个体的。而每一个个体如何连接成为一个社会的整体，体现为整个上层建筑的结构，也就是“教”。由于上层建筑与经济基础的不可分关系，这个“教”，其实就指代了整个社会结构。“富”而“教”，其充分发展的形态就是全面发展的人自由地联合构成整个社会的结构，用一个现代术语，就是整个社会结构由全面发展的自由人的联合体构成，对西学熟悉的人都知道，这就是马克思关于共产主义的定义。

不同的社会，有不同的“庶、富、教”发展程度。而“全面发展的自由人的联合体”，就是“庶、富、教”充分发展所呈现的面貌。只有自由人，才会有多样性，才会有“不相”而“不同”，才有真正的“庶”；只有全面发展，才有真正的“富”；由“庶”而“富”，充分发展而形成“全面发展的自由人的联合体”所构成的社会结构，这才是真正的“教”。“庶、富、教”，就是不同成其大而大同。“庶、富”的发展水平，决定了“教”的发展水平，只有“庶、富”充分发展，才有“教”的充分发展，“庶、富”对应的是“人不相”，而“教”的充分发展最终对应的就是“人不愠”，只有“全面发展的自由人的联合体”构成的“教”，才是构成“人不愠”世界的社会结构基础。而只有“人不愠”，才是真正的“善人”。

## 18. 子曰：善人、教民七年，亦可以即戎矣。

“善人教民七年，亦可以即戎矣。”的通常断句是错的，应该是“善人、教民七年，亦可以即戎矣。”“善人”、“教民”是同为“动+名”结构的并列。在所有通常的解释里，都把“即”解释成“马上、走向”等，“戎”解释成“战争”等，“即戎”解释成“马上走向战争”等。如果这种解释是正确的，那么孔子所说就有大问题。试想，“恶人教民三年，亦可以即戎矣。”比“善人”厉害多了。为什么？学好三年，学坏一日，历史经验从来都是“恶人教民”比“善人”有效率得多。千万别认为德国人受希特勒、日本人受东条英机蒙蔽了，那是“恶人教民”之功。几乎所有上战场的德国人、日本人，不都是满腔热情、心甘情愿？他们就没有他们所谓的理想？特别在胜利大进军时，每一个人人性里潜藏的恶倾向都有足够的环境迅速膨胀，每一个人都在狂热中迅速变成杀人魔王，这种狂热在历史上还少见吗？经历过这种狂热的人，除非有足够的反省和彻底的治疗，否则终身都不得解脱，一有机会就要故态复萌。日本军国主义分子为什么一直这么猖獗？欧洲反犹太分子为什么在如此高压下还能蓬勃生长？对人性之恶的任何忽视，都是历史性的幼稚。

“善人为邦百年，亦可以胜残去杀矣”一章里已经说了，“善人”的语法结构是“形容词动化+名词”。从上一章就知道，“善人”就是“庶之”、“富之”，最终“教之”。“教之”，就是“教民”，“之”指代的就是“民”，由于“教”是“庶之”、“富之”的最终落实和体现，所以在“善人”之后必须单独提出来强调“教民”的重要，“善人”最终目的就是“教民”。“教”，不是指某圣人或圣人教团从上而下的教育，而是指所有人构成的稳定的社会结构，包括现代术语所说的上层建筑与经济基础，用一个更概括的词，就是“文明”。一个社会的“文明”，指的就是社会结构的整体表现，单纯某一方面，是够不上“文明”的，而一个社会的“文明”总体，就包含在“教”里。

“即戎”，不是马上去打仗，不要把孔子当成一个好战分子，难道“善人、教民”就为了去打仗？让民去当炮灰？显然不是。孔子的战争观是站在比孙子更高的角度上论述的，这在后面有关孔子的战争观相关的章节中会有详细解释。但孔子绝不是一个战争狂人，绝没有丝毫把“民”训练成炮灰的想法。“即”，“离”的反义，所谓“若即若离”。用现代术语，“即”就是“融合、同化”的意思。“戎”，古代少数民族，指代未开化的、文明程度比较低的人、民族和国家。“即戎”，就是融合、同化未开化的、文明程度比较低的人、民族和国家。 “善人、教民七年，亦可以即戎矣。”的意思就很清楚了，上一章所说“庶、富、教”的“善人”之道最终形成的强大文明力量，可以融合、同化那些未开化的、文明程度比较低的人、民族和国家。七年，是古代的习惯用法，当时都喜欢用奇数来代表大概的数字。但无论时间具体多长，最终都会“亦可以即戎矣”。

这一章是在彰显“善人”之道的力量，“教”的力量，文明的力量。“善人”之道，就是“圣人之道”一个具体过程中体现的具体形式，“圣人之道”最终要使得“人不知”的世界变成“人不愠”的世界，当然需要融合、同化那些未开化的、文明程度比较低的人、民族和国家，这是“人不知”世界一个很大的组成部分。如果说上一章更侧重于“善人”之道在国家范围的应用，那这一章就指出，“善人”之道在全世界实现的必然性，而只有在全世界的实现，才算真正的“善人”之道。孔子认为，作为“圣人之道”低级阶段的“善人”之道的实现也只能是一个全球性事件，大同，只能是大同天下，而不可能是某一国的大同，必然要“即戎”而达到天下大同。

同样，孔子不畏惧战争，但他更认为，光靠战争绝不能大同天下，只有文明才是最终的力量。暴力只是机缘偶合的导火索，没有暴力，资本主义该灭亡的还是要灭亡，但资本主义绝不会因为任何人的暴力而灭亡，埋葬资本主义的只能是资本主义本身，为暴力而暴力，暴力最终只会不力而暴亡。

## 19. 子曰：以不教民战，是谓弃之。

把“以不教民战”解释成“用不经教练的民众去临战阵”真是无稽，请问，难道用“经教练的民众去临战阵”就是“不弃之”？军人的职责是保卫国家、民众，一个国家的军队如果沦落到需要让“民众去临战阵”，无论是“经教练”还是“不经教练”的，都只能是军队、国家的耻辱！都是“弃之”！如果这样，直接说“以民战，是谓弃之。”不更简练？还有，纳粹以及军国主义者“教练民众去临战阵”，难道在钱大家眼里就不是“弃之”？至于把“以不教民战”解释成“不对人民进行军事训练”，就只能是无耻了。难道像某些国家全民皆兵、个个武装就不是“弃之”？有强大的国力使得人民安居乐业，不用为国家的安全担心反而是“弃之”？如果这样，现在的阿富汗、伊拉克一定有着世界上最好的政府，因为他们的国民天天都免费受到最直接的、最频繁的、最实用的军事训练。李大家的解释也太无极而无耻了。

“不教”，就是不按照上面所说“庶、富、教”的“善人”之道，“庶、富”最终都落在“教”上，“不教”，当然也不能“庶、富”。“教”，是“善人”之道，也是“民善”之道；而“不教”，只能导致“民战”。何谓“民战”？战，战栗、恐惧，这里是使动用法，“民战”就是“使民战”，使民战栗、恐惧。上面已经说过，让国家长治久安的六字箴言“善人、胜残去杀”，“善人”和“胜残去杀”是相互相成的，不行“善人”之道，那只能用“残、杀”，用所谓的白色恐怖来压制，企图让人民战栗、恐惧而治理国家。“弃”，违背、背叛；“是谓弃之”，这叫遗弃、背叛民众。而弃民者，民必弃之，孔子这一章从相反的角度论证“善人”之道。“以”，本义“用”。“以不教民战，是谓弃之”，那种不行“善人”之道，用“残、杀”企图使民众战栗、恐惧而治理国家的，就是遗弃、背叛民众，而最终也将被民众所遗弃。

这一章，从反面更有力地论证了让国家长治久安的六字箴言“善人、胜残去杀”的必要、合理性。“胜残去杀”，不能企图用“残、杀”让民众战栗、恐惧，国家不可能因此而长治久安。但历史上很多人都不明白这个如此浅显的道理，不明白让国家长治久安的最稳固基础在于“民之乐”而不是“民之战”，是“使民善”而不是“使民战”。这种糊涂蛋多不胜数，《论语》里马上就举了一个例子，因此就有了下一章。

## 20. 哀公问社於宰我。宰我对曰：“夏后氏以松，殷人以柏，周人以栗，曰，使民战栗。”子闻之，曰：“成事不说，遂事不谏，既往不咎。”

鲁哀公向孔子的弟子宰我问“土地神的祭祀”，宰我自作聪明道：“夏代用松木，殷代用柏木，而周代用栗木是为了借谐音使民战栗。”孔子听到，就告戒：“正成的事不要妄加评议，即成的事就不要徒劳劝告，已成的事就不要再生灾祸。”

“成事”，不是指已成的事，而是指正成的事，也就是在萌芽状态的，这时候，还需要观察，不能妄加评议，胡乱定性；“遂事”，马上就要成的事，已经无可挽回的，就不要徒费口舌去劝告了，这样只能产生怨恨；“既往”，已经过去的已成的事，要“不咎”，“咎”的本义是灾祸，已经成的事，如果错了，就不要错上加错，再生灾祸。这句话针对事物发展的三个不同阶段应该采取的态度。 但通常的理解基本都是错的，特别是最常用的“既往不咎”，把“咎”解释成“追究”之类的，错得一塌糊涂。

宰我牙尖嘴利，在孔子弟子中，是最爱用怪问题来刁难孔子的。但又经常逞口舌之快而干蠢事。鲁哀公被鲁国三家大夫压制，心里很不爽，问他“土地神祭祀”的问题，本就不是无故发问。国家就是社稷，问“社”就是问国家，问国事，宰我当然明白，就自作聪明地把周代用栗木解释为是“使民战栗”。但这种望文生义的想法是孔子所反对的，而且孔子也不认为周代用栗木就是“使民战栗”，因此告戒他，关键是要他“已成的事就不要再生灾祸。”周代用栗木是“已成的事”，但宰我望文生义，而且是在鲁哀公接题问国事的情况下，这样只能给鲁哀公一个不好的暗示，实际上就是鼓励鲁哀公行“残”、“杀”之术，从而引发灾祸，孔子因此给予特别的告戒。结合上一章“以不教民战，是谓弃之。”的论述就知道，孔子反对“使民战栗”的“残”、“杀”之术是一而贯之的，即使在自己弟子的言谈中涉及这个方面的暗示，也给予严厉的告戒，对此必须有明确的认识。

## 21. 子曰：夷狄之有君、不如，诸夏之亡也。

“亡”，轻视；“诸夏”，指代文明程度比较高的人、民族和国家。“诸夏之亡也”，即“诸夏亡之也”，“之”指代“夷狄之有君、不如”；“如”，本义“遵从、依照”，不如什么？不如“道”也。但这里的“道”不是指“圣人之道”，而是“诸夏”所标榜的“道”，包括“齐式”的“王霸之道”和“鲁式”的“仁德”之道。“有君”，有其君、有其国也。“夷狄”，和“善人、教民七年，亦可以即戎矣。”中的“戎”一样，都是指代未开化的、文明程度比较低的人、民族和国家。“夷狄之有君、不如，诸夏之亡也。”的意思是：未开化的、文明程度比较低的人、民族和国家，虽然有他们自己的国体、政体，但由于没有遵从、依照文明程度比较高的人、民族和国家的政体、国体，而被后者所轻视。

“亡”，还有过去的意思，“诸夏”所轻视的，其实就是“诸夏”的过去。为什么轻视？因为“夷狄之有君”，夷狄的国体、政体等等都是“诸夏”过去曾经历而今已超越的，“诸夏”因此而轻视，就有“夷狄之不如”的想法。而“诸夏”都是从“夷狄”而来，文明程度比较高的人、民族和国家的过去都经历过未开化的、文明程度比较低的阶段，但有些人、民族、国家，“人一富，脸就变”，就像现在很多所谓的中国富翁们，开始看不起穷人、农民、民工，却忘了，所有中国人，都是从农民而来，三代之内都有农民，每个中国人身上都留着农民的血。国家也一样，所谓强国对弱国的压榨，诸如现在美国到处贩卖所谓的“民主、自由”。”只要有不同的人、民族、国家同时存在，就必然有“诸夏”、“夷狄”之分，对于民族、国家来说，任何不行“圣人之道”的，无论是“齐式”的“王霸之道”还是“鲁式”的“仁德”之道，都必然会有“先进”对“落后”的轻视、压榨。

而“圣人之道”的“即戎”，是否定“夷狄之有君、不如，诸夏之亡也”的。如果说“以不教民战，是谓弃之。”在狭义角度上是针对本国内部的，在广义角度上，在国与国之间，在天下的范围内，同样有“以不教民战，是谓弃之。”在这广义的角度上，其中的“民”就是“民族、国家”的意思了。一个国家、民族，如果不行“善人”之道，用“残、杀”企图让别国、别的民族战栗、恐惧而治理世界，就是遗弃、背叛各国、各民族，而最终也将被各国、各民族所遗弃。一个现成的例子，就是美国，以前历史上所有大帝国的兴亡历史，都是这个广义角度“善人”之道的最好反面教材。相应的，“善人、胜残去杀”让国家长治久安的六字箴言，同样是世界长久和平的六字箴言。而由“善人”、“胜残去杀”这一个硬币的两面所构成的“善人”之道，也就由这章而从狭义的一国状况推广到了广义的天下状况，由家而天下了。

“道”，只有现实之道，没有任何“道”是先验的，具有某种类上帝力量的。所谓“修身、齐家、平天下”，都是现实的“身、家、天下”；“善人”之道、“圣人之道”不是一个抽象的概念，不是一个以“道”为名的借口，而是具体的、现实的。所有“道本位”的把戏，都要先立一个抽象的“道”，无论是自由、民主，还是仁义、道德，都没什么区别。用这个抽象的“道”来“本位”，其实就是以“道”为名编造借口。“圣人之道”、“善人之道”是大道，更是现实之道，无位可本，又何来“本位”？正因为无位可本，才可以无所位而生其本、无所本而生其位。这，才是真正的大道、现实之道。

## 22. 子曰：为政以德譬，如北辰居其所而众星共之。

“为”，设置、建立，也就是立其本、立其位；“以”，使、令；“德”，得，行“圣人之道”、“善人之道”所得。“譬如”不能像白话文那样当成一个词，而是“譬”+“如”，分属前后分句。“譬”，晓谕、使人知晓，引申为彰显。“如”，像；“居”，处在；“所”假借为“处”，处所的意思；“共”，通假“拱”，执持的意思。

“北辰居其所而众星共之”，字面意思就是北极星处在其处而其它的星星执持着它。而深层的意思就是，人把北极星的位置确定后，执持这位置相应定出其他星星位置。但北极星位置不是先验的，例如，说北极星在北边，只是因为相应的社会文化系统把那叫“北边”，而实际上，北极星的位置不是固定不变的，甚至被称为北极星的那星星，也是会随着时间的改变而改变的。北极星位置的确定，只是一个人参与其中的当下、现实的具体结果，而其他星星根据北极星位置定出相应位置，也同样是一个人参与其中的当下、现实的具体结果。

“为政以德譬”，设置、建立“政”使行“圣人之道”、“善人之道”所得彰显，就像“北辰居其所而众星共之”的道理一样，并不能把“政”的原则先验地确立。其确立，也只是一个社会上所有的人参与其中的当下、现实的具体结果，那种把某种特殊的国体、政体等当成先验的、四海皆准的原则而上帝化的玩意，都不是“为政”之道，只不过是一些根据私利而制造的谎言。有人可能说，这不就是“具体问题具体分析”吗？错！这至少不是通常所说的“具体问题具体分析”。一般意义上的“具体问题具体分析”，只不过是用一套通用的法则在具体问题上套用，根本不是马克思意义上的“具体问题具体分析”。马克思意义上的“具体问题具体分析”，其实就是马克思任何理论前提只能从分析现实逻辑出发的等价说法，并没有任何先验的逻辑是先于具体问题的，具体分析不是用一些先验的法则去分析，而是从具体问题中找出其现实的逻辑关系来。

而这一章，其实就是上一章所说““圣人之道”、“善人之道”是大道，更是现实之道，无位可本，又何来“本位”？正因为无位可本，才可以无所位而生其本、无所本而生其位。这，才是真正的大道、现实之道。”的进一步展开。何谓“为政以德譬，如北辰居其所而众星共之。”？就是“无所位而生其本、无所本而生其位”。 只有明白了这句话，才可能真正明白马克思意义上的“具体问题具体分析”，也才可能真正明白何谓“为政以德譬，如北辰居其所而众星共之”。

## 23. 季康子问政於孔子，孔子对曰：政者，正也，子帅以正，孰敢不正？

季康子，鲁国大夫，向孔子问政。这一章完全从上一章“为政以德譬，如北辰居其所而众星共之。”而来。

“帅”，遵循。“帅以正”，“帅之以正之”的省略，这省略的“之”，就是人所参与其中的当下现实。能遵循的，只能是人所参与其中的当下现实；能“正”的，也只能是人所参与其中的当下现实。“正”，指事字，上一表示方向、目标，下足(止)表示向这个方位或目标不偏不倚地走去。对于儒家、《论语》来说，这方位或目标就行“圣人之道”而成就之。“以”，和，表示并列关系。“帅”和“正”、“帅之”和“正之”，是并列的关系，表示两者不能偏废、相互相成的关系。“帅以正”，用现代术语，就是遵循现实的逻辑，从现实出发，行“圣人之道”而成就之。

与“北辰居其所而众星共之”相仿，现实、现实的逻辑就如同北极星，当人把北极星的位置确定后，执持这位置相应就可以定出其他星星位置；当人从现实出发分析把握了现实关系的逻辑结构后，“孰敢不正？”，其它问题就会以此为基础相应地找到解决的办法。这里不需要任何的先验、抽象原则，而是“无所位而生其本、无所本而生其位”。人不是现实的奴隶，现实必须是人参与其中的，没有了人，也无所谓现实，更无所谓现实逻辑。 现实之于人，按其逻辑，有着各种不同的选择，究竟如何去选择，就构成了各色各样的政治。各种政治结构的逻辑支点，都来自现实，这逻辑支点也如同北极星，一旦确立，其它就以此为基础相应地构建。而对于儒家、《论语》来说，这个现实的逻辑支点，“正之”所在，就是行“圣人之道”而成就之。

“政者，正也”，为政，就是要立行“圣人之道”而成就之这一逻辑支点；“子帅以正，孰敢不正？”为政的人，遵循现实的逻辑，从现实出发，行“圣人之道”而成就之，其它问题就会以此为基础相应地找到解决的办法。这里必须要明确的是，现实，是最底层的支点，行“圣人之道”而成就之这个逻辑支点必须也必然在现实支点之上，离开现实，无所谓“圣人之道”。“圣人之道”，不是离开现实的乌托邦，那种把“圣人之道”装扮成某种口号、旗帜、目标，以此而驱使人，让人为此而折腾，都和“圣人之道”、《论语》、孔子毫无关系。

## 24. 子曰：不在其位，不谋其政。

针对本章，前几章反复提到“无所位而生其本、无所本而生其位”，何谓“位”？就是指变化的位次。例如《易经》乾卦，从“初九”到“上九”，就是不同的位次，对应着变化的不同状态。一切都从也只能从现实出发，现实在什么阶段，什么位次，是必须首要分析的问题。相应的，“其政”必须要与“其位”相适应。“不在其位，不谋其政”，就是“不谋不在其位之政”，不谋划与现实变化的位次不符的政事、政治关系、政治制度、上层建筑、生产关系等等。

在马克思对社会总体结构的考察中，有所谓的“生产关系适应生产力”之说，这其实就是“不在其位，不谋其政”在社会总体结构运动中的特殊表述。马克思是以生产力的变化位次来界定社会总体结构位次的，而“其政”必须适应“其位”，“不在其位，不谋其政”，不可能超越生产力的位次而行高位次生产力所对应的生产关系。同样，“上层建筑”必须适应“经济基础”，也是“不在其位，不谋其政”对社会结构内部关系的特殊表述。

## 25. 子曰：“不在其位，不谋其政。”曾子曰：“君子思不出其位。”

“不在其位，不谋其政。”刚在上一章说完，怎么又来一次？其实，在原来《论语》的排序中，上一章出在《泰伯》一篇，而这一章出在《宪问》一篇，由此也见原来编排的混乱。前章，只记录了孔子的原话，而本章，增加了曾参（孔子关门弟子）的话。但就是他这话，使得千古以来无知之徒的错解错上加错。当然，责任不在曾参，只是更暴露了无知之徒妄言《论语》、妄批《论语》的可笑。

“不在其位，不谋其政”的真义，在上一章里已经说了，不再赘言。至于“君子思不出其位”，朱熹比鲁迅等还是要高明一点的，至少知道这其实是《易经》“艮卦”象辞的引用，也就是说，朱熹正确地指出了，曾参是引用《易经》“艮卦”象辞来解释、印证“不在其位，不谋其政”。“艮卦”，其象“兼山”，两座大山夹着，《彖传》说“时止则止，时行则行；动静不失其时，其道光明。艮其止，止其所也。”这是什么意思，就是“不在其位，不谋其政”，就是本ID在上一章里相应的解释。对于喜欢扑通扑通的，以为本ID所解是胡编乱造，故意曲解圣解孔子的意思，但却不知道，本ID所解皆不出孔子其义，象辞、《彖传》也是孔子所写，即使像钱穆之流，怀疑象辞、《彖传》是后出，但也不可否认象辞、《彖传》所论是孔子、儒家所认同的。

“君子思不出其位”，“思”不是通常鲁迅、钱穆、李泽厚之流所认为的“思想”，而是“司”的通假，“司”什么？政，和“为政”是一个意思。“君子”，“闻、见、学、行”“圣人之道”的人，“思不出其位”，就是“不在其位，不谋其政”，相应的解释可参考上一章。“不在其位，不谋其政”，“时止则止，时行则行；动静不失其时，其道光明。艮其止，止其所也”，这就是君子行“圣人之道”必须时刻谨记的。 《彖传》的话，这里就不详细解释了，有一点必须指出：“时”，不是依其时或与时俱进的意思，而是本书最开始几章反复强调的“与天其时而天与其时”；“止”，何谓“止”？就是上几章反复强调的“无所位而生其本、无所本而生其位”，这才是“止”，而不是通常所理解的“驻守、居住、停止、止息、阻止”等所谓的“止”。

## 26. 子曰：“不患，无位；患，所以立。不患，莫己知求，为可知也。”

前章，曾对“位”与《易经》的关系有了相应的揭示。《易经》，中华文明之源。孔子与《易经》的关系，在《论语》中也多次提及。如果连“位”都不理解，显然是无法明白《易经》的，当然对《论语》也只能瞎解了。“位”，就是位次，就是所“止”，就是所“立”。 “无所位而生其本、无所本而生其位”，即所“立”、即所“止”、即所“位”。有所“立”，则“立”其“有”，其“有”必有其“位”，何谓“有”？用现代术语，就是“存在”。与“有”相对的就是“无”，“有”有其“位”，“无”有其“位”吗？两千年后，海德格尔关于“有”的思考是以其对“无”的思考为背景的，存在与非存在，海氏提出了这样的命题“为什么在者在而‘无’倒不在？”对于这样一个深刻的哲学问题，孔子两千多年前的回答是“不患，无位；患，所以立”。对于孔子来说，最重要的问题是“以何立”的“不患，无位；患，所以立”，而不是“何以立”的“为什么在者在而‘无’倒不在？”

至少对于中前期的海氏，孔子和他有着“以何立”与“何以立”的分野，“何以立”没有参悟到何谓“无所位而生其本、无所本而生其位”，因而才有“何以立”的纠缠。而孔子悟之而摆脱“何以立”源始境界的纠缠而直抵“以何立”的当下境界。从“何立”现象境界到“何以立”源始境界再到“以何立”当下境界，对应着“见山只是山、见水只是水”、“见山不是山，见水不是水”、“见山仍是山、见水仍是水”三重境界，不辩此，无以谈儒学、西学。不过要补充一句，别把这三种境界和禅宗连一起，否则一棍打你色身星散，禅宗岂是儒学、西学可思可议？

“患”，即“畏”，对于海氏来说，“畏”启示着“无”的源始境界。海氏将“无”从“何立”现象境界对“有”的单纯、抽象否定，拯救性地开拓为“何以立”的源始境界使得“有”得以而有，其对西学的功劳是大大的。但对于儒家来说，这还不够，困于“何以立”的源始境界，“见山不是山，见水不是水”，犹未脚跟落地。但后期海氏已经开始打开这源始境界的大黑笼，用存在之“思”的源构域展现当下的生机，可以说，海氏最后已经触及“不患，无位；患，所以立”的“见山仍是山、见水仍是水”境界。

“不患，无位；患，所以立”，“患”，以“不患”的“无位”而“立”，“立”在古代是和“位”相通的，“患，所以立”，“患，所以位”也。老子说“人之大患，患其有身”，其实，凡其“有”，必有其“患”，在海氏则认为，只有“畏”、即“患”，使此在本真地能在。而“不患，莫己知求”，“求”，选择。“莫己知求”，不以自己“所知”来选择。“为可知也”，“为”，就；“可”，能。后期海氏存在之“思”的源构域，与此“能知”可参照参悟。“不患，莫己知求，为可知也”，“不患”，不以自己“所知”来选择，就是“能知”，就是存在之“思”在天地人境界当下大易流行、生生不息。

儒家，内圣、外王，“不在其位，不谋其政”的外王，是和“不患，无位；患，所以立。不患，莫己知求，为可知也。”的内圣相互相成的。这是参悟儒家之说的大关键。

缠中说禅白话直译
子曰：“不患，无位；患，所以立。不患，莫己知求，为可知也。”
孔子说：“不患”，无位次；“患”，以“不患”的“无位次”而“位次”。“不患”，不以自己“所知”来选择，就是“能知”。

## 27. 子曰：不患人之不己知；患其不能也。

从语法上看，有两个问题是不能逃避的：一、“其”是指代“人”还是“己”。二、“能”是名词还是动词。

对于第一个问题，“其”是指代“人”，对于第二个问题，“能”当名词没问题，但在这里，更合理的是动词，因为，“不患人之不己知，患其不能也”其实是“不患人之不己知，患人之不能己知也”的省略，相应的，“能”在这里更应该是动词。因此，本章的解释是“不患人不明了自己，患人不能明了自己。”这里的“人”，包括自己和别人。

先说“人”指自己的情况，自己不明了自己，这是人的常态，而且只要还是人，这种状态就无法彻底改变，而这没什么可怕，可怕的是人不能不断明了自己，一世糊涂，而且以糊涂为荣，妄自尊大或妄自菲薄，失去了明了自己的愿望和可能，这就是人生最大的不幸。人，首要的是不断明了自己，所谓“内圣”，所谓修身，也是要不断地明了自己。

对于“人”指别人的情况，别人不明了自己，反之，自己也不明了别人，人与人之间互相不明了，站在“家、国、天下”的角度，这是一个很普遍的问题，也是一个很正常的问题。由于个人在社会结构中所处位置的不同，相互间因为利益等问题，出现相互间的不明了，是很正常的，没什么可怕的。但可怕的是，人与人之间不能不断互相明了，甚至还忙于互相制造鸿沟，你是“精英”、他是“平民”，这是“富人”，那是“穷人”，使得社会结构出现各种不可填补的裂痕，社会上人与人之间失去了互相明了的愿望与可能，这才是社会最大的不幸。社会，首要的是互相间的不断明了。所谓“外王”，所谓“齐家、平天下”，首要的，就是要人与人之间的不断明了，没有人与人之间的不断明了，何来“人不愠”的世界？

本章说涉及的“不患”与“患”，和上一章的又有什么关系？其实，上一章所说的是一个根本性的问题，站在终极的角度，一切存在都有其“患”，而“患”以“不患”的无位次而位次。但所谓的终极，也是相对而言的，在具体的存在系统中，也相应有其“患”与“不患”。在这系统似乎无位次的“不患”，在另一系统内就成了“患”；反之，在某一系统的“患”，在另一系统内就成了“不患”。每一个现实系统的存在，都有其“患”与“不患”。

本章所探讨的，正是人类社会这个系统内“患”与“不患”的问题。在人类社会的角度，对于个体来说，自己不明了自己，就是“不患”，站在绝对的意义上说，自己永远也不可能彻底明了自己，所谓的明了，只是相对于永远不明了的明了，“不明了”是无位次的，而“明了”因“不明了”而位次。说某某人有自知之明，某某人没有自知之明，这都是因“不明了”的无位次而有了自知之明与没有自知之明的位次，依次下去，自知之明还可以分出三六九等来。因此，该“患”的不是自己不明了自己的无位次，而恰好是以这无位次为借口认为反正不能彻底明了自己，因此妄自尊大或妄自菲薄，失去了不断明了自己的愿望和可能。却不知道，正因为“不明了”的无位次，所以才有了自己不断“明了”自己的位次，所以才有了“明了”的可能，不明白这一点，是不可能明白何谓“内圣”的。

同样，在人类社会的角度，对于人与人来说，人不明了人，就是“不患”，站在绝对的意义上说，人永远也不可能明了人，所谓的“明了”，只是相对于永远“不明了”的“明了”，“不明了”是无位次的，而“明了”因“不明了”而位次。因此，该“患”的不是人不明了人的无位次，而恰好是以这无位次为借口认为人不能彻底明了人，因此肆意互相制造鸿沟，使得社会结构出现各种不可填补的裂痕，人人都失去了明了人的愿望和可能。却不知道，正因为“不明了”的无位次，所以才有了人“明了”人的位次，所以才有了不断“明了”的可能，不明白这一点，是不可能明白何谓“外王”的。

何谓“能”？用现代术语来说就是要主、客条件具备，从“不能”到“能”，就是要不断创造，使得主、客条件具备。 对于任何现实的社会、任何现实的人来说，“人之不己知”是绝对的宿命，是无位次的，是无条件的，而正因为如此，才有了创造各种主、客条件使得这无位次的“人之不己知”不断显现“人之己知”不同位次的可能来，从而实现从“不能”到“能”位次的不断提升。这就是人类社会生生不息的动力源泉，所谓“天行健”，不明白这一点，是无法理解儒学、《论语》、孔子的。

缠中说禅白话直译
子曰：“不患人之不己知；患其不能也。”
孔子说：不患别人或自己不明了自己，患别人或自己不能明了自己啊。

## 28. 子曰：“不患人之不己知；患不知人也。”

这一章就着上一章来，在一个更具体的问题上展开讨论。如果说前面两章分别站在根本性以及人类社会的一般性角度讨论问题，那这一章就在人类社会的内部结构上揭示其“不患”与“患”。在人类社会的内部结构上，“人之不己知”是其“不患”，正因为有了“人之不己知”的“不患”，才有了“不知人”的“患”。 “人之不己知”，在人类社会结构内部是无位次的，人类社会，必然由人构成，而只要是人，就是“不己知”的，正因为“不己知”的无位次，才有了“不知人”的位次。

“不己知”是社会中所有人存在的必然状态，如果真有什么“人性”，唯一可能的“人性”就是“不己知”。任何理论，如果违背了这个“不己知”，就是荒谬可笑的。例如，有某种上世纪被无数人吹捧的主流经济学，以所谓人的理性为前提，这种经济学只能是垃圾经济学。因为“不己知”，在人类理性的层次上，“非理性”是无位次的，人类的理性因“非理性”的无位次而位次，叫嚣人类理性的，根本上从来都是“非理性”的。

“不知人”，就是前面反复提到的“人不知”，“圣人之道”，就是要把“人不知”的世界变成“人不愠”的世界。为什么有这个可能？就是因为“不己知”的无位次而有“不知人”、即“人不知”的位次。正因为有了“人不知”的位次，才有可能把“人不知”的世界变成“人不愠”的世界。但这改变，不可能通过改变“不己知”的状态而达到，因为“不己知”是无位次的，任何涉及“不己知”改变的都是“不己知”，“不己知”在人类社会的结构下是无可改变的。换言之，一切企图通过改造人从而达到改造人类社会的运动都是荒谬可笑的，任何希望通过灵魂深处爆发革命而达到改造社会的运动都是荒谬可笑的。

从“人不知”到“人不愠”，是不能从“不己知”下手的，因为无从下手。马克思从来不探讨任何人类思想的改造问题，因为人类的所谓思想位次，从根本上来源于社会“人不知”的位次，唯一需要改造的只能是“人不知”世界的现实结构。但社会的改造必须由其位次而决定，不同位次的社会有着不同的形态、规律，这里没有任何先验的、放之四海而皆准的良方，都必须从每个社会结构的现实逻辑、位次出发，这才是知其位次而行之，这才存在把“人不知”世界变成“人不愠”世界的可能，离开了现实的逻辑、位次，都是别有用心的鬼把戏。

缠中说禅白话直译
子曰：“不患人之不己知；患不知人也。”
孔子说：不患人不明了自己，患“人不知”的世界啊。

## 29. 子曰：“性相，近也；习相，远也。”

性不应泥于善恶，本章的着力点在近、远两字上。何谓“性”，《集释》《皇疏》：性，人所禀以生也，即性是人所被赋予而得以生的，也就是说，性是先天、先验的。《集释》《皇疏》进一步解释到，人俱禀天地之气以生，虽复厚薄有殊，而同是禀气，故曰相近。也就是说，这个先验的基础被定为“天地之气”。

孔子是拒绝一切先验原则的。不明白这点，是根本不可能明白所谓“性相近也，习相远也”。

本章是顺着前几章而来。“不患”，无位次；“患”以“不患”的无位次而位次。而“患”的位次之所以位次，并没有任何先验、先天的前提，“不患”并不是“患”的先验、先天前提，“不患”只是“患”涌现的舞台。存在必有其“患”，“不患”并不存在，也不是一个理论的假设，否则就在理论上存在了，就不是“不患”了。“不患”不是前提，“患”的前提，只能是当下现实，即“患”自身。

“相”，去声，有其位次，相应的，就有其位次所显之相，离相而求一抽象、先验的位次而不可得。“近”，缠附也，其相立，必缠附其性，可谓性？“性”，心生也，心执“患”为“不患”之生，进而以“性”“性相”，因而近也，生其缠附也。所有以理论而理论的理论，都逃不了这个“性相近”。

世界不是用来解释的，世界是用来改变的，“患”以“不患”的无位次而位次，而不同位次的实践，就是人对世界的改变，从而才有“人不知”的世界到“人不愠”的世界。

何谓“习相”？就是《论语》开始所说的“学而时习之”。“相”，因“有”患其“患”而相其“相”，而人能“学”，能“明了”的，只是各种不同位次的“相”，除“相”之外，并没有“相”之后所谓先天、先验之“性”。“相”而“习”，“学”其“相”，并不是要忽悠出各种的所谓“理论”来，而是要“习”，以“习”习其相。“习”的根本目的，就是要改变世界，就是“不相”其“相”而显其新“相”，就是与天其时而天与其时、与地其利而地与其利、与人其和而人与其和。

“远”，深远、深奥。真正深远、深奥的是“习”，是实践、是改变，而不是那些书虫们的哀号和忽悠。
但必须指出的是，这里并不否认任何理论存在的价值，反而是肯定所有理论存在的价值。理论，以无价值之“不患”而显示出其价值，理论的价值以理论的无价值而价值。而理论的无价值之“不患”，是缠附在现实之“患”上的，理论因此缠附而显示出不同的位次来，而理论的位次是缠附在现实的位次上的，但这种缠附，如果是一种一对一的逻辑关系，那就不是缠附了。

所谓的现实，离不开某种理论视角的照射，把现实绝对化，把现实变成某种先验、先天的前提，同样是可笑的。如果现实真是先验、先天的前提，又何来现实的改变？不同位次的理论也可以出现在同一位次的现实里而显示出其位次来，反之，利用同一位次的理论可以变出不同位次的现实来而显示出其位次来，而这才是理论的“不患”缠附在现实之“患”上，这才是理论的位次缠附在现实的位次上。只有这样，才能算真正明白何谓缠附，何谓“性相近也”。

缠中说禅白话直译
子曰：性相，近也；习相，远也。
孔子说：以性性相，缠附呀；以习习相，深奥啊。

## 30. 子曰：人无远虑，必有近忧。

字面上，这是很简单的一章；字面后，就不那么简单了。理解的关键在于：何谓远虑？何谓近忧？

“远”，深远、深奥，同于“习相，远也”，和“习相”相关，脱离“习相”无所谓深远、深奥，不过幻想而已。“习相”，先要明其“相”，明其“相”必先明其“相”之位次，明其“相”之位次，必对其“相”的当下逻辑关系有一明确把握。而现实的存在，不离时空，现实逻辑关系也必构成相应的时空关系，对现实逻辑关系的把握，须从这现实的时空关系中切入。

“虑”，审察、思虑、谋划。“虑”，不是哈姆雷特式的，而是审察、思虑、谋划的统一，三者缺一不可，而最终必须落在行动上，没有行动的“虑”也不过是幻想而已。 上面的所有工夫，都构成“习”的一环，但仍不是“习”的全部。“习”的关键在于对现实逻辑关系把握后的改变，是转现实而不是被现实所转，只有这样，才勉强算得上“远虑”。 就算是炒股票这么小的事情，也必须有其“远虑”，否则没有对市场的深刻把握，也必然导致其“忧”之“近”，这点，观察一下那些亏损累累的人的行为就清楚了，那都是些被市场所转的典型。

“近”，缠附，同于“性相，近也”；“忧”，忧患，祸患。“近忧”，缠附忧患、祸患，为何如此？因为“人无远虑”。忧患、祸患的种子是当下种下的，每一思想、行为，都在种下种子。而种子并不一定即刻萌芽，把“近忧”解释成眼前的忧愁、忧患，是对此不能明了。 现实中，很多没有“远虑”的事情，所谓运气来了挡都挡不住，眼前一片大好，加速上涨，何来眼前的忧愁、忧患？如此，难道就没有“近忧”？这，显然是不对的。人的行为，必须从其苗头下手，不想吃恶果，最简单的方法就是不要种下其种子，忧患、祸患的种子一旦缠附，一有机会就会萌芽，就要结果。别以为可以用任何方法可以消除这种子，种子一旦种下就是无位次的，准确说，相对于现实系统来说，种子是无位次的，任何现实的把戏都消灭不了种子，种子不一定在眼前发芽，但不发芽只是机会不成熟，一旦成熟，逃都逃不掉，眼前看不到、没迹象的忧患、祸患，往往才是致命的。而这，才是真正的“近忧”。

无“远虑”与“近忧”之间的关系，孔子给了一个“必有”的强判断，由此可见对此的重视与强调。这话可不单单针对个体的人，家、国、天下，同样成立。“人不知”的社会，归根结底就是“人无远虑”的社会，其中的每个人、每个家庭、每个地区、每个团体、每个国家等，都处在“人无远虑”之中，由此种下无数“忧”的种子，忧患、祸患种子因而“近”而缠附。要使得“人不知”的社会成为“人不愠”的社会，首先要改变的就是这个“人无远虑”。

一个能“远虑”的人、家、国、天下，必须有其相应的“远虑”能力，社会必须发展到一定位次，显示出一定位次之相，才可能有其相应的“远虑”。任何的“远虑”都是和一定位次的社会相连的，离开了一定位次的现实社会，“远虑”也无所谓“远虑”了。 但社会的现实结构是有深浅之分的，有些“远虑”可以完全洞穿整个社会的深层结构，这样的“远虑”就构成了人类文明历史最珍贵的部分，孔子、马克思，都成为这最珍贵部分的中流砥柱。后人经常以孔子两千多年前说的话怎么可能对现在有用，现实已经改变了等等理由来搪塞，却不知道有些“远虑”是可以洞穿社会结构的深层，而社会结构的深层，在两千多年来，根本就没有任何的改变。因此，孔子的“远虑”，依然适合今天。马克思的，当然也一样。

缠中说禅白话直译
子曰：人无远虑，必有近忧。
孔子说：人没有深远的审察、思虑、谋划，必然缠附祸患。

## 31. 子曰：众，恶之，必察焉；众，好之，必察焉。

摈弃“我本位”的独断，以“众”为众，相应就有如下断句：“众，恶之，必察焉；众，好之，必察焉”。“众”，有大众、有小众，无论以大压小还是以小卖小，都不可能是真正的“众”。“众”，必须显现“众相”之“众”，对任何一种现象，不同人会显现出不同的好恶程度，相应就有了“众相”之“众”。那种对所有现象都万众一心、一种色彩、一种声调、一种气味、、一种味道、一种思想、一种行动，是无“众”可言的。“之”，指代前面的“众”，包括现实中的一切现象。“好之”，以之为好而好之；“恶之”，以之为恶而恶之。

认为好的喜欢，认为恶的厌恶，这都是人之常情。而人之“远虑”，离不开对现实中一切现象的“察”。“察”，无所谓好恶，而带着各种好恶去“察”，就无所谓“察”了，只不过继续“我本位”逻辑的把戏。何谓“察”？分辨、明察、知晓也。只有排除一切好恶，当下直观，才有真正的“察”。任何人都有其情绪、好恶，但这情绪、好恶就是“察”的最大干扰，“远虑”离不开“察”，而“察”就要摈弃一切好恶，当下直观，这样才有可能进而“远虑”。 “焉”，“于此”的合音。当下直观，就是“于此”直观，离开了现实的此岸，幻想那虚无飘渺的彼岸，是没有“察”之直观可言的。

“人无远虑”之人，没有深远的审察、思虑、谋划，在“必有近忧”的缠附祸患里，归根结底最大的祸患，就是以一己之私对“众”、对“众相”、对一切现象恶之、好之，不能摈弃一切好恶当下直观。用主观的臆测替代客观的观察，用彼岸的幻想替代此岸的现实，这种事情，无论现实和历史中，难道还少见吗？由此而产生的祸患、酿造的悲剧，难道还少见吗？两千五百多年前，孔子已经给出了明确的警示。

缠中说禅白话直译
子曰：众，恶之，必察焉；众，好之，必察焉。
孔子说：一切现象，当被认为是恶的就会被厌恶，对此必须摈弃一切厌恶当下直观；一切现象，当被认为是好的就会被喜好，对此必须摈弃一切喜好当下直观。

## 32. 子曰：视，其所以；观，其所由；察，其所安。人焉廋哉？人焉廋哉？

“以”，凭借；“由”，遵从；“安”，安置；“廋”，隈曲。“其”，指的是任何个体的人，即“天地人”结构中“人”的个体化现实存在。现实，必有其“患”，而其“患”是以“不患”而位次的，“人”的个体化现实存在亦然。本章讨论的就是显示出不同位次的现实个体之“患”所依据的“不患”。必须指出的是，这现实个体之“不患”在“天地人”结构就是其“患”。并没有任何绝对的“不患”，这在前面关于“患”与“不患”的论述中早有说明。

站在现实个体的自我系统中，其“不患”结构是无法考察的，因为在那里，“不患”是一切依据的依据，也是其结构考察的依据，任何的考察都是同语反复，就像在欧几里德几何公理系统内用三角型内角之和180度与平行线的唯一性之间的互证一样。但站在“天地人”结构中，现实个体之“不患”成其“患”，因此就有其位次，考察其内部结构就成了可能，就像可以站在欧氏几何、罗氏几何、黎曼几何之外去考察它们各自的公理化结构，用三角型内角之和进行相应分类研究。本章类此而对人的个体之“不患”进行的分类研究，得出一个“视、观、察”的个体“不患”结构， 所以孔子才有了“人焉廋哉？人焉廋哉？”的感叹，用一个通俗的说法，就是“人不过如此”，就像在公理化的视角下，“三角型内角之和180度”之公设不再神秘，不过如此而已。

两千多年后，西学中出现了康德，对人类的先天能力（站在《论语》的话语系统中，就是上面所说的个体“不患”）进行了彻底的研究，写出了近现代哲学历史最重要的三大批判，成为近现代哲学最重要的源头，从此，哲学的研究没人能绕开康德，而《论语》本章，也就是孔子的三大批判，其意义和康德是一样的，必须与之对照才能更深刻地理解。不知其“不患”，又焉知其“患”？不知其“患”，焉能不患？

康德，把人类的认识能力分为低级的认识能力“感性”与高级的认识能力“理性”，感性是认识的开始，是认识不可超越的范围，是高级认识的对象和质料。高级认识能力分为知性、判断力和理性，经验并不是感性的直接结果，而是知性综合感性材料后的结果。例如科学研究的所谓自然界，甚至每一个个体的人，这些经验、认识对象，并不是感性所把握的，而是知性作用的结果。判断力，更准确的是规定性的判断力，是应用知性的先天法律形成经验、认识对象的能力。而理性，就是把知性的先天法律尽可能扩展的能力，一般这种能力的极限就是产生绝对的主观理念，例如上帝、世界、灵魂等。但这种能力一旦把理性自我扩展到把制造的理念幻想当成有实有，就会产生各种谬误，例如灵魂不灭、上帝存在等。因此必须限制理性的应用范围，但这种限制，反而是人摆脱自然必然性的实践前提。人的理性实践，其前提就是意志（人的高级欲望能力）的自由，而这才使得道德成为可能。但理性的实践前提，在康德那里是不能应用在实有之上，它只涉及“应有”而不是“实有”。

知性与理性之间，如果单纯是规定性的判断力所连接，那人就成了一个必然性的机器，意志的自由就成为不可能，理性的实践也不可能。康德就此显发了“反思判断力”，使得意志自由与知性的必然有了协调的可能，人首先在艺术上创造出一种自然与道德、必然与自由的统一，而康德又把这延伸到世界从必然到自由的可能。其后，列宁主义所延伸的运动，将这付诸实践，成为人类社会在康德思维范式中对必然向自由的可能进行的一次行为艺术。当然，这和马克思毫无关系。

有了康德的比较，孔子的三大批判就有了明晰的可能。“视”，人与认识对象之间的看，相当于感性以及康德规定性判断力所连接的知性与理性所构成的高级人类认识能力，也就是人类所有的认识能力；“观”，看法，相当于“反思判断力”所连接的自由意志；“察”，当下的直“观”，是自由意志的当下实践。“视，其所以”，认识能力是人所凭借的；“观，其所由”，自由意志是人所遵从的；“察，其所安”，自由意志的当下实践是人所安置的最终归依。 孔子比康德高明的是，他和马克思一样，不会去假设一条从必然到自由的艺术之路，你本自由，何必自由？列宁主义是康德艺术之路的必然延伸，而和马克思无关，和孔子的“圣人之道”更无关。

缠中说禅白话直译
子曰：视，其所以；观，其所由；察，其所安。人焉廋哉？人焉廋哉？
孔子说：认识能力，人的凭借；自由意志，人的遵从；当下直 “观”，即自由意志的当下实践，人的归依。人，哪里有隈曲啊？人，哪里有隈曲啊？

## 33. 子曰：不知，命无以为君子也；不知，礼无以立也；不知，言无以知人也。

这里说的是“不知”的各种后果，“知”，“智”的本字，“不知”，没有智慧。这里的“不知”不单单指个体的人，还指“人不知”的社会本身。“命、礼、言”，都不是一个单纯个体化的现象，在社会化的人类生存中，都与社会本身相关。可惜在腐儒两千多年的折腾下，都将此当成虚头八脑的东西，当成某种先验的东西，完全违背了儒家立足现实的基本立场。

“命”，使命，连道家都可以说“我命由我不由天”，更不用说儒家了。中华文化，对命运的看法从来都比以古希腊悲剧为代表的西学传统看法要正面有力得多。对于个体的人来说，“我命由我不由天”，则“命”只是使命，这个使命不是由上帝选定的，而是由我而来，天地就是我的舞台。 而没有智慧，是不能理解这“我命由我不由天”的，以为我的命运是上天安排的，以为奴隶就只能是奴隶，统治者就只能是统治者，却不知道这一切都是“人所造”的，只有打破了这种所谓的天命、命运的胡言，才会真正承担起人的现实使命，这样才可能成为真正能行“圣人之道”的君子。

“礼”，社会上人与人之间关系的各种底线所构成最基本的社会正常秩序。如果社会上人与人之间没有最低的底线，那么社会就只能是散沙一盘，只可能让位于各种暴力与法律。暴力和法律只是当社会不能正常运行时才需要采取的，一个正常的社会，暴力和法律都是迫不得已的，而没有智慧的人，没有智慧的社会，却只相信暴力和法律，抛弃各种的底线，这样，“礼”是没可能建立的，连接社会人与人之间关系的系统就要破裂，社会也只能在动荡之中。

“言”，言论、舆论，包括社会现实一切言论、舆论。一个没有智慧的人，一个没有智慧的社会，其言论是不足以使人有智慧的，而没有智慧的言论不可能产生智慧，只会继续制造混乱与蠢行。言与行是密切相关的，特别在一个言论传播发达的社会，“言”对人的塑造、对社会的塑造作用，如何评价都不过分。

缠中说禅白话直译
子曰：不知，命无以为君子也。不知，礼无以立也。不知，言无以知人也。
孔子说：没有智慧，不可能承担君子的使命；没有智慧，不可能建立社会正常的秩序；没有智慧，不可能产生使人智慧的言论。

## 34. 子曰：由知、德者，鲜矣！

这里，“由”并不是指孔子学生“子路”，而是“蹈行、践履”的意思，这种用法很常见，如《礼记》“是故隆礼由礼，谓之有方之士”；“知”，“智”的本字，智慧的意思；“德”，行“圣人之道”所得；“鲜”，平声，新鲜、鲜活的意思。“圣人之道”，就是将“人不知”的世界变为“人不愠”世界的道路，这里没有任何固定的模式和先验的走法，路是人走出来的，是人所“由”而来，是人所“蹈行，践履”而来。没有人的“蹈行，践履”，何来路？除了“知、德”，行“圣人之道”的君子无所“蹈行，践履”也无须“蹈行，践履”。

把“人不知”的世界变为“人不愠”的世界，“圣人之道”是无位次的，而“德”因此而有了位次，因此而有所得，该所得就是“德”。而正因为“圣人之道”不是先验的，而是立足于现实之中，因此永远都是新鲜、鲜活的。何谓“鲜”？日日是好日，时时是花时，永远处在一个创新、创造之中，所谓“天行健，君子自强不息”也。 对于“圣人之道”来说，“知”是基础，正如上章所说“不知，命无以为君子也”，没有智慧，不可能承担君子的使命；而君子的使命是什么？就是“闻、见、学、行”“圣人之道”，把“人不知”的世界变为“人不愠”的世界。而“闻、见、学、行”“圣人之道”，不是一个遥远的神话，而是要落实在现实的每个当下，因此而位次，因此而有所“德”。保持其新鲜、其活力，当下活泼泼地呈现，是“闻、见、学、行”“圣人之道”的生命力所在。

缠中说禅白话直译
子曰：由知、德者，鲜矣！
孔子说：蹈行、践履“闻、见、学、行”“圣人之道”智慧、所得的君子，永远处在创新、创造之中啊。

## 35. 子曰：民可，使由之；不可，使知之。

这里，“由”是上一章中“蹈行、践履”的意思，“知”就是上一章中“闻、见、学、行”“圣人之道”的智慧。上一章说“由知、德者，鲜矣“，本章就是顺此而来的。“可”，意思是“适合”，所谓“适合”，就是适合于当下的位次。 “民”，众萌也，民众是一切现实道路的源泉。当某种位次适合于当下民众的现实，就“使由之”，“使之由”的倒装；当某种位次不适合于当下民众的现实，就“使知之”，“使之知”的倒装。“使”，“放纵、任性”，让民众充分发挥他们的潜能、智慧。

明白了上一章的，这一章就很简单了。“闻、见、学、行”“圣人之道”的所得，是所有人的，而不是某些所谓精英的，“由”、“知”，最终都来自于民、归之于民，而民众的创造力是无穷的，民众的智慧也是无穷的，要“使之”，“放纵、任性”他们，放任他们去挥洒他们的潜能与智慧，这样才是真的“闻、见、学、行”“圣人之道”，才会有“闻、见、学、行”“圣人之道”的所得。孔子这一章，两千多年来被曲解不断，对比一下本ID的解释，就知道那些无论反孔还是挺孔的人的无耻与下流了。

缠中说禅白话直译
子曰：民可，使由之；不可，使知之。
孔子说：民众当下适合的，放任民众去蹈行、践履；民众当下不适合的，放任民众运用智慧去创造、创新。

## 36. 子曰：由诲女，知之乎！知之为，知之；不知为，不知；是知也！

关键的问题是“由”究竟指什么？是不是通常所认为的孔子弟子“子路”？在“由知、德者，鲜矣！”一章中，已经否定了“由”指“子路”的一贯说法，本章也如此。关于这点，现给出一个具体的分析。在《论语》中，孔子一贯称呼子路都有一个固定用法，就是“由也”。例如“由也好勇过我，无所取材”、“由也，千乘之国，可使治其赋也，不知其仁也”、“由也果，於从政乎何有？”、“由也升堂矣！未入於室也！”、“片言可以折狱者，其由也与！”等等。而且这种语法现象并不单单用在子路身上，《论语》中孔子也一贯用“回也”称呼颜回，例如“贤哉，回也！”、“回也，非助我者也！”等。特别这一句，把子贡也捎上：“赐也何敢望回？回也闻一以知十，赐也闻一知二。”由此可见，这是《论语》中的标准用法，把“由”当成“子路”，绝对是胡来。还有，“知之”的“之”究竟指什么？通常的翻译都把这“之”给掩掉不翻了，如果真是这样，为什么原文不直接就用“知为知，不知为不知，是知也”？

本章的“由”与“知”，都顺着上一章的“民可，使由之；不可，使知之”而来。“由”，蹈行、践履，用一个更常用的词语，就是“实践”；“诲”，教导；“女”，汝之通假，你的意思，这里泛指一切人类。“知之乎”，“之”，指代“由诲女”，“知之”，以之而智，以实践所教导你而有智慧。“为”，“伪”也。何谓“伪”？非先天，人为也。所有的创造、创新，都是人为，没有人为，何来创造、创新。“为”，就是“由”，就是现实人的现实实践。“知之为”，以知而为，依智慧而实践。“知之”，以之而智，以依智慧而实践所得而有智慧，“之”指代前面的“知之为”，而此智慧，与原来“由诲女”而有的智慧，经过了“知之为”而有所不同，因而是新的智慧，“为”，相对前面的“由”，也是进一步的实践。“不知为”，不以知而为。“是”，复指上文“知之为，知之；不知为，不知。”并对此进行论断及归纳，“这是”、“这就是”的意思。

在“天地人”结构下，道家的“无为”立场，对“人为”抱有极大怀疑。何谓“无为”？无人为也。道家相信“天地人”结构中有一先天自然之道，所以有“人法地，地法天，天法道，道法自然”之论，进而假设人最初的状态最接近自然，因此要返朴归真，要能婴儿，进而要破除一切人为刻意，诸如此类。儒家是不会假设什么先天自然之道的，儒家不相信任何脱离现实的所谓智慧，不相信有什么先天的智慧先验地存在，更不相信只要找到这种智慧就一通百通、成圣成仙。儒家只相信智慧是人为的，是实践的，是实践中来的。

“有为”，儒家的基本立场，就是一切以人类的现实实践为基础，人类的一切智慧离不开人类的现实实践，而现实实践也离不开智慧的总结。在上一章中，强调了“由”与“知”的问题。这一章就是要揭示这两者之间的关系：“由”是“知”的基础，没有“由”，无所谓“知”；但“由”离不开“知”，依“知”而“由”而“为”，才有新“知”，才有创造、创新，而这才是最根本的智慧。 而这最根本的智慧也不是凭空而来的，也是由人的历史实践而有的。而且，这种实践而智慧，智慧而实践的过程就是“易”，就是生生不息的人类生存本身。

缠中说禅白话直译
子曰：由诲女，知之乎！知之为，知之；不知为，不知；是知也。
孔子说：实践教导你，以此而有智慧啊。依智慧而进一步实践，以此而有新的智慧；不依以实践而有的智慧进一步实践，就不会有新的智慧。这，就是最根本的智慧。

## 37. 子曰：我非生而知之者，好古，敏以求之者也。

这一章完全承接上一章而来，上一章更多地站在人类泛指的角度讨论智慧与实践的问题，而这一章，孔子用自己为例子来说明具体的个体如何获得智慧的问题。

“生”，天生、先验的；“之”指代“生”，“知之”，以之而智，依生而智，依天生、先验而有智慧。所谓“好古”，喜爱先哲的遗典、古代的典章等。

“敏”，假借为“拇”，大拇指，转义为“印证”的意思。“好古”不能光从书本到书本，必须在现实的实践中得到“印证”；“求”，选择，“敏以求”，印证并选择。

千百年来，孔子形象被无数腐儒、反儒者有意无意地歪曲；千百年来，关于孔子泥古、复古的谎话成了腐儒、反儒口中的真理。而在《论语》中，孔子以自己为例子明明白白地表述了对“古”的观点，就是要“敏以求之”，“之”指代“古”，要对“古”印证并选择，这才是孔子对“古”的真实态度。在上一章，孔子已经明确表示智慧来自于实践，而在这一章里，孔子更明确指出，对先哲的遗典、古代的典章等要印证并选择，而印证、选择都离不开当下人的实践，只有这样，才算真的“好古”。

本章，孔子提出了学习前人知识、智慧的三个步骤：好、敏、求。 首先，对前人知识、智慧所凝结成的遗典、典章等必须尊重、善待进而学习、研究，才谈得上“好”。尊重、善待进而学习、研究，真正把握以后，还需要在实践中继续印证，这才是“敏”。“敏”，有两层的含义：其一，前人知识、智慧都来源于其当下的实践，而时代变化了，条件变化了，其应用可能要失效，可能有所改变，这必须在实践中才能印证、发现；其二，对前人知识、智慧的把握，特别对于那些洞穿时间的智慧的把握，必须在实践中慢慢体会、摸索，才能发现前人的真义，决不能像某些人对待孔子、马克思那样，根本没弄明白就扮代表，这样是谈不上“好”，更谈不上“敏”了。有了印证，自然就有了选择的基础，选择不是机械地挑选，不是用对错等简单标准来划分，而是根据当下的实践有机地发展、延伸，这样才不辜负古人，也不辜负自己，这才算得上是“求”。

缠中说禅白话直译
子曰：我非生而知之者，好古，敏以求之者也。
孔子说：我不是天生、先验地依赖天生、先验而有智慧的人，只是爱好学习、研究先哲遗典、古代典章，并在实践中对此印证、选择的人。

## 38. 孔子曰∶生而知之者，上也；学而知之者，次也；困而学之，又其次也。困而不学，民斯为下矣！

人，生不离困。生存之困、生死之困，诸如此类，解其困，只能依靠智慧，没有智慧，困而不知其困、不知其何以困，更不知何以出其困。何谓“困”？“梱”的本字，门槛的意思，借代为门，所谓分门别类，无门而门，无位次而有其位次，因此有其“困”。但此“困”，有客观的，如人一生下来，就首先入了“人”这个门，当时的社会环境、人的身体智力等都成了任何个体不可逃避之“门”；还有主观的，如自设门户、画地为牢而自困。要破其“困”、其“捆”、其门，对人来说，从实践而得的智慧以及依智慧而去的实践，是唯一可能依靠的。

而如何得到智慧？前面几章，孔子已经指出智慧来自实践，而对于个体来说，学习前人智慧的结晶是一个最基础的实践过程，“好、敏、求”就是学习前人智慧的三大步骤。孔子说自己“非生而知之者”，但这里却说“生而知之者，上也”，是否矛盾？其实，这正好反映了孔子、《论语》的严谨。孔子并不绝对地否定“生而知之”的可能，因为如果绝对地否定，那这个否定就成了一个先验的命题，这显然和孔子注重实践、注重有为的思想相背离。其实，孔子这种类似观点，在他对鬼神等态度上同样有所反映。孔子并不绝对地否定鬼神等的存在，并不绝对地认为“鬼神的绝对不存在是一个不可改变的真理”。孔子只承认因为“生而知之”、鬼神等超出了当下实践而有的智慧所能解决的范围，因此就存疑、就少谈、就敬而远之，但并不排除其存在，以及在以后的实践而有的智慧中得到解决的可能。孔子的这种态度，比那些所谓的唯物主义者要客观的多。

那么，“生而知之”能否存在？站在纯技术的一个很简单的例子，也不用借助什么鬼神。例如，哪天人类对思维的秘密最终把握了，对人类大脑记忆的秘密把握了，就完全可以使得人“生而知之”。比如对受精卵实施一些程序，把缠中说禅解释的《论语》、缠中说禅教你炒股票等等一脑儿填进去，让那小孩一出来就可以炒股票、说论语，这大概也没什么可奇怪的。对于类似的情况，孔子说是“上也”。“上”，并不是人等级上的区别，更不是宣扬任何天才论，这里的“者“字，也并非如同上面三人以及通常所理解的指的是“人”，把这里的“者”字当“人”解释，不过玩弄精英自以为精英的把戏。把人先验、先天地分为三六九等，是典型的胡扯。而且，也解释不了为什么后面的“困而学之”与“困而不学”不带“者”字，难道后面就不指“人”？这里的“者”，其实只是语气词，“生而知之”、“学而知之者”、“困而学之”、“困而不学”只不过是四种人生的可能情况，和人的三六九等无关。主观上把人分为三六九等，就是自设其门，就是自“困”；而历史现实中，人确实有三六九等，这就是历史现实客观的“困”，是必须解之的。

显然，人的最好可能就是“生而知之”，但对于孔子来说，“生而知之”超出当下，“学而知之”才最切合当下。学，首先要对其困有所认识，更认识到去其困必假以学，因此“困而学之”，进而“学而知之”，才能以智慧解其困。“困而不学”，就会出现“民斯为下矣”。而“民斯为下矣”，也就是因为“困而不学”。没有人天生愿意落入“困而不学”的可能而不能自拔的，“困而不学”往往不是因为其惰性，而是社会的环境，特别在孔子时代，“学”被所谓的精英贵族所霸占，“困而不学”，实质是“被其困而不能学”，历史现实把社会上的人分为三六九等，使得“民”得不到“学”的条件。孔子并不先验、抽象地谈论个体如何得到智慧的问题，个体，必须生活在现实的社会结构之中，“学而知之”并不先验地适用于所有人，因为个体的现实性往往使得人只能“困而学之”，甚至“困而不学”。

在历史现实中，人必须得其“学”才能解其困。这个解其“困”有两个含义，一个是解一种客观条件制造的“困”，一个是意识形态所制造的“困”，因此“学”成为每个人的现实生存最重要的前提条件。一个让人“困而不能学”的社会是丑陋的、卑劣的，必须要改造之。孔子注重教育，主张“有教无类”，是与此密切相关的。所有把“困而不学”当成某种类型人的，都无法解释后面这句“民斯为下矣”，这里为什么无端多了个“民”字？上面的钱、李，就干脆把这个“民”给私吞了，不翻了，这显然不是严肃的态度，自己都搞不清楚，有什么资格出书，现在的垃圾书骗人，大多如此。而杨就更无耻了，竟然硬污蔑孔子认为“遇见困难而不学，老百姓就是这种最下等的了”，所有通过歪曲孔子而反孔的，都如此卑鄙。

圣人之道，就是把“人不知”改造成“人不愠”，而现实中，最切实的就是“学而知之”。但“人不知”社会最大的特点就是自设其“困”，把人先验、先天地分为三六九等。马克思说人的全面发展，何谓全面发展？首先就要无其“困”，反对把人先验、先天地分为三六九等，无论这种分类的基于人的智力、出身、社会分工、阶级地位等等。社会分工，是“困”；官和民，也是“困”；阶级，是“困”；智力水平，也是其“困”。

在“人不知”社会里，“困”就是根本之相，有其“困”必有其“愠”，必须“不相”之，才可能把“人不知”社会改造成“人不愠”社会。而相应的社会改造，首先要把“困而不学”社会状态改造成“困而学之”的社会状态，才可能达到“学而知之”的社会状态，然后才有可能使得所有人都能全面地发展，才可能使得所有人有“生而知之”的可能，才有可能成为“人不愠”的社会。否则，即使科学上使得人可以“生而知之”了，但社会结构上的“困”也只能使得这种科学更加深社会结构之“困”，对于人类社会来说，技术科学只能是手段，要实现“人不愠”的社会，必须从改造其“困”开始。

缠中说禅白话直译
孔子曰∶生而知之者，上也；学而知之者，次也；困而学之，又其次也。困而不学，民斯为下矣！
孔子说：所有人，天生地依赖天生而有智慧，是最好的；所有人，都能自由地学习且通过学习而有智慧，是稍差的；所有人，被分为不同类别而得到不同类别的学习，是更差的。所有人，被分为不同类别而某类人得不到学习的机会，这就是民众被当成卑下的原因啊。

## 39. 子曰：盖有不知而作之者，我无是也。多闻，择其善者而从之；多见而识之；知之次也。

本章承上几章而来，难点在于“次”字。“次”，本义是临时驻扎和住宿。在古代，军队在一处停留三宿以上叫“次”。“知之次”，直解就是智慧的临时驻扎和住宿，这里把寻求智慧的过程比喻成行军，“多闻，择其善者而从之；多见而识之”就如同行军中的临时驻扎和住宿，但都不是智慧的最终目的。现实智慧的最终目的只有一个，就是把“人不知”变成“人不愠”。这站在社会发展的层面是如此，站在个人修养的层面亦如此。一个“不知”的人是不可能“不愠”的，即使对于个体来说，“不愠”也是一个很高的人生境界。 但智慧，如同过河之筏，没有智慧不行，以智慧为有所得、有所恃也不行。而真正有智慧的人，也不会以智慧为有所得、有所恃，更不会把智慧之皮毛、那些通常被成为知识的玩意当成有所得、有所恃。

“盖有不知而作之者”，所谓“盖有”，就是大概存在，这和孔子对待“生而知之者”的态度是一样，不绝对地否认其存在。“不知而作之者”，就是没有智慧却凭没有智慧而有所作为的人。孔子说这种人大概会有，那究竟有没有呢？其实，现实中有的可能性几乎可以忽略。有人反驳说，那韦小宝算不算？站在知识分子或腐儒的角度，韦小宝当然只能算是流氓，怎么会有智慧？但站在另一角度，韦小宝又何尝没有智慧？在现实中，那些能成点事的人，如果不带有色眼镜，哪个不有点小聪明？当然，可以说聪明不等于智慧，但如果聪明都谈不上，就更别说什么智慧了。大智如愚，说的是其表面，而不是指其内心，更不是说表现得越愚蠢的越有智慧。所谓的正人君子爱说那些都是旁门左道，但干旁门左道的人多了去了，怎么只有少数的成功者？没有“知”，旁门左道也干不好的；而没有“知”，所谓的正道也是战胜不了旁门左道的。用苍白的正义必将战胜邪恶为自己壮胆或忽悠别人去卖命是没用的，历史的经验却一再证明，许多先前的旁门左道最终都成了康庄大道，而所有的所谓正道，都有着旁门左道的历史，对此，正人君子又能有什么解释呢？

“我无是也”，孔子说自己不是这样的，不是“不知而作之者”那样的，那究竟怎样？“多闻，择其善者而从之；多见而识之”，这与上面所说的“好、敏、求”是一回事情，“多闻、多见”，就包括了“好”与“敏”，如果没有“好”，就不可能“多”，而“闻”、“见”都是有所印证的，都离不开“敏”。“择”，“识”就是“求”，识别、选择的结果就要“从之”，根据选择的采取某种办法或原则，真正的“从之”，就是从现实逻辑出发分析、解决问题，最后实现对现实以及其逻辑关系的改造与革命。必须强调的是，“善者”，不能按道德主义的角度来理解，“善者”不一定是“好人”，“好人”也不一定是“善者”，何谓“善者”？在任何方面有超过自己见识、能力的，都是“善者”。以这个角度看，世人无一不是“善者”；但没有人是全能的，没有人是所谓的上帝，任何人都有其“不善”的方面。所以要依其见解不依其人，这才是“从之”，也就是“从善者”之“善道”。

上一章说了，“学而知之”，而“多闻”是“学”的最重要前提。没有“多闻”，就只能是井底观天之辈。但更重要的是，社会必须提供一种能够“多闻”的环境，如果全社会只有一种观点、一种思想，那如何能“多闻”？观点、思想的多样化，反而不会让人无所适从，而是人能最终智慧的最基本起点。注意，观点、思想的多元化，并不意味着就一定有“多闻”的条件，例如在资本主义社会，一切的观点、思想后面都有一只无形的手在控制着，一切违背资本的话语，很难在被资本所完全控制的渠道中得到放大，这种所谓的多元，其实也不过是皇帝的新衣。“人不知”的社会，最基本之一的就是在“闻”上的“不多”，而要改变“人不知”的社会，就要首先从“多闻”下手，不仅要“不相”一切对“多闻”的有形控制，更要“不相”一切对“多闻”的无形控制。否则，在资本、市场所控制的社会里，一切的“多闻”都只能是把戏。

“多闻”了，才有“择其善者而从之”的可能，而只有如此，才可能“多见”，“见”，不是表面化的见闻，而是经过自己的思考、比较、研究、实践后才形成的见识。 一个喧哗的时代，可能是“多闻“的，但不大可能是“多见”的，因为所谓的“见”，都是人云亦云，都是东抄西剽，而一个“不多见“的社会、时代，是没有创造力的，更不可能脱离“不知”。见解，不等于见识，其见通透了，才有其识，否则不过是盲人说象，瞎掰而已。而有了自己的见识，进而“多”，见识进而深厚后，才可以“识”。这里的“识”，不单指自己的见识之“识”，那只是书本上的，静态的东西，真正的“识”，要走出去，要真刀真枪地去辨别，更重要的是要去辩正，在“入世”中磨练，这样才会有真正的“识”。

缠中说禅白话直译
子曰∶盖有不知而作之者，我无是也。多闻，择其善者而从之；多见而识之；知之次也。
孔子说：大概存在没有智慧却凭没有智慧而有所作为的人，我不是这样的。在一个能让每个人都能自由见闻的社会里，尽可能地扩展自己的见闻，选择超过自己的见解，依据其见解而不是依据有此见解的人或群体，深入探讨、吸收学习；进而让自己的见识逐步深厚，才能更清楚地去辨别、辩正各种知识的真伪、深浅。但这些都是智慧的临时落脚处，不是智慧的真正所在。

## 40. 子张学干禄。子曰：多闻阙疑，慎言其余，则寡尤。多见阙殆，慎行其余，则寡悔。言寡尤，行寡悔，禄在其中矣。

本章难点在“禄”字，“禄”的本义是“福气、福运”，《说文》：“禄，福也”，而《诗经》也有“天被尔禄”。这是当时的人普遍想法，“禄”是上天施与的。其实，直到今天，这也是中国人的普遍想法，否则看相算命之类就不会如此长盛不衰。站在文化类型的角度，人类社会最早的文化类型是所谓的“巫文化”，像“天被尔禄”，就是典型的“巫文化”，而孔子这里所打破的，正是这种“巫文化”的逻辑。但实际的中国历史，传承的却不是孔子的，而是用“巫文化”所改头换脸的孔子。孔子所反对的，最后却被包装成孔子，这在世界历史上却不是一个特殊的现象，马克思的遭遇就更现代、更惨烈了。伟大的思想，最终的命运都逃不过这种改装，但伟大的思想是无法最终改装的，这同样是历史的常态：伟大的思想总要“春光乍泄”。

子张，孔子晚年的学生，他来孔子这里，希望“学干禄”，也就是学习如何求得福气、福运。“干”，平声，“求取”的意思。在“人不知”的现实社会生存，永远离不开的，就是这个“干”。能“干”所“干”的，最重要的就是所谓“名”、“利”两字。这两字，无人能逃，而两者互相依存，一般人所谓的好福气、好运气，也离不开这得“名”得“利”。有号称不要“名”、“利”的，基本都为“干”的失败者，失败了，就逃，最终得一个看破“名利”的虚名，还是在“名利”之中。

孔子生活在现实之中，当然不会虚伪地逃避现实的“名、利”。但站在孔子的角度，他“干”的是“大名、大利”之“禄”，何谓“大名、大利”？就是“圣人之道”，就是把“人不知”的世界改造成“人不愠”的世界，这才是真正的“名、利”，也才是真正的“禄”，真正的福气、福运，这才是全人类真正的幸福。当然，子张要问的，只是个体的福气问题，这对于任何人来说，都是一个最重要的问题之一了，没有人真正希望自己没有福气、福运的，就算是有被虐倾向的人，也有他的福气、福运，对他来说，能让他很爽地被虐，就是福气、福运了。因此，如何能“干禄”，这是个体生存必须要解决的问题。当然，对于国家、社会，其道理是一样的。

孔子的回答，完全不涉及“巫文化”的“天被尔禄”。有人可能要反驳说，《诗经》是孔子编撰的，如果孔子并不同意这种思想，为什么会保留“天被尔禄”相关的诗。这种问题根本不是问题，就像本ID现在解释孔子，并不是说孔子的境界就是本ID的境界。本ID多次说过，孔子、马克思都不是究竟，但如果你连孔子、马克思都搞不明白，就更无法究竟。在人类所有的思想中，孔子、马克思是有史以来最高的了，必须先把握他们才能论及其余。但别以为这就是禅，这就是本ID的思想，和这个毫无关涉。本ID就是看到从来没人能真正理解孔子，都是曲解，所以才费这工夫写写孔子的事情，但这和本ID又有什么交涉？孔子、马克思又怎能明白本ID的境界？同样道理，孔子当然可能编撰与“天被尔禄”相关的诗，但“天被尔禄”的“巫文化”玩意，又如何能明白孔子的境界？

其实孔子的回答，完全从上章而来，“多闻”、“多见”，这都是智慧的前提。孔子的话，简单概括，就是“福智两全”。“阙”，去除；“尤”，过失；“殆”，危险；“悔”，过失。“言寡尤，行寡悔”是典型的互文，就是“言行都少过失”的意思，把“悔”解释成“后悔、懊悔”等，是不明白互文的语法功能。“多闻阙疑”，见闻广泛从而去除疑惑；“多见阙殆”，见识深厚从而去除危险。既然疑惑、危险都去除了，为什么还要“慎言其余”、“慎行其余”？其实，没有疑惑才是真正的大疑惑，人的言行，有哪个不是自以为很有把握才言行的？人的失败，总是在其最有把握、毫无疑惑的地方；而自以为没有危险才是最大的危险，这一点就更容易理解了。疑惑、危险，对于人生来说是“不患”的，是没有位次的，人生就是充满疑惑、危险的。人的生命，如风中烛，随时随地都可以被吹灭，至于人的疑惑，那就更多了，随时随地都在两难之中。“疑”、“殆”，都是“不患”的，正因为“疑”、“殆”的无位次，才有“阙疑”、“阙殆”的位次。但这位次之“患”，如沧海之浮沤，而“其余”是沧海，“不患”的“疑”、“殆”是沧海，因此只能够“慎言其余”、“慎行其余”。

“慎”，一般都解释成“谨慎”？那什么是“谨慎”？哈姆雷特那样算不算？如果是个大傻瓜，无论如何地谨慎言行，还是大傻瓜。谨慎是与所在位次相关的，有如此的见闻、如此的见识，才有如此的谨慎，如此就是位次。 “慎”，通“顺”，“遵循”的意思，该种用法在先秦时代十分常见，例如在《墨子》、《荀子》、《管子》、《韩非子》里都有。“遵循”什么？就是“多闻”所闻、“多见”所见。人的一切，只能从现实出发，只能从现实当下的位次出发，而现实当下的位次不是凭空而来的，自“闻”所闻、自“见”所见。但“闻”、“见”必须“多”，才可能“慎”，否则不过是人云亦云、人行亦行而已。

而“言行其余”，离不开“闻见”的位次，有如此“闻见”，方有如此“言行”。“多闻见”，然后才能“慎言行”；在“多闻见”基础上的“慎言行”，才可能“寡尤悔”，才可能“禄在其中矣”。 在孔子这里，人之“禄”源自人之“言行”，而非“天被”。“人”，包括类与社会以及个体意义上的人。人类的福祸、人类社会的福祸、个人的福祸，国家的福祸，都是自己的言行造成的。要“干”其“禄”，孔子指出了其中唯一现实的可能，就是：多闻见、慎言行、寡尤悔。遵循这九个字切实下去，才可能成就“福智两全”。“福”之“全”离不开“智”之“全”，而“智”没有“福”之“全”，只是苍白之智，无补于事。

缠中说禅白话直译
子张学干禄。子曰：多闻阙疑，慎言其余，则寡尤。多见阙殆，慎行其余，则寡悔。言寡尤，行寡悔，禄在其中矣。
孔子说：子张求问获取福运的方法。孔子说：见闻广泛而去除疑惑，见识深厚而去除危险，遵循如此“闻见”而如此“言行”，那么言行都会少过失。言行少过失，福运在其中啊。

## 41. 子曰∶君子谋道不谋食。耕也，馁在其中矣；学也，禄在其中矣。君子忧道不忧贫。

在“道，不同、不相为谋”一章里，本ID有这样的话：““谋”，就是“征求解决疑难的意见或办法”，引申为“谋划、商量办法”等，《论语》后面还有所谓“谋道”、“谋食”的说法，和这里的“谋”是一致的。”正如这段话所指出的，本章的“谋”，不是通常所理解的“营求”，而是指“谋划”。对于人来说，所有的行为、思想、欲望，背后都有一定的“谋划”、“意向”模式，孔子对这些模式进行高度的总结，划分为两种：道之谋与食之谋。这是人类所有欲望、思想、行为等的两种最根本模式。

何谓“食之谋”？就是“馁、耕、食”三位一体。“馁”，饥饿，馁”了，就要“耕”，天上不能掉馅饼，这样就必然有物质的生产、进而有社会的分工、最终形成一定的经济基础与上层建筑所构成的社会结构。“耕”了，才能“食”，这个“食”的分配问题，就成了所有阶级社会的核心问题。 “馁、耕、食”，概括了“人不知”社会一切的行为模式，所有与“人不知”社会相关的理论、实践，都离不开这个模式。

孔子的深刻还不在于仅仅指出了“人不知”社会的这种必然模式，而在于明确指出“耕也，馁在其中矣”。本来，因为“馁”、所以“耕”，但在“人不知”的社会里，“耕”却不能消灭“馁”，反而要不断产生“馁”。 这里有两种含义：其一， “馁”产生一定的“耕”，相应又激发出新的“馁”，生产力的发展更激发起人类新的欲望，“得陇望蜀”，人类的欲望不断延伸，人类的创造力也不断延伸，人类生产力更不断延伸，这不断构成人的类层面上“馁、耕、食”的恶性循环；其二，一定的“耕”所决定的生产关系下，相应产生“食”的一定分配模式，使得相对的“馁”成为“人不知”社会的常态，“耕”的发展、生产力的发展往往不能消灭“馁”，反而是不断制造“馁”，这构成了人的社会层面上“馁、耕、食”的恶性循环。

对以上两个恶性循环，孔子都是坚决反对的。第一个恶性循环，涉及的是人与自然的关系，该循环之所以是恶性的，就是其对应着一个荒谬的前提：在自然与人的关系中，自然有无限的空间允许人的欲望无限地膨胀，相应地，生产力可以无限发展，物质可以无限可分，人类被假设成一个只要给予足够时间，就可以无所不能的“准上帝”。这样的假设，其荒谬性已经在人类的实践中被不断证明，而孔子在2000多年前已经明确指出。第二个恶性循环，涉及的是人与社会的关系，在那种荒谬地假设所谓“看不见的手”的理论里，“耕”成为了新的“准上帝”。

孔子明确地反对这两种荒谬的逻辑，明确地反对各种“上帝”、“准上帝”的思维、行为、社会模式。孔子明确指出，“馁、耕、食”的“食之谋”，必然导致“人不知”社会的恶性循环。 孔子提出的是“君子谋道不谋食”，“闻、见、学、行”“圣人之道”的人，首先就要打破这种荒谬的“食之谋”，从而彰显“道之谋”。何谓“道之谋”？“道，不同、不相为谋”也，对“馁、耕、食”的“食之谋”“不同、不相”也。“道之谋”，不离“闻、见、学、行”，前几章已经反复强调“多闻”、“多见”的重要，“闻、见”是“学”的基础，没有“闻、见”，就无所谓“学”，而没有“学”，就无所谓“行”。在第二章里，明确指出了“学”包含两个不能偏废的方面：1、对照；2、校对。而这个对照、校对，都是在“闻、见”的基础上，都是在现实的基础上。“闻、见”之“多”，归根结底不离人与自然以及人与人这两个方面，那种从“馁”出发的“闻、见”，是不可能“多”的。要“多闻、多见”，进而能真正地“学”，真正地面对现实进行对照、校对，前提是对“馁”的“不同、不相”。

如果每个人都有一个共同方向无限扩张的“馁”之分量，那么，无论人类社会如何改朝换代，这总和之中，以“馁”为基础的“馁、耕、食”模式就不可能改变。要改变这种模式，就必须要对“馁” “不同、不相”。注意，这里并不是要鼓吹禁欲，而是要在人与自然的关系中，通过对自然以及自然与人关系的“多闻、多见”，使得能通过相应的“学、行”去把人类的“馁”“对照、校对”在一个自然与人的现实关系能允许的范围内。 人的自觉，首先是对人之“馁”的自觉，因为不自觉、无限制的“馁”只能导致人的灭亡，而人的存在是一切关于人的理论、实践的唯一前提，没有这个前提，一个理论、实践都是废话。

但对“馁” 的“不同、不相”，不是要去制造什么新人，不是要去延续那些灵魂改造的闹剧。所有关于人性改造的谎言与妄行，都有着人性存在先验性的荒谬前提。人之“馁”，并不是先验存在的，并不是“不患”的，而是有其位次的，是在人与自然以及人与人的现实关系中不断位次的，只要这种现实关系存在着，人之“馁”就会不断产生。需要改造的是现实本身，而不是人本身。 由此可见，任何以国民性、人性、灵魂改造为前提的，其实质就是不敢去触动或变相保护真正根本的现实利益。而不从“耕、食”出发，不对“耕、食”进行“不同、不相”，不可能有真正的对“馁” 的“不同、不相”。

“耕、食”关系中，在现实中，最根本地，就是显示出相应生产力与生产关系以及相应的分配制度。而站在人的社会层面，分配制度是最关键的。“民以食为天”，这里，不单单指“吃”相关的“食”，更指一切与人的欲望满足相关的“食”，以及一切相关的分配制度。 前面的分析里已经详细说明，以“馁”为基础的“耕”，必然导致“馁”的常态，从而延续、扩大“馁、耕、食”的恶性循环，而以“耕”为基础的“食”，同样如此。“耕”为基础的“食”，也就是生产关系决定分配关系，在生产中占有主导地位的决定了分配中的主导地位，这里就关系到生产资料的私有制关系，私有制必然导致拥有生产资料的一方在分配中拥有统治的地位，从而导致在社会层面，阶级性的“馁”的必然存在。所谓阶级，归根结底是由生产资料的私有关系所决定的。因此，要打破这种社会层面的“馁、耕、食”的恶性循环，必须对“耕、食”进行“不同、不相”，而其中的关键，就是对“耕”中的生产资料的私有制关系进行“不同、不相”。

对“馁、耕、食”的恶性循环进行“不同、不相”，就是要将之改造成一个良性的循环。在人的现实存在中，“馁、耕、食”是不能改变的，“道之谋”是不能脱离“食之谋”的，否则，所谓的“不同、不相”就是自立其相了。正因为有“馁、耕、食”恶性循环之相，才有“道之谋”的“不同、不相”。这里，必须在“多闻”、“多见”的基础上“对照、校对”人与自然关系的现实所“需”，按照这个所“需”来确定“食”的分配，由此分配而确定其“耕”，从而构成人的现实之“馁”。也就是说，“闻、见、学、行”“圣人之道”的君子，就是要把“馁、耕、食”的“食之道”恶性循环通过“不同、不相”反过来，形成“食、耕、馁”的良性循环。人的自觉，人类的自觉，就在于对现实之“需”的“闻、见、学、行”上。

以欲望、以“馁”决定所“需”的，不过如禽兽、畜生，而人之“需”，必须首先要成为“人”，成为“天地人”结构中的“人”，成为“天地之心”，这样才资格成为真正的人。在“天地人”结构中，人之“需”的确定，只能在对人与“天地”关系的“闻、见、学、行”中进行，而这个确立，是“不患”而有其位次的。因为对于“人”的存在来说，有一点是“不患”的，就是“人”必然在世界中存在，必然在“天地”中存在，人存在的状态，必然在“人”与“天地”的结构关系中得到确立，这种确立是“不患”的，无论人类是否自觉，这个“不患”是无可改变的，除非人类有一天可以不在“天地”中存在。而自觉的人类，会在这“不患”中变其位次，从而使其所“需”也因此而位次，这就有了“食、耕、馁”不同位次的良性循环。所谓的解决，并不是停止不前，反而是一个真正的开始，一个人与自然、人与社会良性循环的真正开始，这也才是孔子、儒学站在“天地人”结构中所说的真正的“和谐”。

所以，孔子说“学也，禄在其中矣”，这个“学”，这个“天地人”结构中人自觉的对照、校对，是“闻、见、学、行”“圣人之道”的关键所在，“多闻、多见”，归根结底是为了“学”，而“学”的目的是为了“行”。而人类真正的幸福，真正的“禄”，就在“学”之中。因此，“君子忧道不忧贫”。所谓“贫”，无论是物质还是精神的，归根结底就是“馁、耕、食”恶性循环的必然结果，在此间打转，是不能打破的，担忧也没用。在“食之谋”打转是没用的，必须“闻、见、学、行”“道之谋”，把“馁、耕、食”的恶性循环“不同、不相”为“食、耕、馁”的良性循环，才是真正的解决。

缠中说禅白话直译
子曰∶君子谋道不谋食。耕也，馁在其中矣；学也，禄在其中矣。君子忧道不忧贫。
孔子说：“闻、见、学、行”“圣人之道”的君子，按“道之谋”谋划而不按“食之谋”谋划。以人的欲望饥饿为基础的生产，新的欲望饥饿就在其中啊；以人与天地关系中对照、校对确定人之所需，福运、真正的幸福就在其中啊。君子只担忧如何“闻、见、学、行”“圣人之道”的“道之谋”，而不担忧“馁、耕、食” “食之谋”的恶性循环必然导致的人在物质与精神上的贫穷。

## 42. 子曰：君子不器。

何谓“器”？《易·系辞》：“形乃谓之器。”，“器”就是“形”；何谓“形”？“形”，就是“相”。 何谓“君子不器”？就是“君子不相”。“道，不同、不相为谋”，要“闻、见、学、行”“圣人之道”的君子，就要“闻、见、学、行”“不相”之谋。

缠中说禅白话直译
子曰∶君子不器。
孔子说：君子不相。

## 43. 子曰：古之学者为己；今之学者为人。

“内圣外王”本是一体，内不圣的外王哪能持久？外不王的内圣顶个屁用！所谓“学”？是“多闻”、“多见”基础上的“对照、校对”，不离“天地人”间的大易流行。 “为己”、“为人”，最终都要成就“内圣外王”，岂能将“为己”、“为人”割裂？单纯“为己”与单纯“为人”，同样只能制造“馁、耕、食”的恶性循环。

从语法上看，本章是明显的互文，古文中，为了语言的流畅与对称，这十分常用。这里，无须追究所谓蛋与鸡的关系，无须追究究竟是“为己而为人”还是“为人而为己”，归根结底，都是“内圣外王”、“为己为人”一体。这，无古今之别，离此之学，只能是伪学，不可能是真正的学问。

缠中说禅白话直译
子曰：古之学者为己；今之学者为人。
孔子说：无论古今，真正的学问与学人，都不离“内圣外王”、“为己为人”的一体之学。

## 44. 子曰：三年学不至，於榖不易，得也。

何谓“至”，就是尽善尽美，“不至”，就是没有达到尽善尽美。 上章中孔子说：“无论古今，真正的学问与学人，都不离“内圣外王”、“为己为人”的一体之学”。这种学问，不单单是书本上的，更重要的是在当下的实践中对照、校对。因此，三年学而达到尽善尽美是不可能的，那么这算不算一事无成呢？孔子不认为这样，只要能“於谷不易”，就算有所得了。

何谓“於榖不易”？“榖”，由于现在用简体字，都写成“谷”，就和山谷的“谷”给混在一起了。而通常把这里的“榖”解释成粮食的总称，进而引申为俸榖。其实，这里的“榖”应该解释为“生、活着”的意思。《诗经》里有“榖则异室，死则同穴”，就是这个意思。“於榖不易”，就是只要活着就不改变，一生不变，“易”是改变的意思。

“学”，有一个退转的问题。“三年”，只是一个约数，不是实指三年，三五年、或七八年，甚至三、四十年，很多人的“学”就全变了，为什么？因为他没有达到不退转的地步，为五斗米折腰去了、为名色折腾去了、为新嘲玩意忽悠去了，他的学，并没有一个不退转的根基，风向一变、环境一变，全变了。学，虽然还不能尽善尽美，但在根本上透脱了，在根本上通达了，才有可能不退转，才可能“於榖不易”，这种状态，是“学”的一个重要的位次，是学有所成了，所以是“得也”。而没达到这种对“圣人之道”之“学”不退转、“於榖不易”的状态，是不能算“得也”的。

缠中说禅白话直译
子曰：三年学不至，於榖不易，得也。
孔子说：多年闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”，虽然不能达到尽善尽美，但能对“圣人之道”的“学”达到一生不退转的位次，这才算是“学”有所得啊。

## 45. 子曰：学如不及，犹恐失之。

《广雅》有“及，至也”，“不及”，就是上章的“不至”；“如”，而，表示连接；“学如不及”，学如不至，对照、校对“圣人之道”进行学习而不能达到尽善尽美，为什么这样？因为“犹恐失之”。“犹”，不是通常所解释的连词，而是“踌躇疑惧”的意思， 《老子》有“犹兮若畏四邻”；“恐”，恐惧、疑虑；“失之”，使之失，之，指代“学”；“犹恐失之”，踌躇、恐惧、疑虑使“学”迷失，因此达不到尽善尽美。

“学”，最经常的状态其实就是踌躇、恐惧、疑虑，特别面对各种的理论、情况，众声喧哗，没有足够的智慧去辨别，左右为难、进退维谷、患得患失，不能悬崖撒手、直下承担，归根结底就是不敢承担。承担什么？承担这个天地，人，天地之心；天地，人之躯壳，你连自己的躯壳都不能承担，你还能算是人吗？承担，就是《论语》、也是儒学的真精神。”

《易经》有“天行键，君子以自强不息；地势坤，君子以厚德载物”，人以天地为“学”，对照、校对，不光光如现在的所谓实用科学般只在表面上打转，更不能如思辩哲学般凭空预设些先验前提，而是直下承担，天地之德，最直观、最当下的，就是“天之不息、地之载物”，任何科学、哲学，都不能违背这最直下的现实逻辑，这就是儒学之“学”所对照、所校对、所承担的。而人的现实存在，个体的现实存在，同样是儒学之“学”所对照、所校对、所承担的。放弃了承担，把承担归置到虚幻的上帝式前提上，都是没有智慧从而踌躇、恐惧、疑虑所致。任何缺乏人的现实承担之“学”，都只能是小人之“学”，而不是儒家的君子之“学”、圣人之“学”。何谓“小人”？因没有智慧而踌躇、恐惧、疑虑，令顶天立地的“人”为之而小者。人之小，皆自小之，小人逃避承担、敷衍承担，最终还是在承担之中，因为承担是“不患”的，不管是直面还是逃避，承担都是现实存在的。

承担，最重要的就是承担这个人之生死、人所有的错误与罪恶。学，为什么会有踌躇、恐惧、疑虑？就是企图要去证明自己的正确，企图要去找一条所谓永远正确的道路。但天地就是你的，天地里的道路都是你的道路，如果不去走，如果没人去走，怎么知道是错误的？任何的道路，都只能是人走出来的，在没走之前，又有谁有资格当上帝去宣告其对错？儒学，不是要给一个所谓正确的标准来规划天地，而是要“行之”，而是要承担。任何的智慧，必须以承担为前提，没有承担，是不会有任何智慧可言的。尽善尽美，不是一个固定的、先验状态，归根结底，就是承担本身。只有智者、仁者、勇者，才会有真正的承担，这才是真正的大智、大仁、大勇。

缠中说禅白话直译
子曰：学如不及，犹恐失之。
孔子说：闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”而不能达到尽善尽美，是因为踌躇、恐惧、疑虑使它迷失而不能直下承担。

## 46. 子曰：学而不思则罔，思而不学则殆。

这是比康德“感性无知性则盲，知性无感性则空”更彻底穷源的一章。“学”，闻“圣人之道”、见“圣人之道”、“对照”“圣人”、在现实社会中不断地“校对”，这是以差异性为前提的； 而“思”，《说文》有“思，容也”，“容”，离不开一定的范式，例如一个筛子，对水来说就不是“容”的，还有所谓不可思议，相应的潜台词就是“可思”有一个潜在的标准，超过这标准的，就被当成不可思议了。“思”的前提在于同一性，例如，能被欧氏几何所“思”，那其潜台词就是对象运动的刚体性在所“思”的对象中具有同一性，因此才会有把所有边长相等的正方形当成一样的可能。如果没有“同一性”，一切科学都是不可思的，例如物理，一个最简单的同一性例子就是在狭义相对论里，任何惯性系都被看成同一的，如果没有这同一性的要求，狭义相对论根本无法展开。在哲学里，就算是以重整形而上学为己任的海德格尔，其存在之“思”，也摆脱不了某种“同一性”的潜台词。

对于以差异性为前提的“学”与以同一性为前提的“思”，孔子的见解与德里达有相通的地方。德里达那里，差异性与同一性纠缠在延异之中，同时在场或缺席，在延异中不可能纯粹地分解或确立差异性与同一性，也不可能由差异性与同一性构造或结构出延异，这与“合二为一”或“一分为二”的胡诌辩证法没任何关系。

“学而不思则罔，思而不学则殆”是典型的互文，求所谓“学而不思”、“思而不学”，都只能迷惘、疲怠而无所得。“学”与“思”，当下地纠缠一起不可分。 任何的“学”，都以同一性的“思”为前提，这一点，连康德都很清楚，如果没有“思”的某种前提性结构，“学”是不可能的；而任何的“思”，都以差异性的“学”为前提，这一点就不是康德所能知道的，德里达说“我呈现给自己，是在语言之后”，这就有点靠谱了。

缠中说禅白话直译
子曰：学而不思则罔，思而不学则殆。
孔子说：将差异性的“学”与同一性的“思”分开，都只能迷惘、疲怠而无所得。

## 47. 子曰：唯！女子与小人为难、养也。近之则不孙，远之则怨。

“唯”，发语词，用在句首引出句子，没有含义；“女”，在《论语》中，都通“汝”，例如“女与回也”、“女为君子儒”等，没有一处是解释成“女人”的；而“子”专指“儿子”，是很晚的事情，在《论语》时代，“子”就是指儿女，没有性别上的特指，“女子”就是“你的儿女”；“与”，本义“赐予，施予，给予”，引申为跟随；“为”，变成、成为；“难”，灾难、祸患；“养”，通“痒”。

人的现实存在，不离“闻、见、学、行”，有所“闻”、有所“见”，因此有所“学”，最终依“学”而行；人有所“行”，都有“闻、见、学”的影子，人的所有现实行为，都不是无源之水，都和某种先前的“闻、见、学”相关，各人的“行为”互相影响，又逐步构成社会的行为模式。 对于“学”，“闻、见、学、行”的中枢，一个最现实的问题就是“跟谁学”。任何的“学”，也都有一个现实的“择师”问题。这里的“师”，不单单指人。西方有所谓重真理更胜于重老师，那不过是把“师”给狭义化了，一切让你可“学”的，都是“师”。但“师”是有位次的，君子“学”和小人“学”的区别在于，小人自小之，把顶天立地的人，弄成权名利色的奴隶、弄成一种所谓先验模式的奴隶。人的眼睛，都是给这些小人之“师”弄瞎、弄坏的。

“近”，依附；“之”，指代前面的“小人”；“孙”，这里是本义，不是通假，引申为“子嗣”。依附小人，必然依附其“学”，然后不断“徒子徒孙”下去，都是小人、小人之“学”的子嗣，不是你的子嗣了。“远”，违背，小人之“学”，都离不开先验的虚妄假定，将这虚妄假定当成“上帝”，一旦有人违背，必然危及其“学”的存在，自然就会埋下仇恨。为什么？小人之“学”，归根结底就是其现实权名利色的根基，任何把其现实根基拔除的，又怎能不引其仇恨？特别地，当一个人先跟随其“学”的人最终违背其“学”，这样的仇恨就不是随便可以消解了。所谓门户之争、清除门户，无不源自这种仇恨。一旦开始“择师”出问题，那后面的问题就无穷无尽，无论是依附还是违背，都是灾难、痒疾。

君子之“学”，不是私学，没有任何的门户。天地，无论多宽广，都不过尔心之一尘，又有什么可以门户之？君子之“学”，是现实而不被现实所现实之学，是究底穷源而不被其所困之学，是“不相”而无“不相”之学，是无学而无不学之“学”。君子之“学”，首要确立的是一个“天地人”结构中顶天立地的“人”。

缠中说禅白话直译
子曰：唯！女子与小人为难、养也。近之则不孙，远之则怨。
孔子说：是的！你的儿女跟随小人而“闻、见、学、行”，就产生灾难、痒疾。依附小人，就失去子嗣；违背小人，就埋下仇恨。

## 48. 子曰：唯上知与下愚不移。

“与”是解释的关键，现今认为“与”是“和”的意思，但这只是一个后起的意思。“与”的本义是“赐予”，原来是指朋党之间相互协作、相互赐予，因而引申为“结交、亲附”。

站在儒家的立场上，“上知”就是君子，“下愚”就是小人，为什么？因为没有“上知”，不可能成为君子。儒家最注重智慧的，而智慧的获得，与“圣人之道”的“见、闻、学、行”是一体的。“见、闻、学、行”、“圣人之道”必须达到不退转的位次，才可能有真正的智慧，也就是“上知”的呈现。要不退转，必须彻底穷源，“学如不及，犹恐失之”，“不及”就谈不上“上知”，而没有“上知”，也成就不了真正的“君子”。而“小人”，将人自小之，与世漂移，浮萍无根，何谈智慧？对于人来说，最大的愚蠢就是这“将人自小”，“小人”就是真正的“下愚”。

君子为什么要“与”小人、结交小人？因为君子都是从小人而来，从小人转化而来，任何人，在没有“见、闻、学、行”“圣人之道”之前，都是小人，都曾自小之。 “圣人之道”，是大道，不是私道，永远活泼、当下地呈现，即使没有孔子，“圣人之道”也不会被掩盖，而任何人，只有“见、闻、学、行”“圣人之道”，才可能得到真正的智慧、才可能转小人而成君子。君子，不可能与小人为敌，而是要去结交他们，对其“小人”之相“不相”之。但一般的人，如果没有达到不退转，在与“小人”的结交中，就会面临上一章的情况“唯！女子与小人为难、养也。近之则不孙，远之则怨”。因此，站在现实的立场上，孔子还是主张“远小人”，特别小孩子，一定不能交给小人“教育”，否则后患无穷。

但真正的君子，不单单要出于污泥而不染，而且更要赴汤蹈火，于恶世恶人中“见、闻、学、行”、“圣人之道”，不如此，无以成就真正的不退转，也无以使得“人不知”的世界转化成“人不愠”的世界。“唯”，这和上章不同，表示希望、祈使的意思，这是孔子对所有立志成为君子的人的希望与期许。“上知”，具有真正智慧的君子，达到不退转的位次，在任何情况下都能“不移”，当然也包括“与小人”的情况，也只有通过“与小人”历练，才可能成就真正的不退转。“不移”，不改变、不退转的意思。

缠中说禅白话直译
子曰：唯上知与下愚不移。
孔子说：愿真正“见、闻、学、行”“圣人之道”的君子，结交、亲附没有智慧、充满贪婪、恐惧的小人而成就“见、闻、学、行”“圣人之道”的不退转。

## 49. 子曰：温故而知新，可以为师矣。

“可以”不是白话文里的一个词语，而是“可”+“以”，“温故而知新”因强调而提前，相当于“可以温故而知新为师矣”。“可”，应当；“师”，不能狭义地理解为一定是某人，所有学习、效法的对象、目标都是“师”。 “温”，通“蕴”，积聚、包容；“故”，故有的，这里指经过时间沉淀、检验的智慧；“知”，“智”的本字，智慧；“新”，鲜活的创造与呈现。“温故而知新”，积聚、蕴藏故有的、经过时间沉淀、检验的智慧而保持智慧当下鲜活的创造与呈现。

“由知、德者，鲜矣！”，蹈行、践履“闻、见、学、行”“圣人之道”智慧、所得的君子，永远处在创新、创造之中啊。“故”，就是蹈行、践履“闻、见、学、行”“圣人之道”智慧所得，“温”所得，是一种积聚、蕴藏，没有“温故”，就没有智慧的创新与创造，没有“由知、德者，鲜矣！”。而“知新”，其“新”如果不能“温故”，那就不能成就真正鲜活的智慧，没有积聚、蕴藏是无智慧可言的。这种相互相成的“温故”而“知新”，是“见、闻、学、行”“圣人之道”可以“为师”的。

孔子、儒家绝不泥古，师古、好古是师其智慧、好其智慧，而智慧必须在当下能活用出新，才是真正的智慧，否则，把“温故”当成在故纸堆里找些原则、准绳来勾画、预测未来，只能是愚行。 “习旧知而开新知”只能是某种扩充知识的途径，但决不是唯一的，更不可以此为“师”。类人猿的“旧知”，无论如何去“习”，都开不出网络世界的“新知”。但智慧是超越这一切的，无论是“新知”还是“旧知”，都离不开智慧当下鲜活的创造与呈现，这才是真正可以为“师”的。

缠中说禅白话直译
子曰：温故而知新，可以为师矣。
孔子说：应当把“积聚、蕴藏故有的、经过时间沉淀、检验的智慧而保持智慧当下鲜活的创造与呈现”作为君子“见、闻、学、行”“圣人之道”所师法的目标啊。

## 50. 子曰：吾十有五而志于学，三十而立，四十而不惑，五十而知天命，六十而耳顺，七十而从心所欲不逾矩。

一句无人不晓的话，却一直无人真的晓得，甚至连并列成分省略的简单语法现象，都没被指出过。“十有五而志于学”后的“立”、“不惑”、“知天命”、“耳顺”、“从心所欲不逾矩”前，其实都相应省略了“志于”。完整的句子应该是“子曰：吾十有五而志于学，三十而志于立，四十而志于不惑，五十而志于知天命，六十而志于耳顺，七十而志于从心所欲不逾矩。”

“于”，相当于“被”、“用”；“志”，“誌”的古字，标记。“志于X”，用X来标记。这里有两层意思：

一、十有五、三十等年岁数字，大致和孔子达到某种相应境界的实际年龄相关，但并不表明这个体经验有着任何绝对的意义，例如，并不是任何人“三十”就一定“立”，“三十”与“立”之间并不必然相关，这些境界也并不一定按年龄机械地被赋予某种必然的次序，只是一种标记；

二、所有以往解释都忽视了“志于”的省略，而把后面的境界当成“学”的必然结果，更把每种境界当成一个固定的标准，却不知每种境界是自足而动态的，每种境界都有其“成住坏灭”，之所以是“志于”，只是把每种境界用一个名言标记而已，决不能掩盖其鲜活的当下呈现。

“学”，“闻见学行”“圣人之道”，“闻见”而“学”，“学”而“行”，“学”是贯通“闻见”与“行”的枢纽，“学”，包罗万有，相应境界、所为，以“学”为标记。

“立”，世间一切，皆有所“立”，有所位次，究底穷源，首先就要究其“立”、穷其位次，如此境界、所为，就以“立”为标记。

“不惑”，“立”则有其“患”，“患”则有其“惑”，而“立”皆“不患”而“立”其“患”，不穷其“不患”，则不能“不惑”，这“不患”而“不惑”的境界、所为，就以“不惑”为标记。

“天”，时也；“时”，当下也；“命”，生存、存在；“知“，智慧。“知天命”，当下生存而呈现智慧。 所有的智慧，都离不开当下的生存，否则都是虚无幻想，智慧的成就，必须是当下生存的鲜活呈现，这境界、所为就以“知天命”为标记。

“顺”，遵循；“耳顺”，“耳”，“闻”也，“闻”与“见学行”是不可分的，“闻见学行”遵循什么？就是“知天命”。“闻见学行” 遵循当下生存鲜活呈现的智慧，这才是真正的“耳顺”，这种境界、所为，以“耳顺”为标记。

“从心所欲不逾矩”，“心”，非指一已之私心，民心也，依从民心期望不越“矩”，何谓“矩”？“闻见学行”“圣人之道”在当下现实中可能实现的位次。依从民心所期望但不超越“闻见学行”“圣人之道”在当下现实中可能实现的位次，这境界、所为以“从心所欲不逾矩”为标记。

“闻见学行”“圣人之道”，穷其现实之“立”，尽其现实所“立”之“不患”而“不惑”于时，以其当下之时让智慧鲜活地呈现而“知天命”，然后才有“耳顺”的内圣、“从心所欲不逾矩”的外王。只有这样理解，才算大致明白本章的主旨。

缠中说禅白话直译
子曰：吾十有五而志于学，三十而立，四十而不惑，五十而知天命，六十而耳顺，七十而从心所欲不逾矩。
孔子说：我十五岁的境界、所为用“从此闻见学行圣人之道”来标记，三十岁的境界、所为用“穷尽闻见学行圣人之道的现实可能位次”来标记，四十岁的境界、所为用“透彻闻见学行圣人之道现实可能位次的不患”来标记，五十岁的境界、所为用“闻见学行圣人之道让智慧依当下生存鲜活地呈现”来标记，六十岁的境界、所为用“遵循当下生存鲜活呈现的智慧而闻见学行圣人之道以成就内圣”来标记，七十岁的境界、所为用“依从民心期望但不超越闻见学行圣人之道在当下现实中可能实现位次而成就外王”来标记。

## 51. 子曰：君子，食无求饱，居无求安；敏於事而慎於言；就有，道而正焉；可谓好学也已。

“可谓好学也已”，是“谓好学也可已”的倒装，“已”通“矣”；“谓”，称为；“可”，恰当、适当。符合什么条件被称为“好学”才是适当的？孔子给出了如下三大标准：食无求饱，居无求安；敏於事而慎於言；就有，道而正焉；“食无求饱，居无求安”，即“食无求而饱，居无求而安”。所谓“食色，性也”，“食”，指代人的所有欲望；“无求”，不贪求；“饱”，引申为欲望的满足；“居”，在现实中当下的生存条件、环境，不单单指住房； “安”，安身立命。对欲望不贪求才是真满足，对生存的环境不贪求才是真正的安身立命，这是对君子“好学”最基本的要求。如果整天都想着“贪求”，用自己的欲望之眼来观察世界，哪里能看清楚世界？哪里还有“好学”可言？注意，“无求”，不是故意放弃，故意糟践自己，而是根据当下的条件适当的选择。

“敏於事而慎於言”，即“於事而敏、於言而慎”。“敏”，假借为“拇”，大拇指，转义为“印证”的意思；“慎”，通“顺”，顺应。通过当下的事情去印证，使得理论、言论顺应当下的实际，这才是真正的“敏於事而慎於言”。
“就有，道而正焉”，“就”，尽、穷尽；“有”，现实的存在；“道”，使之行道，使现实行“圣人之道”；“正”，指事字，上一表示方向、目标，下足(止)表示向这个方位或目标不偏不倚地走去，对于儒家、《论语》来说，这方位或目标就行“圣人之道”而成就之；“焉”，于此，在现实中。对现实究底穷源，使现实行“圣人之道”而在现实中成就之，这就是“就有，道而正焉”。

每一个人，都是自足于天地，不需要假设一个上帝或道德的上帝来匡正。在“天地人”的结构中，其道德、行为等，都当下自足地呈现着，连企图摆脱这种当下自足的呈现也只能是当下的，脱离了这个，一切都是没意义的。

缠中说禅白话直译
子曰：君子，食无求饱，居无求安；敏於事而慎於言；就有，道而正焉；可谓好学也已。
孔子说：“闻见学行”“圣人之道”的人，对欲望不贪求从而满足，对生存的环境不贪求从而安身；通过当下的事情去印证，使得理论、言论顺应当下的实际；对现实究底穷源，使现实行“圣人之道”而在现实中成就之，称之为“好学”，是适当的啊。

## 52. 子曰：十室之邑，必有忠信如丘者焉，不如丘之好学也。

“室”，家族；“邑”，本义“国”；“必”，倘若；“如”，遵从；“丘”，孔子自称；“焉”，于此；“不如”，不若。“十室之邑”，由所有家族构成的国家，人而家而国，修身、齐家、治国，进而才能平天下。“十”，《说文》，十是数之具，包括东西南北中央，极言其大，也就是囊括所有的意思。

“必有忠信如丘者焉”，即“必有如丘之忠信者焉”，于“十室之邑”倘若具有遵从我的“忠信”标准；“不如丘之好学也”，即“不如有如丘之好学者焉也”的省略，比不上于“十室之邑”具有遵从我的“好学”标准。这两句话表明了孔子的一种态度、也是一种深深的忧虑，就是一个国家不能光把“忠信”当成标准，而不把“好学”当成标准，这样的国家并不能算是行“圣人之道”。

上一章，孔子彰显“好学”的三大标准，是从“内圣”角度谈论的；而本章，就是从“外王”的角度谈论“好学”的重要。内圣外王都离不开“好学”，必须对欲望不贪求从而满足，对生存的环境不贪求从而安身，通过当下的事情去印证，使得理论、言论顺应当下的实际，对现实究底穷源，使现实行“圣人之道”而在现实中成就之。

缠中说禅白话直译
子曰：十室之邑，必有忠信如丘者焉，不如丘之好学也。
孔子说：所有国家，倘若有遵从我的“忠信”标准的在其中，不若有遵从我的“好学”标准的在其中。

## 53. 子曰：三人行，必有我师焉：择其善者而从之，其不善者而改之。

何谓三人？为何不是五、十人？二人呢？这些问题，大概从来没人能回答与正视过。其实，所谓三人，指的是“君、父、师”，三类最值得尊重的人，“三人行”，与“君、父、师”同行。 人，要取法其上，难道和几个大淫贼同行，还“必有我师焉”？那是同性而不是同行。如果按上面及通常解释，三人都是植物人，那你和三植物人同行，如何“必有我师焉”？植物人依然是人，那么其善者人如何从？其不善者又如何改？这不是抬杠，而是原来的解释太愚蠢可笑。

“必有我师焉”，“必”，倘若；“有”，具有“；“师”，师法；“焉”，于此。孔子更注重在现实的当下印证，而对“君、父、师”，孔子并不一味肯定，觉得一定要有可师法的地方，而是更强调，如果没有其他标准，是不能确认其善与不善。这个标准，只可能是当下的现实。 “君、父、师”，无论有什么理论和看法，都不可能脱离当下的现实成为永恒的准则，这样才存在后面“择”的可能。

与“君、父、师”同行，倘若有可以师法的地方，孔子给出如下的建议：“择其善者而从之，其不善者而改之”。“择”，选取，以当下的现实为标准选取，而不是根据自己的喜好、师承、派别去选取； “善”，完善；“从”，通“纵”，广泛；“从之”，使之从，使善者广泛，将完善的在当下现实更广泛的范围中应用、检验；“改之”，使之改；将不善者在当下现实中不断修改完善。“改”，除了修改，还有强调“重新、再”的意思，这种修改不是一次性的，而是不断进行直到完善。

前两章说了“好学”对内圣外王的意义，本章更指出，站在“好学”的标准下，对“君、父、师”为代表的前人遗产，应该的态度是“择其善者而从之，其不善者而改之”，脱离这个前提，所谓师法，不过是尸法而已。而孔子、论语，永远活在鲜活的现实之中。

缠中说禅白话直译
子曰：三人行，必有我师焉：择其善者而从之，其不善者而改之。
孔子说：与“君、父、师”同行，倘若有让我师法的在此：选取他们完善的并在当下现实更广泛的范围应用、检验，选取他们不完善的并在当下现实中不断修改、完善。

## 54. 子夏曰：日知其所亡，月无忘其所能，可谓好学也已矣！

钱穆：子夏说：“每天能知道所不知道的，每月能不忘了所已能的，可说是好学了。”

这不是孔子的话，而是其弟子子夏的。孔子的思想，经一传再传，最后完全变味，而祸端就从其弟子开始。同称“可谓好学也已”，子夏的“日知其所亡，月无忘其所能”之于孔子的“君子，食无求饱，居无求安；敏於事而慎於言；就有，道而正焉”，就如秋风之蝉之于春阳之凤，一蛭之蚁之于九天之鹏。孔子的被曲解与败坏，就是从其弟子，从最简单的“好学”开始。

“日”，每日；“知”，孔子的“知”都以“智慧”解，而这里的“知”无法解释成“智慧”，否则语法上就成问题了，只能解释成“认识”；“亡”，通“无”，没的；“日知其所亡”，每日认识他所没的；“忘”，遗忘；“能”，会的；“月无忘其所能”，每月不遗忘他所会的。

当孔子的“智慧的当下鲜活呈现”变成子夏对“知识的日积月累”，中华文明的衰败就此埋下祸根，子夏之流绝对是中华文明的千古罪人。五千年文明历史，浩如烟海的典籍，如果没有“当下鲜活的智慧”，都是废物一堆。“知识”如果不产生能“当下鲜活”的智慧，知识不过是知识分子面首店里挂的招牌。

## 55. 子夏曰：仕而优则学；学而优则仕。

钱穆：子夏说：“仕者有余力宜从学。学者有余力宜从仕。”

中国有所谓“士大夫”，“大夫”者，仕也；未仕者，士也。站在某种角度，“仕而优则学；学而优则仕”确实是千古名言，但这里的“优”应该解释成其本义，“优倡”是也。在这种解释下，一副中国二千来年的真实图景就呈现面前：仕、士、优一体。

## 56. 子夏曰：百工居肆以成其事；君子学以致其道。

钱穆：子夏说：“百工长日居住肆中以成其器物，君子终身在学之中以求致此道。”

“百工居肆以成其事；君子学以致其道”，其实就是“百工居肆以成其事；君子居学以致其道”的省略，这是一个典型的对称比喻句式。本章的意思很简单，直译大致就是：就像各种工匠在手工业作坊里为完成他们的制作，君子在学中为完成他们的事业。这里，子夏把孔子鲜活的“学”变成了手工作坊一般有着具体目的、程式、规范的子夏之“学”，这就如同希腊哲学柏拉图之后将赫拉克利特的“逻格斯”变成“逻辑”，从此，一切都被结构着、程式着、基础着，而这一切都对应着一切意识形态的把戏。后世的所谓儒学，在这种意识形态化中沉沦，子夏之流，其祸大矣。

## 57. 子谓子夏曰：女为君子儒！无为小人儒！

钱穆：先生对子夏道：“你该为一君子儒，莫为一小人儒。”

“女”，即“汝”，你。本章字面意思十分简单，问题的关键在于什么叫“君子儒”、“小人儒”。后世把孔子挂了一个儒家的标签，但在《论语》中，只有这一章提到“儒”。“儒”，本义指“术士”，在周代专指为贵族子弟的教师等。孔子的学生几乎就没有什么贵族子弟，至少在《论语》中，也没有记载有人把孔子称为“儒”，更没有记载孔子以“儒”为荣，甚至把自己称为“儒“的语录也一条都没有。所谓“儒家”的出现，都拜子夏之流所赐。“儒家”之于孔子，只是约定俗成、将错就错。

这里的“儒”，与后世的儒者、儒生、读书人之类都无关，孔子年代根本就没这样的说法与意指。《周礼》里有“四曰儒，以道得民”。但此文被汉代刘歆整理，是否历史真实，至少康有为是坚决反对的。胡适把“儒”当成起源于商代类似基督教牧师般的某类人，也不过是一个被西方模式所洗脑者的呓语。至于《礼记》中有《儒行》，但《礼记》只是战国及后儒生所撰，反而是一个曲解改造孔子思想的铁证，不足观。抛开这一切关于“儒”的争论，就《论语》本身来看，孔子并没把“儒”当成一个可以代表自己的标签，这一点是十分明确的，这从“儒”在《论语》中的仅见就足以证明。

这里，还是采取《说文》“儒，柔也，术士之称。从人，需声”的标准解释，无论是贵族子弟的教师还是后来的儒者、儒生，都可以看成某种意义上的“术士”。孔子走的是刚阳一路，虽然是刚中有柔，但与“术士之柔”远非一类。本ID在这里提出一个前无古人的论断：老子实际上是古代之“儒”的集大成者，而孔子百尺竿头更进一步，非老子之流可梦见矣。老子之“道”实“儒”，道家实际更应该称为“儒家”，而孔子之学，自从颜回先去后，并无继者，后借孔子之名而惑世者，不过如子夏般的小人儒而已。

在孔子看来，当时包括老子在内的一切所谓“儒“，都不过在小人范围内，没有智慧而自小之，都是“小人儒”。但当时的“儒”、各种的术士在社会上有广泛的影响，孔子对应着造了一个新词“君子儒”，以彰显自己主张的不同。何谓君子儒？横天横地而不离当下，不离当下而横天横地，转“人不知”之世界为“人不愠”之世界，担当天下而无所担当，无所担当而担当天下，“闻见学行”“圣人之道”而成就之。孔子已经看出子夏之流不堪承担，所以有本章的直接警示，也算为后世留一话头。

## 58. 哀公问：“弟子孰为好学？”孔子对曰：“有颜回者好学，不迁怒，不贰过。不幸短命死矣，今也则亡，未闻好学者也。”

钱穆：鲁哀公问孔子道：“你的学生们，哪个是好学的呀？”孔子对道：“有颜回是好学的，他有怒能不迁向别处，有过失能不再犯。可惜短寿死了，目下则没有听到好学的了。”

无论“不迁怒，不贰过”是什么含义，但本章里，孔子明确表示，除了颜回，其他人都达不到他的好学标准，这一点是无疑的。这也证明了，上面说子夏之学非孔子之学，确实没有冤枉他。不过，上面三位对“不迁怒，不贰过”的解释都有问题。

“怒”，不是通常说的愤怒、怒气，而是“超过”的意思，在《荀子·君子》“刑罚不怒罪，爵赏不逾德”中，就是按此解释；“迁“，变更、变动；“贰”，背离；“过”，超过。古文喜欢对称，往往用一些类似又稍有差别的词语构成对称句式，“不迁怒，不贰过”中，“迁”对“贰”，“怒”对“过”， 相互间的意思差别不特别大。

孔子之学，立于当下的现实而究底穷源，若“迁”若“贰”，则违背。而“怒”与“过”，超过当下的现实，同样违背孔子之学的基本原则。而只有颜回能领悟孔子之学的实质而能“不迁怒，不贰过”，所以被孔子所盛赞，而其他人，都如子夏般把智慧的当下呈现“迁贰”成对知识的日积月累，又怎么可能得到孔子的认可？

## 59. 季康子问：“弟子孰为好学？”孔子对曰：“有颜回者好学，不幸短命死矣！今也则亡。”

钱穆：季康子问孔子：“你的弟子哪个是好学的呀？”孔子对道：“有颜回是好学的，不幸短命死了，现在是没有了。”

本章与上章一致，再次肯定颜回是孔子所认定的唯一符合其好学标准的学生，只是回答的对象不同，由此更证明了此观点非孔子一时之论，而是他的一贯之论，也从一个侧面证明，孔子之后打着孔子旗号的人，都不过是借孔子之名贩卖求名而已。至于对孔子这两章类似回答的繁间之异进行穿凿，都是无聊之举。同样问题，在不同时间、对不同的人，回答大同小异，极为正常。套用心理学，如果一个人对同样问题的回答永远一字不差，那只能证明此人口不对心，所谓回答都在背稿子，而这显然不是孔子所乐意的。

## 60. 子曰：语之而不惰者，其回也与？

“语”，本义“谈论、议论、辩论”；“之”，指代“语“的对象；“惰”，衰败；“其”，通“岂”，难道，表示诘问。“与”，同“欤”，表诘问。本章的意思是，难道能言善辩的只有颜回吗？也就是说，颜回之所以是颜回，并不是因为他能言善辩。一个好学的人，自然能言善辩，但好学不在于能言善辩，多有能言善辩之徒，不过死剩一张嘴，这种人，又有什么用？

这一章，依然是在肯定颜回之学，只有颜回得孔子之髓。孔子之学，不在言语上，不在文字上，不在如讼师般的口若悬河上，否则，全民讼师化不就完了？就像这个时代，谁都能忽悠、谁都能恶搞，但又有多少人是真明白事的呢？生不知生，死不知死，那叫行尸走肉。人身难得，又有多少人能不耗费在嘴上、床上？说取行不得的，行取说不得的，参！

缠中说禅白话直译
子曰：语之而不惰者，其回也与？
孔子说：任何人与他辩论而他都能语不衰败的所谓能辩之士，难道只有颜回吗？

## 61. 子贡问君子。子曰：先行其言而后从之。

子贡，孔子最出名的学生之一，聪明而善辩，正是上章孔子所说“语之而不惰者”，但在孔子心里，他和颜回是有区别的，从《论语》相关章节就不难明了。本章，子贡问君子的标准问题，其实，这是一个假问题，君子“闻见学行”“圣人之道”，并不是一个道德标准所能规范的。子贡希望得到一个静态的标准性定义，孔子却用给出了一个当下性回答：“先行其言而后从之”。“先行其言而后从之”，是“先行其言而后从其言”的缩略。

“行”，发hang，连续贯穿；“言”，不单指出言论，更包括人的一切思想以及相应的行为； “行其言”，把他的言论、思想以及相应的行为连续贯穿，也就是孔子在后面所说的“吾道一以贯之”，只有“行其言”，才可能“一以贯之”；“从”，通“纵”，广泛，光“一以贯之”，而不能“从之”，不能使之广泛，那不过是小圈子甚至是个人的自渎，没什么意义。

缠中说禅白话直译
子贡问君子。子曰：先行其言而后从之。
子贡问君子，孔子说：“先使自己的言论、思想以及相应的行为一以贯之，然后再使之广泛。”

## 62. 子贡问曰：“赐也何如？”子曰：“女，器也。”曰：“何器也？”曰：“瑚琏也。”

本章可以看出，孔子是一个很有幽默感的人。子贡，聪明而缺智慧，却对自己的聪明甚为自负，所以就问孔子“我究竟怎么样？”希望得到孔子的肯定。“赐”，是子贡的名。孔子一语双关提醒子贡“君子不器”，子贡不明白，还以为孔子说他是一种器皿，就反问什么器皿。孔子很有幽默感地告诉他，是瑚琏，一种宗庙里盛黍稷敬神的名贵玉器。

知识分子、儒生，总有点臭美的传统，其实，百无一用是书生。知识分子，不是被人当枪使、当旗忽悠就是百年寒门当寒号鸟哀鸣。孔子这里的幽默更绝，宗庙里盛黍稷的瑚琏，就算把你供起来，也不过是祭坛上的摆设而已，至于知识分子好争的名，不过如摆设那玉器的成色，无论成色如何好也还是摆设而已。

缠中说禅白话直译
子贡问曰：“赐也何如？”子曰：“女，器也。”曰：“何器也？”曰：“瑚琏也。”
子贡问：“我，怎么样？”孔子说：“你，“器”呀。”问：“什么器皿？”答：“宗庙里盛黍稷的瑚琏那样的名贵器皿”

## 63. 子贡问曰：“有一言而可以终身行之者乎？”子曰：“其恕乎？己所不欲，勿施於人。”

这里的“一言”，不在“字句”间，是“言”而“一”。“一”，纯一不杂，而没有“一”，何来“终身行之”？“行”，发hang，连续贯穿。一而行之，也就是一而贯之的意思。注意，子贡所理解的一而贯之，与孔子所理解的是不同的。子贡希望得到一个规律、一个定义、一个天理、一个天道之类东西“一而贯之”，这也是绝大多数人的想法，一个上帝式的想法，但这显然不是孔子的“一而贯之”所指。对于孔子来说，只有现实的当下才是“一而贯之”的，没有任何不变的准则、道德等是可以“一而贯之”的，为了表明这个问题，孔子因而有下面的回答。

“其恕乎？己所不欲，勿施於人”是“己所不欲，勿施於人，其恕乎？”的倒装，千古以来，所有人都把“己所不欲，勿施於人”当成了所谓孔子的“恕”道，其实都是把这句倒装话的意思给搞反了。“其…乎”的句式，表示的是诘问、反问。正因为当时都喜欢谈论所谓“恕”道，而且给出不同的定义，认为自己的定义才是正确的，然后都企图把自己的定义“一而贯之”，这种想法，就如同子贡的想法一样，孔子就用一个反问句给于反驳。
“己所不欲，勿施於人”是当时最流行的对“恕”道的定义，也是最普通的常识，孔子反问，难道“己所不欲，勿施於人”就是“恕”道吗？显然，孔子并不一味地、脱离当下现实地认为“己所不欲，勿施於人”就是所谓的“恕”道。通过反驳这个最常识言论的非绝对性，孔子就表明了没有什么言论是可以如子贡所认为的可以终身一而贯之的。可笑的是，千古以来，竟然被这样一个简单的反问句所疑惑，竟然把孔子反对的东西当成孔子的东西。

其实，假设“己所不欲”的就是“己所不欲，勿施於人”，那么“己所不欲，勿施於人”是否要“勿施於人”呢？如果否，这就与“己所不欲，勿施於人”的言论矛盾，如果是，既然“己所不欲，勿施於人”要“勿施於人”，那还废话什么？这样的垃圾言论竟然成为两千多年来强加给孔子的所谓语录，简直无聊透顶。孔子在两千多年前就看出这话的逻辑矛盾，看出这是一句垃圾废话，一个“其恕乎？”的诘问就把这话给扒了皮。

缠中说禅白话直译
子贡问曰：“有一言而可以终身行之者乎？”子曰：“其恕乎？己所不欲，勿施於人。”
子贡问：“有可以终身一而贯之的言论吗？”孔子说：“自己不想要的就不施加给别人，难道就是“恕”吗？”

## 64. 子贡曰：“我不欲人之加诸我也，吾亦欲无加诸人。”子曰：“赐也，非尔所及也。”

本章重点在何谓“加”？通常的解释为“施加、强加”，其实，这都是“加”的延伸意思。“加”，从“口”而用“力”，十分形象，本义是虚报、夸大其辞、说过头话、在原来的基础上增添、把本来没有的添加上去、诬枉。子贡自己不想诬枉别人，也不希望别人诬枉自己，孔子认为，这不是子贡所能办到的。其实，何只子贡，只要是社会中的人，只要是在“人不知”中的人，就不可能办到，连孔子自己也不能办到。

这子贡，从来就没明白孔子，依然继续他的“一而贯之”的名言游戏，本章又来了一个“我不欲人之加诸我也，吾亦欲无加诸人”，又发着“我不想别人诬枉我，我也不想诬枉别人”的梦。但在当下现实中，这种玩意从来就不可能“一而贯之”，从来就是幻想，不可能实现。一个人对别人的评论、观察，“不患”地在其角度上，在量子力学中，观察者不可能“无加”于观察结果之外，在现实的当下，在“人与人”的观察中，显然也不可能，这种“无加”的把戏如果被当成一个目标去追求，就是大傻瓜，就像企图在量子力学中排除观察者状态的影响一样。孔子在二千多年前就明白这个道理，一句“赐也，非尔所及也”，说白了，就是“子贡，别脑子进水、白日做梦”。

缠中说禅白话直译
子贡曰：“我不欲人之加诸我也，吾亦欲无加诸人。”子曰：“赐也，非尔所及也。”
子贡问：“我不想别人诬枉我，我也不想诬枉别人。”孔子说：“子贡啊，这不是你所能达到的。”

## 65. 子曰：“赐也，女以予为多学而识之者与？”对曰：“然，非与？”曰：“非也！予一以贯之。”

“一以贯之”，可一者，必是“不患”者，对于现实中的人，最基础的、最前提性的、最可“一”的，就是当下的现实本身，一切离开当下现实的，都非一。 如前所说，《论语》的关键在承担，承担什么？就是承担这当下的现实，必须首先承担这当下的现实，才可能有改造、超越。“闻见学行”“圣人之道”，就是“一以贯之”的另一种说法，直下承担，才可能“闻见学行”“圣人之道”，才可能“一以贯之”，否则就只能继续制造些名言的垃圾来延续自欺欺人的把戏。

“之”，没有具体所指，可以泛指一切当下现实中一切的东西，可以是具体现象，也可以是某种抽象理论，可以包括现实人生中一切可以被“识”的东西。多学并不能识之，如果不能当下承担，所谓的多学，不过是名言游戏。孔子所认为的“学”，都是以对现实的直下承担为前提的，也就是以“一以贯之”为前提的。

缠中说禅白话直译
子曰：“赐也，女以予为多学而识之者与？”对曰：“然，非与？”曰：“非也！予一以贯之。”
孔子问：“子贡啊，你把我当成不断学习从而了解现实当下的人吗？”子贡回答：“对，不是这样吗？”孔子说：“不是啊，我只是直下承担当下现实而贯通它。”

## 66. 子曰：“参乎！吾道一以贯之。”曾子曰：“唯。”子出。门人问曰：“何谓也？”曾子曰：“夫子之道，忠恕而已矣。”

关于孔子的“一以贯之”，两千多年来争论不休。最常见的，就是先假设一所谓“仁”道，人人本于心，从而因我心而贯通万人之心，进而万世人之心。这假设的荒谬性，根本不值得反驳。这里，千万别用谁谁谁不是人的逻辑来搪塞，老话说的好，“一种米养百样人”，都是人，只是在“人不知”社会的当下现实中，这人和人不是一样的人。这不是什么上帝、先验的逻辑，而是当下现实的现实逻辑所决定的。

但孔子的学生们，总是自作聪明，本章的主角曾参，孔子死时才29岁，来了一句“夫子之道，忠恕而已矣”，为祸神州2000多年。本章字面意思很简单，但其中情节，却与下面神会的故事类似。

曾参是孔子的关门弟子，神会也可以算是惠能的关门弟子，但这两个关门弟子，其实都没入门。一天惠能问：“吾有一物，无头无尾，无名无字，无背无面，诸人还识否？”这就如同孔子说“参乎！吾道一以贯之”，这里也同样有一个潜台词“还识否？”神会就抢着回答惠能：“是诸佛之本源，神会之佛性。”这就如同曾参说“夫子之道，忠恕而已矣。”孔子后面说什么，《论语》里没记载，但在《六祖坛经》里，惠能对神会的回答有如下回应：“向汝道无名无字，汝便唤作本源佛性，汝向去有把茆盖头，也只成个知解宗徒！”这回应完全可以同样给曾参：“向汝道吾道一以贯之，汝便唤作夫子之道忠恕而已矣，汝向去有把茆盖头，也只成个知解宗徒！”

曾参，也就是一知解宗徒，神会和曾参这两个知解宗徒，在历史上却有相同的一点，就是都成了把本门“发扬广大”的人，神会扫荡北宗使得惠能的南宗一脉大显，而曾参，后来成了曾子，成了孔子门人里实际上影响最大的一个。曾参比神会为祸更深的是，当时禅宗大德辈出，神会这门都没找着的一脉很快就断灭了，而孔子门下，真得孔子之髓的颜回比孔子还早死，后继无人，结果就给曾参这知解宗徒搞出大名堂，2000年来对中国有着最大影响的儒家，其实就是曾家一脉，其门派出了子思，再下传孟子，四书中，除了《论语》，另外《大学》、《中庸》、《孟子》，三本都出自曾参门下，由此就知道，中国这两千多年的正统儒家究竟都是些什么货色了。

缠中说禅白话直译
子曰：“参乎！吾道一以贯之。”曾子曰：“唯。”子出。门人问曰：“何谓也？”曾子曰：“夫子之道，忠恕而已矣。”
孔子说：“曾参啊！我“闻见学行”圣人之道一以贯之。”曾参说：“是。”孔子出去。孔子的其他弟子问：““一以贯之”是什么意思？”曾参回答：“老师的道理，只是“尽已之心以待人，推己之心以及人”罢了。”

## 67. 有子曰：其为人也孝弟，而好犯上者，鲜矣；不好犯上，而好作乱者，未之有也。君子务本，本立而道生。孝弟也者，其为仁之本与！

钱穆：有子说：“若其人是一个孝弟之人，而会存心喜好犯上的，那必很少了。若其人不喜好犯上，而好作乱的，就更不会有了。君子专力在事情的根本处，根本建立起，道就由此而生了。孝弟该是仁道的根本吧？”

前面一直说孔子的弟子们是如何对孔子进行歪曲，如何把自己的私货夹带到《论语》之中，其中最过分的就是这位“有子“了。在《论语》中，孔子其他弟子都称呼名字，只有“有子”和“曾子”是被带上“子”的尊称，连颜回这孔子最出色的弟子，在《论语》中也没被称为“颜子”，这就很奇怪了。最奇怪的是，在《论语》通常排序里，“有子”的第一条语录排在孔子最出名的三个“不亦”后面，等于在500多条语录中排名第二，是所有弟子里最早出现的，而“曾子”的第一条语录，被排在第四位，是所有弟子里第二出现的。现在，搜索排位还要付费，这“有子”与“曾子”，都是孔子晚年才收的弟子，有何德何能单独被尊称而且排位如此靠前，完全占据最好的广告位置，二千多年来，让如此多人看《论语》时，都被迫第一时间记住这两位，凭什么？唯一合理的解释，现在流传的《论语》就是这两位的弟子合伙编辑的，其中大量夹带了他们的私货，这简直是中国文化史上最无耻的一笔。

本章，字面意思很简单，最大的问题是，这“有子”说了那么多废话，其核心思想还是为了扼杀所有的“犯上作乱“者。儒学刚猛，充满反抗精神，竟然被这“有子”阉割成奴才玩意。这人还特虚伪，最后所谓“孝弟也者，其为仁之本与！”，说的可不是“孝弟”，因为按照前面“其为人也孝弟，而好犯上者，鲜矣；不好犯上，而好作乱者，未之有也。”的逻辑，为什么强调、宣扬“孝弟”？就是因为“孝弟”了就不“犯上”，进而就不“作乱”。按这种逻辑，并不是“孝弟”本身真被此人看重，而是宣扬“孝弟”导致的不“犯上作乱”结果符合了此人所代表的、害怕被“犯上作乱”的那一群人的利益。而又是谁最怕“犯上作乱”呢？

此人所谓“君子务本，本立而道生”，完全与孔子的思想背道而驰，连“曾子”的所谓“一以贯之”都与孔子无关，这所谓的君子之本，不过是为了把其“孝弟”了就不“犯上”进而就不“作乱”的谎话说圆而编造的更大谎言。其中的逻辑关系无非是，你要成为君子，首先要有“君子之本”，有了“本”才有“道”生，而“孝弟”是“仁”道之本，君子都要遵守。这样，通过伪造的所谓“君子之本”，“有子”就一步步将人引向永远无条件地不“犯上作乱”的真正陷阱，否则就是忘“本”了，然后就可以宣布此人违反“仁”道，就不是“人”，是“贼”是“寇”，然后就可以围而灭之，这样，这些害怕被“犯上作乱”的人，就可以永远继续为非作歹，鱼肉世界，这就是两千多年来的中国统治者看着“有子”、“曾子”们所夹带着私货编撰的《论语》就特别亲切的根本原因。

## 68. 孟懿子问孝。子曰：“无违”。樊迟御，子告之曰：“孟孙问孝於我，我对曰，”无违。””樊迟曰：“何谓也？”子曰：“生，事之以礼；死，葬之以礼，祭之以礼。”

“孝”，对于孔子、儒家来说，只是一个很日常的概念。在孔子那里，绝对没有后世被改装的所谓“以孝治天下”的想法。孟懿子，鲁大夫，其父要求其学礼于孔子，也算是孔子早期弟子之一，但此人对孔子有点像犹大之于耶稣，所以后来一般都不把他当成孔子的弟子。

“违”，本义“离开”；“无违”，就是不要离开当下社会的现实，这包括了文化、经济等。后来有些人把“无违”当成不要违背父母，这显然是不对的，于实际情况不合，难道杀人放火之辈就没有儿女？难道他们的儿女也要跟着杀人放火才是“无违”？而且，孔子在后面也给出了“无违”的解释“生，事之以礼；死，葬之以礼，祭之以礼”。这里，孔子强调的是“礼”，由于“礼”在《论语》中被反复提到，很多相关问题必须在后面逐步解决，但这里必须首先知道，“礼”对于孔子来说是当下的，没有超越现实永恒不变的“礼”。

“礼”，最初与“祭神求福”的“礼仪”相关，进而引申到社会生活中各种行为上某种约定俗成的规范，而这，必然与当下社会当下本身相关。而“孝”本身，也是一种约定俗成的规范，同样具有当下性。因此，在孔子看来，所谓的“孝“，是在社会行为规范的动态系统中一个当下的呈现。没有任何先验的规范，使得“孝”有绝对不可更改的标准。

缠中说禅白话直译
孟懿子问孝。子曰：“无违”。樊迟御，子告之曰：“孟孙问孝於我，我对曰，”无违。””樊迟曰：“何谓也？”子曰：“生，事之以礼；死，葬之以礼，祭之以礼。”
孟懿子问孝。孔子说：“不要离开。”樊迟替孔子赶车，孔子对他说：“孟孙向我问孝，我回答说：“不要离开”。”樊迟说：“什么意思？”孔子道：“父母在世，用社会当下约定俗成的规范去侍奉他们；父母去世，用社会当下约定俗成的规范去安葬、祭祀他们。”

## 69. 子游问孝。子曰：“今之孝者，是谓能养。至於犬马，皆能有养；不敬，何以别乎。”

本章字面意思很清楚，但与上章视角不同。上章是站在整体的社会结构角度审视“孝”作为一种特殊的社会规范的当下性。而本章，是站在具体个体的角度，审视“孝”作为一个具体的个体行为的当下性。所谓“在貌为恭，在心为敬”，孔子强调“敬”，而不是表面上的“养”。心，惟在当下，一心不敬，则不过将父母当成犬马，即使能养之，又有何益？

缠中说禅白话直译
子游问孝。子曰：“今之孝者，是谓能养。至於犬马，皆能有养；不敬，何以别乎。”
子游问孝。孔子说：“能养父母就被认为是现在的孝了。甚至狗和马，都会有人养；如果内心不敬，又用什么来区别这两者？”

## 70. 孟武伯问孝。子曰：“父母唯其疾之忧。”

孟武伯，孟懿子的儿子。“父母唯其疾之忧”是“唯其疾之忧父母者”的倒装与省略， “唯”，纵使；“其”，指代儿女；“之”，结构助词。孔子这里说的很平易，也很有操作性。什么是孝？孔子给出一个判别的标准，就是“儿女纵使生病也担忧父母的那种感情”，为什么？因为自己生病而使得父母担心，更使得父母得不到照顾，为此不安，因此产生忧愁。这种感情是当下产生、发自内心的，不需要什么道德规范去约束。

本章，如上章，同是站在具体个体的角度，审视“孝”作为一个具体的个体行为的当下性。孝，不是一种虚无飘渺的道德概念，而是一种真切的当下的感情，纵使你生病，也当下产生担忧父母的感情，这就是孝。当然，平时没有生病时，当下产生担忧父母的感情，同样也是孝。但在生病等极端情况下，依然能当下自然地产生担忧父母的感情，这种孝才算是经历考验的。 有些所谓的孝子，平时口比蜜甜，真到紧要关头，只想着自己，所谓久病床前无孝子，更不用说自己生病等情况了，这些都不能算是真正的孝。

注意，这里的“疾”只指生病，不指那些不当行为等导致的过患。人间最大的不幸莫过于白发送黑发，任何不珍惜自己生命的，因为一些恶习而遭遇意外的儿女，都是世间最不孝之人。 另外，因为自己的行为遭受伤残、牢狱等，道理也是一样的。为什么？一个因为自己的不当行为而导致伤残、牢狱、甚至死亡的，绝不可能在当下真正产生对父母的担忧，这些人心里如果真的担忧父母，就不会容忍自己有任何不当行为而把自己陷入险地。

缠中说禅白话直译
孟武伯问孝。子曰：“父母唯其疾之忧。”
孟武伯问孝，孔子说：“（孝就是）纵使自己生病也担忧父母的那种当下产生的感情。”

## 71. 子夏问孝。子曰：色难。有事，弟子服其劳；有酒食，先生馔，曾是以为孝乎？

“色”，本义脸色；“难”，为难；“事”，事故；“服”，负担；“其”，指代“事”；“劳”，烦劳，麻烦；“弟子”，年轻人；“先生”，年长者；“馔”，吃喝；“曾”，本义是副词，加强语气。

本章依然是站在当下的情感角度讨论“孝”，“有事，弟子服其劳；有酒食，先生馔”，在一般人看来，就是“孝”了，但孔子并不这样认为。因为这种所谓孝的行为，完全可以是不情愿、在某种道德规范压力下出现的，这种行为不是发自内心的当下情感，露于外，就会“色难”，这就不能算是“孝”。

缠中说禅白话直译
子夏问孝。子曰：色难。有事，弟子服其劳；有酒食，先生馔，曾是以为孝乎？
子夏问孝，孔子说：“有事故，让年轻人负担其中的烦劳；有酒食，让年长者吃喝；但如果这些行为不是发自当下的情感，只是由于一种道德规范的力量，内心不情愿甚至在外显露出脸色为难，那么，难道就能把这种行为当成孝吗？

## 72. 子曰：父母在，不远游，游必有方。

“方”通假“谤”，这在《论语》中并不是孤例，例如“子贡方人”这句也是这个意思； “远”，不是指距离远，而是指偏远险恶之地；“游”，这里指的是“游学”。

该句意思是，当父母还健在时，即使像“游学”这样有意义的事情，如果要以身赴险，孔子也是不赞成的，如果一定要去，那么就会有“谤”，也就是被诅咒的意思。这里的诅咒，可能是旁人的，也可能是命运的，所谓多行不义必自毙，这也是一种诅咒。

孔子在这里说得很平实，对于一个家庭，家族的传承是很重要的，别以为这是封建思想，试想，所有人都断子绝孙，那人类还存在吗？唯一需要纠正的，就是家族传承并不一定以男性为基础，女性也一样。而古代人的寿命都比较短，父母在，对于家族来说，最重要的是抓紧时间延续其香火，任何以身赴险的事情，必不可取。即使香火已延续，一旦以身赴险使得白发送黑发，那就是天底下最大的不孝了。这点，对男性女性都是一样的。

缠中说禅白话直译
子曰：父母在，不远游，游必有方。
孔子说：“当父母健在时，即使是游学也不能到偏远险恶之地，否则一定招致旁人或命运的诅咒。”

## 73. 子曰：父母之年，不可不知也。一则以喜，一则以惧。

“孝”是一种当下的，直接呈现的情感，而这一章，是对此一个最平实的描述。“知”，从“口”，旁边是“矢”，意思是“识敏，故出于口者疾如矢也”，即“认识、知道的事物，可以脱口而出，像箭一样快”。“父母之年”，父母的年龄；“不可不知”，不可不脱口而出。请问，你能否立刻不加思索就能说出自己父母的年龄？这一点，绝大多数的人都办不到。

什么事情才能脱口而出？当然是常被挂念的，与自己的身心、情感一体的。我们的身体，来自父母，被父母所养育，自然与父母是身心、情感一体的。如果连“父母之年”都不能脱口而出，那如何能称为“孝”？这里的“年”，除了指出年龄，还有和父母相关的一些日期，例如他们的生日，还有我们的出生日等等。有人可能奇怪，我们的出生日如何与父母相关？其实，我们的出生日，对于父母，特别是母亲来说是苦日，在古代，这一点更明显，因为生育条件不好而死去的母亲，在当时并不罕见，就是平安，生育中所受之苦，也是人生之大苦之一。

而这种当下的情感，是“一则以喜，一则以惧”，是“悲欣交集”的。其实，人生的所有事情，都是如此，“一则以喜，一则以惧”，“悲欣交集”。人，非纯苦非纯乐，苦乐皆有，才有所谓的人。如果按六道轮回的观点，鬼道、地狱等纯苦，天道纯乐，都不适宜修行悟道。而只有人道是苦乐皆有，“悲欣交集”，所以才说人身难得。得此难得之人身，而不行正道，就如盲龟偶遇一孔木而弃之，怎能不万劫于苦海沉浮？如果连“孝”这最基本的情感都没有，又何以为人？何以行之正道？孔子、论语虽非彻底之论，但从这最基本处着手，却是最平实可行的。

缠中说禅白话直译
子曰：父母之年，不可不知也。一则以喜，一则以惧。
孔子说：“父母的年龄、生日等，不能不常常挂念以至能脱口而出。这种当下的情感，一方面带着欢喜，一方面带着忧惧，悲欣交集。

## 74. 子曰：君子喻於义，小人喻於利。

利益、利害，都必须究底穷源，对整个社会、各种制度的运行有深切了解的人，才有可能对利害、利益有稍微的了解。否则，不过是一个利益机器上被摆布的一群，利益战争下的一堆炮灰而已。

何谓小人？首先是人，只是画地为牢，自小而已。而一般的所谓人，在社会结构被社会机器所玩弄，所有的学问、观念，不过被所谓的常识、天经地义的所组装而已。这里可以毫不客气地说，在孔子眼里，一般的所谓人，连小人都算不上，不过是假人，木偶而已。

“於”，是“被”的意思，后面的“义”、“利”，都是“喻”的主动者。无论“君子”、“小人”，其“喻”都不是无源之水，都是因为被“义”、“利”的力量所牵引中而“喻”的。如果没有“义”、“利”，没有这个社会结构本身，所谓的“君子”、“小人”之“喻”都是胡诌。何谓“喻”？开导也。

本章的意思，就是“君子被义所开导，小人被利所开导。”那么，何谓“义”，何谓“利”？“利”，就是利益、利害关系所组成的现实社会结构以及其对应的一套现实运行机制；“义”，各种现实结构所对应的道德、法度等规范。

小人，在参与利益之网的现实运作中，被利益之网的潜在力量所开导，明白了其中运行的机制与结构，从而于其中而游刃有余，由此而得其大利，所谓窃财而不留盗痕，窃名而万古留名，窃国而成国之圣人，这才算够得上当一小人。

君子，首先要成一小人。君子成于小人，一个不是先成小人的君子，不过是一个糊涂蛋。于“利”糊涂，成不了小人，更成不了君子。“君子”，能游刃于利益之网中，更被各种现实结构所对应的道德、法度等规范所开导，知其时、依其时、行其时而转其时，不相其相，转毒药而醍醐、大地而黄金，“人不知”而“人不愠”，这才是真君子之所行。

小人，虽说是对利益之网而游刃有余，但因为画地为牢，自我小之，为一我所牵，最终不过仍是机关木人，到头来，被一点聪明所误，一场游戏一场梦而已。而君子，尽知小人所知，行小人之行而无一我之所牵，不废一法而行千法万法，行千法万法而不立一法，于所知所行而自在。

缠中说禅白话直译
子曰：君子喻於义，小人喻於利。
孔子说：“君子被各种现实社会结构以及对应的各种道德、法度等规范的关系之网中蕴藏的力量所开导，小人被利益、利害关系所组成的现实社会结构以及其对应的一套现实运行机制的关系之网中蕴藏的力量所开导。”

## 75. 子曰：君子周而不比，小人比而不周。

这章的根本就两字：“周”和“比”。何谓“比”？“比”在甲骨文里是两人步调一致、比肩而行，典型的象形字；“周”，甲骨文里是“田”里有四点，表示把田里都种满了，因此就有周遍而没有疏漏的意思。那么，什么是“君子周而不比，小人比而不周”呢？字面意思就是，君子所见所闻所知所行周遍而没有疏漏，但不会让别人和自己步调一致、比肩而行；而小人，总是希望别人和自己步调一致、比肩而行，但所见所闻所知所行却不能周遍而没有疏漏。

这里很明显，孔子认为，所有小人的一个很大的共同点，都是希望别人和自己步调一致、比肩而行，为什么？小人，被一个“我“所牵制，他自己的行为、见解，都不过是那个“我”的造作，永远和那“我”步调一致、比肩而行，因此，这种内在的品行自然就推而广之，希望任何人都和“我”一样，所有人的利益都为“我”而来，诸如此类的。任何希望和自己步调一致、比肩而行的学问、宗教、理论等等，都是小人之学。例如所谓的基督教、道教之类的玩意，立一个上帝、道，然后让人去步调一致、比肩而行，这就是典型的小人之学。

君子之学，不同而大同，不需要什么步调一致、比肩而行。这世界有无数种花，怎么可能让每种花都步调一致、比肩而行？只有了“周”，才可能“不比”，面首的世界只有来面首的和被面首的，小人的世界只有小人。君子的世界，不光有君子，里面还有面首、小人。君子，没有世界，君子的世界，只是世界本身而已。世界“不知”，君子“周”其“不知”而“不相”之，转“不知”之世界为“不愠”之世界，而君子，本无能转所转。就如同阳光普照，无所谓照物，而物得阳光而自彰，阳光本无能彰所彰。

缠中说禅白话直译
子曰：君子周而不比，小人比而不周。
孔子说：君子，见闻学行周遍而没有疏漏，却不会让别人和自己步调一致、比肩而行；小人，让别人和自己步调一致、比肩而行，见闻学行却不能周遍而没有疏漏。

## 76. 子曰：君子和而不同；小人同而不和。

本章重点，就在于“同”与“和”。“同”，会意字，“冃+口”，“冃”，重复，何谓“同”？就是通过口头上的不断重复达到聚集，当然，这反映着孔子时代的特征，实际上，这口头上的限制并不需要。例如，文化就是一种“同”，文化，从开始的口头传播到现在的网络传播，本质上并没有改变“不断重复达到聚集”的效果；“宗教”更是一种“同”，所谓的教义、教宗等等，就是一种“不断重复达到聚集”的玩意；“科学”一样是“同”，“科学”从本质上是文化、宗教的大汇集，科学相信“不断重复的实验”达到“同一”的效果，是其成立的基础，是科学得以聚集的基础。总之，文化、科学、宗教等等，以及一切社会结构中的一切玩意，本质上都是“同”，都是“不断重复达到聚集”的玩意。“哲学”之类的玩意，无论唯心、唯物、一元、多元、辨证、诡辩，同样是这样。这一切，本质上都是小人之学，在“人不知”的世界，其学也只能是小人之学。

聚集，本质上都不过为了一己之私利。在资本横行的国家、年代，资本就是最大的“同”，社会上的任何现象、言论，都在“不断重复”达到聚集在资本之“同”的大旗之下，资本社会的人，本质上不过是“资本”的复制，都不过是被“资本”所抽干的行尸走肉。

“和”，去声，就是“相应”。“天人相应”、“心手相应”，“桴鼓相应”，诸如此类，都是表达了“和”与“相应”。在孔子那里，在君子眼中，只有“天人相应”，却没有所谓“天人合一”的小人之说。注意，这里的相应，超越了海德格尔所说的“应手”，那不过依然在共业的境界之中，而一般人的理解，连海德格尔所说的“应手”都达不到。

人类社会，“地”的一种形态，不过是“天人相应”而成，无所谓“天”，无所谓“人”，“天人相应”而成这人类社会这“地”的特殊形态。天，“地人相应”而成；人，“天地相应”而成；地，“天人相应”而成。成无所成，不过是相续相缠，相应而已。

孔子在本章里，揭示“天地人”结构最重要之一的关系，就是“相应”，就是“和”。 就如同音乐中的即兴演奏，这宇宙就在这相续相缠中“和”、“相应”，这里没有任何需要“不断重复”去达到聚集的。企图通过“不断重复”去聚集点什么玩意、抓住点什么玩意，不过是小人“我”之私心相应之妄想。

而君子之间，也只是相应；君子于所在的时代、社会，所对应的“天地人”结构中，也只是相应。就如同空谷与空谷的对话，可以风雷激荡、可以溪水潺潺，可以幻化出天地间所有的神奇与风景，但却依然只是空谷与空谷的对话，空谷与空谷的相应，如此而已。

缠中说禅白话直译
子曰：君子和而不同；小人同而不和。
孔子说：君子相应而不聚集，小人聚集而不相应。

## 77. 子曰：君子成，人之美；不成，人之恶。小人反是。

在后面的《论语》中，有这么一条：子张问於孔子曰：“何如，斯可以从政矣？”子曰：“尊五美，屏四恶，斯可以从政矣”。也就是说，“美、恶”是关乎人的品行的，用现代的话，大致就类似于说“美德、恶行”。在孔子眼里，德行是合一的，说德就是说行，说行也就是说德。何谓德？就是“得”。孔子讲究的是“行必果”，必须有所得。而这“得”，不是个人利益上的，而是在品行上的“得”。注意，这里的品行，推而广之，可以关乎家、国、天下。人，有其德行；天下，亦有其德行。这种德行，在孔子眼里，不是没有“美恶”之分的，而是“美恶”分明的。“之”，这里不是结构助词，而是其本义，动词，在远古文字里，是一个象形字，象征着树木的枝茎等不断长大，引申为“生出，滋长”的意思。

通常的错误分句：“君子成人之美，不成人之恶。小人反是”，将这里的“人”看成是别人，将君子和别人打成两橛，然后君子似乎有特殊的魔力，能够成就别人的“美、恶”；相同的逻辑也被用在小人身上。其实，本章探究的，是一个如何成为君子、小人的问题，这里的“人”是泛指的。君子、小人，都是一种“德行“，是动态的，不是静态的，并不是一个诸如毕业证之类的东西。 原句倒装，相应句子等于“人之美而君子成，人之恶而君子不成。小人反是”。

人，本无所谓君子小人，这不是天生的，而是后天“见闻学行”而来。人，不断滋生出美德，而杜绝恶行，人就能成为君子；反之，就成为小人。这是和孔子人人皆可尧舜的想法相一致的。人人平等，最终能成为什么，关键是看你自己“之美”还是“之恶”。正因为有此，才有修身的必要，才一切自足，不需要去求任何外面的神力。因为一切外力，都不可能替代你去“之”，你的生长只能是你的生长，你的德行只能是你的德行，没有任何上帝可以替代。 孔子从来不会相信，那些被所谓上帝一救就可以永生的无聊谎言，孔子只相信自己的力量，一切都由每个人自己的力量生发出来，这也是中国古代“自强不息”传统的逻辑所在。

缠中说禅白话直译
子曰：君子成，人之美；不成，人之恶。小人反是。
孔子说：人不断滋生美德，君子成就；人不断滋生恶行，君子不成。小人的成就与此相反。

## 78. 子曰：君子之於天下也，无适也，无莫也，义之於比。

“适”，本义是“往、到”，引申为“归向”；“莫”，通假“慕”，“向往”的意思。“义”，名词动化用法，“取义”的意思，但这不是“舍生取义”里的“取义”，那里的“义”变成了一种上帝式的无聊道德规范，这里的“义”是“仪”的古字，“容貌”的意思；“比”，就是“小人比而不周”里的“比”。

“归向”落实为一种行动，“向往”只是思想里那一点东西，因此“莫”比“适”程度上要轻点。君子对于天下的事物，不会立一个绝对的标准、上帝的模式之类的玩意在行为上去“适”，甚至连思想里的的“莫”都不会有。但历史上，无数的人，就是要在天下的事物里，忽悠点玩意出来，让人去“适”、去“莫”，然后这些徒子徒孙就当炮灰、传教士不断折腾。这一切，都不是君子所为。君子不但自己不去“适”去“莫”那些偶像、上帝、道之类的忽悠玩意，更不会去制造这些玩意，这天下，没一法可得，没一法可失，没有什么值得去“适”去“莫”的。

但光无“适”无“莫”，依然不是君子所为。君子无“适”无“莫”天下任何一物，但也不轻视天下任何一物。那种号称天下无“适”无“莫”，然后就扮成所谓的高人高士者，不过是去“适”去“莫”这些所谓高人高士的无聊玩意。君子眼里，无净无污，天堂地狱一任往来，君子可以混迹于小人堆里“取义”之于“比”，呈现一种“比”的容貌，行小人行却无小人之“适”与“莫”。

一般人都把菩萨“适”“莫”于一些自己想象的神圣事物，但难道乞丐、妓女、面首、杀人犯里就没有菩萨所行？菩萨行，无所不行，地狱天堂人神鬼兽崇高低劣，无处不在。菩萨行而无所住，无所住而无所不行。甚至，行“适”“莫”之相，也是菩萨之行，而君子之行的道理是同样的。

菩萨自可见菩萨，君子自可见君子。有小人也装着说自己的小人之相只是“义之于比“，自己是无“适”无“莫”的，那当然可以蒙骗一般人。一般人被蒙骗，那是活该被蒙骗。这种事情，在历史上太多了。最毒的花，如果没有其土壤，是长不出来的。 而“人不知”的世界，就是所有毒花最好的土壤。最毒的，就是人的心地。所有的恶行，都是共业的结果，别把自己当成无辜的婴孩。老子号称婴孩是最纯洁的，要回去，那是脑子进水。婴孩的残忍并不比成年人小，只是没有能力显现而已。但人的心地，又是最善的，所有的善行，同样是共业的结果。善恶，都是尔心所生。成君子的是你，成小人的也是你，没有人能替代你。
有人可能要问，明明知道“无适”、“无莫”，但为什么还是去“适”去“莫”了？这就是自己的心力被业力所牵引，自己的力量没有达到。业力之风只能吹走那些能被业力之风吹走的，而真正的自由，就是自由于这业力之网，“无适”、“无莫”地自由于各种境界。

生死是大业力，光喊“无适”、“无莫”，如何如何讨厌去“死”去轮回，但“死”和“轮回”依然不爽。真正的君子，不仅要之於天下而无适、无莫，更要之於生死而无适、无莫。因此，下面的句子同样是君子所必须的：“君子之於生死也，无适也，无莫也，义之於死。”

缠中说禅白话直译
子曰：君子之於天下也，无适也，无莫也，义之於比。
孔子说：君子对于天下的一切，没有行为的归向，也没有思想的向往，甚至可以让自己的容貌呈现出小人的“比“相。